@@ -2,13 +2,16 @@
 Annalist application
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__        = "Graham Klyne"
 __author_email__  = "GK@ACM.ORG"
 __copyright__     = "Copyright 2014 G. Klyne"
 __license__       = "MIT (http://opensource.org/licenses/MIT)"
 
 # https://docs.djangoproject.com/en/dev/ref/applications/
-default_app_config = 'annalist.apps.AnnalistConfig'
+# default_app_config = 'annalist.apps.AnnalistConfig'   @@DEPRECATED
 
 """
 Software version number.
@@ -18,7 +21,7 @@ Even sub-releases are stable versions, except for critical bug-fixes
 
 Odd sub-releases are work-in-progress, and code may change from day-to-day.
 """
-__version__        = "0.5.8"   # Software version number (odd = unstable)
+__version__        = "0.5.18"   # Software version number (odd = unstable)
 
 """
 Data compatibility version: this is saved with collection data, and is used to
@@ -30,9 +33,10 @@ presumption that new software can read older data, and migrate it where necessar
 Not all software updates create data that cannot be read by older software: for 
 these updates the __version_data__ value can be left unchanged.
 """
-__version_data__   = "0.5.7"    # Data compatibility version number
+__version_data__   = "0.5.9"    # Data compatibility version number
 								# 0.5.5: Supertype closure evaluation logic added
 								# 0.5.7: Superproperty URIs added to field definitions;
 								#        Render type changes for supertypes
+								# 0.5.9: Rename "annal:record_type" fields
 
 # End.
