@@ -1,7 +1,12 @@
+# pylint: disable=too-many-instance-attributes, too-few-public-methods
+
 """
 Annalist directory/site layout
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014-2016, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
@@ -57,12 +62,14 @@ log = logging.getLogger(__name__)
 
 COLL_TYPEID             = "_coll"
 COLL_BASE_DIR           = "d"
+COLL_PAGE_DIR           = "p"
 COLL_ROOT_CONF_OLD_DIR  = "_annalist_collection"
 COLL_BASE_CONF_OLD_DIR  = "../" + COLL_ROOT_CONF_OLD_DIR
 COLL_META_FILE          = "coll_meta.jsonld"
 COLL_META_TURTLE        = "coll_meta.ttl"
 COLL_PROV_FILE          = "coll_prov.jsonld"
 COLL_BASE_REF           = COLL_BASE_DIR + "/"
+COLL_PAGE_REF           = COLL_PAGE_DIR + "/"
 COLL_META_REF           = COLL_BASE_REF + COLL_META_FILE
 COLL_PROV_REF           = COLL_BASE_REF + COLL_PROV_FILE
 COLL_TURTLE_REF         = COLL_BASE_REF + COLL_META_TURTLE
@@ -72,12 +79,12 @@ COLL_CONTEXT_FILE       = "coll_context.jsonld"
 # COLL_CONTEXT_REF        = COLL_BASE_REF + COLL_CONTEXT_FILE
 
 SITE_TYPEID             = "_site"
-SITE_DIR                = "annalist_site"
 SITEDATA_ID             = "_annalist_site"
 SITEDATA_DIR            = "c/%(id)s"%{'id': SITEDATA_ID}
 SITEDATA_OLD_DIR1       = "_annalist_site"
 SITEDATA_OLD_DIR2       = SITEDATA_DIR+"/"+COLL_ROOT_CONF_OLD_DIR
 SITE_META_PATH          = ""
+SITE_META_REF           = "."
 SITE_META_FILE          = "site_meta.jsonld"    # Currently not used except to store description data
 META_SITE_REF           = "./"
 SITE_COLL_VIEW          = "c/%(id)s/"
@@ -103,7 +110,7 @@ BIBDATA_ID              = "Bibliography_defs"                       # used for t
 #
 
 # Type records
-TYPE_TYPEID             = "_type"                           # type id, used in URL
+TYPE_TYPEID             = "_type"                           # type id for type records, used in URL
 TYPE_DIR                = "_type"                           # collection directory in file system
 TYPE_DIR_PREV           = "types"                           # collection directory in file system
 TYPE_META_FILE          = "type_meta.jsonld"                # type metadata file name
@@ -115,7 +122,7 @@ COLL_TYPE_PATH          = COLL_BASE_REF + TYPE_DIR + "/%(id)s"
                                                             # type dir relative to collection root dir
 
 # List description records
-LIST_TYPEID             = "_list"                           # list id, used in URL
+LIST_TYPEID             = "_list"                           # list type id, used in URL
 LIST_DIR                = "_list"                           # collection directory in file system
 LIST_DIR_PREV           = "lists"                           # collection directory in file system
 LIST_META_FILE          = "list_meta.jsonld"                # list metadata file name
@@ -127,7 +134,7 @@ COLL_LIST_PATH          = COLL_BASE_REF + LIST_DIR + "/%(id)s"
                                                             # list dir relative to collection root dir
 
 # View description records
-VIEW_TYPEID             = "_view"                           # type id, used in URL
+VIEW_TYPEID             = "_view"                           # view type id, used in URL
 VIEW_DIR                = "_view"                           # collection directory in file system
 VIEW_DIR_PREV           = "views"                           # previous collection directory
 VIEW_META_FILE          = "view_meta.jsonld"                # view metadata file name
@@ -139,7 +146,7 @@ COLL_VIEW_PATH          = COLL_BASE_REF + VIEW_DIR + "/%(id)s"
                                                             # view dir relative to collection root dir
 
 # Field-group description records
-GROUP_TYPEID            = "_group"                          # group id, used in URL
+GROUP_TYPEID            = "_group"                          # group type id, used in URL
 GROUP_DIR               = "_group"                          # collection directory in file system
 GROUP_DIR_PREV          = "groups"                          # previous collection directory
 GROUP_META_FILE         = "group_meta.jsonld"               # group metadata file name
@@ -150,7 +157,7 @@ COLL_GROUP_PATH         = COLL_BASE_REF + GROUP_DIR + "/%(id)s"
                                                             # group dir relative to collection root dir
 
 # Field description records
-FIELD_TYPEID            = "_field"                          # field id, used in URL
+FIELD_TYPEID            = "_field"                          # field type id, used in URL
 FIELD_DIR               = "_field"                          # collection directory in file system
 FIELD_DIR_PREV          = "fields"                          # previous collection directory
 FIELD_META_FILE         = "field_meta.jsonld"               # field metadata file name
@@ -174,7 +181,7 @@ COLL_USER_PATH          = COLL_BASE_REF + USER_DIR + "/%(id)s"
                                                             # user dir relative to collection root dir
 
 # Vocabulary namespace records
-VOCAB_TYPEID            = "_vocab"                          # vocab id, used in URL
+VOCAB_TYPEID            = "_vocab"                          # type id, used in URL
 VOCAB_DIR               = "_vocab"                          # collection directory in file system
 VOCAB_DIR_PREV          = "vocabs"                          # previous collection directory
 VOCAB_META_FILE         = "vocab_meta.jsonld"               # vocab metadata file name
@@ -185,6 +192,19 @@ COLL_VOCAB_VIEW         = COLL_BASE_REF + COLL_BASE_VOCAB_REF + "/"  # ref vocab
 COLL_VOCAB_PATH         = COLL_BASE_REF + VOCAB_DIR + "/%(id)s"
                                                             # vocab dir relative to collection root dir
 
+# General information records
+# Used for holding application information for display; e.g., for the `about` link.
+INFO_TYPEID             = "_info"                           # info type id
+INFO_DIR                = "_info"                           # collection directory in file system
+INFO_DIR_PREV           = None                              # previous directory for migration 
+INFO_META_FILE          = "info_meta.jsonld"                # info data file name
+INFO_META_TURTLE        = "info_meta.ttl"                   # reference info data as Turtle
+INFO_PROV_FILE          = "info_prov.jsonld"                # info provenance file name
+COLL_BASE_INFO_REF      = INFO_TYPEID + "/%(id)s"           # ref info relative to collection base URL
+COLL_INFO_VIEW          = COLL_BASE_REF + COLL_BASE_INFO_REF + "/"  # ref info view relative to collection entity
+COLL_INFO_PATH          = COLL_BASE_REF + INFO_DIR + "/%(id)s"
+                                                            # info dir relative to collection root dir
+
 # Enumerated value descriptions
 ENUM_FIELD_PLACEMENT_ID     = "_enum_field_placement"       # Field placement options
 ENUM_LIST_TYPE_ID           = "_enum_list_type"             # List type (list, grid)
@@ -269,17 +289,20 @@ DATA_DIRS_CURR_PREV = (
     , (ENUM_VALUE_MODE_DIR,         ENUM_VALUE_MODE_DIR_PREV2)
     , (ENUM_VALUE_TYPE_DIR,         ENUM_VALUE_TYPE_DIR_PREV2)
     ])
-DATA_DIRS       = map(lambda pair:pair[0], DATA_DIRS_CURR_PREV)
-DATA_DIRS_PREV  = map(lambda pair:pair[1], DATA_DIRS_CURR_PREV)
+DATA_DIRS       = [ p[0] for p in DATA_DIRS_CURR_PREV ]
+                # map(lambda pair:pair[0], DATA_DIRS_CURR_PREV)
+DATA_DIRS_PREV  = [ p[1] for p in DATA_DIRS_CURR_PREV ]
+                # map(lambda pair:pair[1], DATA_DIRS_CURR_PREV)
 DATA_VOCAB_DIRS = DATA_DIRS + [VOCAB_DIR]
 
 COLL_DIRS_CURR_PREV = (
     DATA_DIRS_CURR_PREV +
     [ (USER_DIR,  USER_DIR_PREV)
     , (VOCAB_DIR, VOCAB_DIR_PREV)
+    , (INFO_DIR,  INFO_DIR_PREV)
     ])
-COLL_DIRS       = map(lambda pair:pair[0], COLL_DIRS_CURR_PREV)
-COLL_DIRS_PREV  = map(lambda pair:pair[1], COLL_DIRS_CURR_PREV)
+COLL_DIRS       = [ p[0] for p in COLL_DIRS_CURR_PREV ]
+COLL_DIRS_PREV  = [ p[1] for p in COLL_DIRS_CURR_PREV if p[1] ]
 
 # Name generation suffixes for tasks that generate new records
 SUFFIX_LIST             = ""
@@ -289,12 +312,10 @@ SUFFIX_SUBTYPE          = "_subtype"
 SUFFIX_SUBPROPERTY      = "_subproperty"
 SUFFIX_REPEAT           = "_many"
 SUFFIX_REPEAT_P         = "_many"
-SUFFIX_REPEAT_G         = "_many"
 SUFFIX_SEQUENCE         = "_list"
 SUFFIX_SEQUENCE_P       = "_list"
-SUFFIX_MULTI            = "_m"      # Reference multiple fields...
-SUFFIX_MULTI_P          = "_m"
-SUFFIX_MULTI_G          = "_m"
+SUFFIX_REF_FIELD        = "_ref"    # Reference field name...
+SUFFIX_REF_FIELD_P      = "_ref"    # Reference field property ...
 
 class Layout(object):
     """
@@ -302,18 +323,18 @@ class Layout(object):
     using a supplied base directory.
     """
 
-    def __init__(self, base_data_dir):
+    def __init__(self, base_data_dir, site_dir_name):
         """
         Dynamically initialize a layout value
         """
         self.BASE_DIR           = base_data_dir
-        self.SITE_DIR           = SITE_DIR
+        self.SITE_DIR_NAME      = site_dir_name
         self.SITEDATA_ID        = SITEDATA_ID
         self.SITEDATA_DIR       = SITEDATA_DIR
         self.SITEDATA_OLD_DIR1  = SITEDATA_OLD_DIR1
         self.SITEDATA_OLD_DIR2  = SITEDATA_OLD_DIR2
-        self.SITEDATA_BASE_DIR  = SITEDATA_BASE_DIR                         # e.g. c/_annalist_site/d
-        self.SITE_PATH          = os.path.join(base_data_dir, SITE_DIR)     # e.g. /data/annalist_site
+        self.SITEDATA_BASE_DIR  = SITEDATA_BASE_DIR     # e.g. c/_annalist_site/d
+        self.SITE_PATH          = os.path.join(base_data_dir, site_dir_name)
         self.SITE_META_FILE     = SITE_META_FILE
         self.SITE_DATABASE_FILE = SITE_DATABASE_FILE
         return
