@@ -12,23 +12,30 @@ A collection is represented by:
 - ... and additional supporting metadata (fields, groups, user permissions, etc.)
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
+import logging
+log = logging.getLogger(__name__)
+
 import os
 import os.path
-import urlparse
 import shutil
 import json
 import datetime
 from collections                    import OrderedDict
-from distutils.version              import LooseVersion
 
-import logging
-log = logging.getLogger(__name__)
+from packaging.version              import Version
 
-from django.conf import settings
+# from distutils.version              import LooseVersion
+
+from django.conf                    import settings
+
+from utils.py3porting               import isoformat_space
 
 import annalist
 from annalist                               import layout
@@ -117,8 +124,7 @@ class Collection(Entity):
             [ (ANNAL.CURIE.comment,     ANNAL.CURIE.meta_comment    )
             ])
         collmetadata = self._migrate_values_map_field_names(migration_map, collmetadata)
-        if collmetadata[ANNAL.CURIE.type_id] == "_collection":
-            collmetadata[ANNAL.CURIE.type_id] = self._entitytypeid
+        collmetadata[ANNAL.CURIE.id] = self._entityid # In case directory renamed by hand
         return collmetadata
 
     def flush_collection_caches(self):
@@ -230,6 +236,8 @@ class Collection(Entity):
         coll_root_dir     = os.path.join(parent_base_dir, layout.SITE_COLL_PATH%{"id": coll_id})
         coll_base_dir     = os.path.join(coll_root_dir,   layout.COLL_BASE_DIR)
         coll_conf_old_dir = os.path.join(coll_root_dir,   layout.COLL_ROOT_CONF_OLD_DIR)
+        #@@ TODO: remove this during 1.x prelease cycle, 
+        #   not covered by tests.  Or remove entire method.
         if os.path.isdir(coll_conf_old_dir):
             log.info("Migrate old configuration from %s"%(coll_conf_old_dir,))
             for old_name in os.listdir(coll_conf_old_dir):
@@ -263,8 +271,22 @@ class Collection(Entity):
                     )
                 log.error("Collection._migrate_collection_config_dir: "+msg)
                 assert False, msg
+        #@@
         return
 
+    def _post_update_processing(self, entitydata, post_update_flags):
+        """
+        Default method for post-update processing.
+
+        This method is called just after collection metadata has been created or updated.  
+
+        For a collection, the caches are flushed as a change to the parent collection
+        may mean that cached values are no longer applicable.  (Updating a collection
+        description is considered to be a relatively rare operation.)
+        """
+        self.flush_collection_caches()
+        return entitydata
+
     @classmethod
     def load(cls, parent, coll_id, altscope=None):
         """
@@ -283,7 +305,9 @@ class Collection(Entity):
         """
         # log.debug("@@ Collection.load: %s, altscope %s"%(coll_id, altscope))
         cls._migrate_collection_config_dir(parent, coll_id)
-        coll = super(Collection, cls).load(parent, coll_id, altscope=altscope)
+        coll = super(Collection, cls).load(
+            parent, coll_id, altscope=altscope
+            )
         if coll is not None:
             cls._set_alt_parent_coll(parent, coll)
         return coll
@@ -314,7 +338,7 @@ class Collection(Entity):
     def update_software_compatibility_version(self):
         # (assumes data loaded)
         ver = self.get(ANNAL.CURIE.software_version, None) or "0.0.0"
-        if LooseVersion(ver) < LooseVersion(annalist.__version_data__):
+        if Version(ver) < Version(annalist.__version_data__):
             self[ANNAL.CURIE.software_version] = annalist.__version_data__
             self._save()
 
@@ -384,22 +408,11 @@ class Collection(Entity):
             log.warning(msg)
             t = RecordType.load(self, vocab_id, altscope="all")
             vocab_cache.set_vocab(self, t)
-            # raise ValueError(msg) #@@@ (used in testing to help pinpoint errors)
+            # raise ValueError(msg) #@@ (used in testing to help pinpoint errors)
         return t
 
     # Record types
 
-    #@@
-    # @classmethod
-    # def reset_type_cache(cls):
-    #     """
-    #     Used for testing: clear out type cache so tets don't interfere with each other
-    #     Could also be used when external application updates data.
-    #     """
-    #     type_cache.flush_all()
-    #     return
-    #@@
-
     def types(self, altscope="all"):
         """
         Iterator over record types stored in the current collection.
@@ -432,7 +445,7 @@ class Collection(Entity):
             log.warning(msg)
             t = RecordType.load(self, type_id, altscope="all")
             type_cache.set_type(self, t)
-            # raise ValueError(msg) #@@@ (used in testing to help pinpoint errors)
+            # raise ValueError(msg) #@@ (used in testing to help pinpoint errors)
         return t
 
     def cache_remove_type(self, type_id):
@@ -511,7 +524,8 @@ class Collection(Entity):
 
     def get_uri_type(self, type_uri):
         """
-        Return type entity corresponding to the supplied type URI
+        Return type entity corresponding to the supplied type URI,
+        or None if not found.
         """
         t = type_cache.get_type_from_uri(self, type_uri)
         return t
@@ -527,23 +541,6 @@ class Collection(Entity):
         s = RecordType.remove(self, type_id)
         return s
 
-    def update_entity_types(self, e):
-        """
-        Updates the list of type URIs associated with an entity by accessing the
-        supertypes of the associated type record.
-        """
-        type_uri = e.get(ANNAL.CURIE.type, None)
-        st_uris = [type_uri]
-        t       = self.get_uri_type(type_uri)
-        if t:
-            assert (t.get_uri() == type_uri), "@@ type %s has unexpected URI"%(type_uri,)
-            for st in type_cache.get_type_uri_supertypes(self, type_uri):
-                st_uri = st.get_uri()
-                if st_uri not in st_uris:
-                    st_uris.append(st_uri)
-        e['@type'] = st_uris
-        return
-
     # Record views
 
     def views(self, altscope="all"):
@@ -609,7 +606,7 @@ class Collection(Entity):
         view_id   = self.get(ANNAL.CURIE.default_view_id,     None)
         type_id   = self.get(ANNAL.CURIE.default_view_type,   None)
         entity_id = self.get(ANNAL.CURIE.default_view_entity, None)
-        log.info("Collection.get_default_view: %s/%s/%s"%(view_id, type_id, entity_id))
+        # log.info("Collection.get_default_view: %s/%s/%s"%(view_id, type_id, entity_id))
         return (view_id, type_id, entity_id) 
 
     # Record lists
@@ -686,17 +683,6 @@ class Collection(Entity):
 
     # View (and list) fields and properties
 
-    #@@
-    # @classmethod
-    # def reset_field_cache(cls):
-    #     """
-    #     Used for testing: clear out field cache so tets don't interfere with each 
-    #     other.  Could also be used when external application updates data.
-    #     """
-    #     field_cache.flush_all()
-    #     return
-    #@@
-
     def fields(self, altscope="all"):
         """
         Iterator over view fields stored in the current collection.
@@ -718,7 +704,6 @@ class Collection(Entity):
 
         Returns field entity if found, otherwise None.
         """
-        field_cache.get_field(self, field_id)
         t = field_cache.get_field(self, field_id)
         # Was it previously created but not cached?
         if not t and RecordField.exists(self, field_id, altscope="all"):
@@ -800,10 +785,21 @@ class Collection(Entity):
 
         returns a RecordField object for the identified field, or None.
         """
-        if not valid_id(field_id):
+        if not valid_id(field_id, reserved_ok=True):
             msg = "Collection %s get_field(%s) invalid id"%(self.get_id(), field_id)
             log.error(msg)
-            raise ValueError(msg, field_id)
+            # Construct and return a placeholder field
+            ph_meta = (
+                { RDFS.CURIE.label:               "(field error)"
+                , ANNAL.CURIE.field_render_type:  "_enum_render_type/Placeholder"
+                , ANNAL.CURIE.field_value_mode:   "_enum_value_mode/Value_direct"
+                , ANNAL.CURIE.field_placement:    "small:0,12"
+                , ANNAL.CURIE.placeholder:        
+                    "(Invalid field id: '%s')"%(field_id,)
+                })
+            f = RecordField._child_init(self, "_placeholder")
+            f.set_values(ph_meta)
+            return f
         return self.cache_get_field(field_id)
 
     def get_uri_field(self, property_uri):
@@ -836,11 +832,11 @@ class Collection(Entity):
         if flags and ("nocontext" in flags):
             # Skip processing if "nocontext" flag provided
             return
-        log.info("Generating context for collection %s"%(self.get_id()))
+        # log.info("Generating context for collection %s"%(self.get_id()))
         # Build context data
         context      = self.get_coll_jsonld_context()
         datetime_now = datetime.datetime.today().replace(microsecond=0)
-        datetime_str = datetime_now.isoformat(' ')
+        datetime_str = isoformat_space(datetime_now)
         # Assemble and write out context description
         with self._metaobj(
                 layout.META_COLL_BASE_REF,
@@ -911,12 +907,27 @@ class Collection(Entity):
               , "@type":        "@id"
               }
             })
-        # Scan vocabs, generate prefix data
+        # Scan types, generate prefix data
+        for t in self.child_entities(RecordType, altscope="all"):
+            tid = t.get_id()
+            if tid != layout.INITIAL_VALUES_ID:
+                tns = t.get(ANNAL.CURIE.ns_prefix, "")
+                if tns != "":
+                    context[tns] = self.get_url() + layout.COLL_TYPEDATA_VIEW%({"id": tid})
+        # Scan vocabs, generate prefix data (possibly overriding type-derived data)
         for v in self.child_entities(RecordVocab, altscope="all"):
             vid = v.get_id()
             if vid != layout.INITIAL_VALUES_ID:
                 if ANNAL.CURIE.uri in v:
-                    context[v.get_id()] = v[ANNAL.CURIE.uri]
+                    vuri = v[ANNAL.CURIE.uri]
+                    if vuri[-1] not in {":", "/", "?", "#"}:
+                        msg  = (
+                            "Vocabulary %s namespace URI %s does not end with an expected delimiter"%
+                            (vid, vuri)
+                            )
+                        log.warning(msg)
+                        errs.append(msg)
+                    context[vid] = v[ANNAL.CURIE.uri]
         # Scan view fields and generate context data for property URIs used
         for v in self.child_entities(RecordView, altscope="all"):
             view_fields = v.get(ANNAL.CURIE.view_fields, [])
@@ -946,7 +957,8 @@ class Collection(Entity):
                         e = self.set_field_uri_jsonld_context(subfuri or furi, subfid, fcontext, context)
                         errs.extend(e)
         # Scan group fields and generate context data for property URIs used
-        #@@TODO - to be deprecated
+        #@@TODO - to be deprecated when RecordGroup is removed from codebase
+        #         (during 1.0 release cycle?)
         # In due course, field groups will replaced by inline field lists.
         # This code does not process field lists for fields referenced by a group.
         #@@
@@ -1053,7 +1065,7 @@ class Collection(Entity):
         """
         rtype = extract_entity_id(fdesc[ANNAL.CURIE.field_render_type])
         vmode = extract_entity_id(fdesc[ANNAL.CURIE.field_value_mode])
-        if vmode in ["Value_entity", "Value_field"]:
+        if vmode == "Value_entity":
             rtype = "Enum"
         elif vmode == "Value_import":
             rtype = "URIImport"
