@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 This module contains (and isolates) logic used to find entities based on entity type,
 list selection criteria and search terms.
@@ -14,6 +17,8 @@ import re
 from pyparsing import Word, QuotedString, Literal, Group, Empty, StringEnd, ParseException
 from pyparsing import alphas, alphanums
 
+from utils.py3porting               import is_string, to_unicode
+
 from annalist                       import layout
 from annalist.util                  import valid_id, extract_entity_id
 
@@ -241,9 +246,6 @@ class EntityFinder(object):
                 val = e[key]
                 if cls.value_contains(val, search):
                     return True
-                # if isinstance(val, (str, unicode)):
-                #     if search in val:
-                #         return True
             return False
         return True
 
@@ -261,7 +263,7 @@ class EntityFinder(object):
             for e in val:
                 if cls.value_contains(e, search):
                     return True
-        elif isinstance(val, (str, unicode)):
+        elif is_string(val):
             return search in val
         return False
 
@@ -286,7 +288,7 @@ class EntitySelector(object):
     >>> f7 = "[p:a] in view[v:a]"
     >>> f8 = "[p:b] in view[v:b]"
     >>> f9 = "[p:a] in view[v:b]"
-    >>> f10 = "[annal:field_entity_type] in view[annal:record_type]"
+    >>> f10 = "[annal:field_entity_type] in view[annal:view_entity_type]"
     >>> f11 = "foo:bar in [@type]"
     >>> f12 = "bar:foo in [@type]"
     >>> EntitySelector(f1).select_entity(e, c)
