@@ -9,28 +9,33 @@ Part of the purpose of this module is to abstract the underlying storage access
 from the Annalist organization of presented entities.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
+import logging
+log = logging.getLogger(__name__)
+
 import os
 import os.path
-import urlparse
 import shutil
 import json
 import errno
 
-import logging
-log = logging.getLogger(__name__)
-
 from django.conf import settings
 
+from utils.py3porting       import is_string, urljoin
+
 from annalist               import layout
+from annalist               import message
 from annalist               import util
 from annalist.exceptions    import Annalist_Error
 from annalist.identifiers   import ANNAL, RDF, RDFS
 from annalist.resourcetypes import file_extension, file_extension_for_content_type
-from annalist.util          import make_type_entity_id, make_entity_base_url
+from annalist.util          import valid_id, make_type_entity_id, make_entity_base_url
 
 #   -------------------------------------------------------------------------------------------
 #
@@ -141,7 +146,7 @@ class EntityRoot(object):
         specializations to be created without changing the URI used.
         """
         # log.debug("EntityRoot.get_url: baseurl %s, _entityurl %s"%(baseurl, self._entityurl))
-        return urlparse.urljoin(baseurl, self._entityurl)
+        return urljoin(baseurl, self._entityurl)
 
     def get_view_url(self, baseurl=""):
         """
@@ -155,7 +160,7 @@ class EntityRoot(object):
         location.
         """
         # log.debug("EntityRoot.get_view_url: baseurl %s, _entityurl %s"%(baseurl, self._entityurl))
-        return urlparse.urljoin(baseurl, self._entityviewurl)
+        return urljoin(baseurl, self._entityviewurl)
 
     def get_view_url_path(self, baseurl=""):
         """
@@ -198,15 +203,18 @@ class EntityRoot(object):
         Also used for cache values.
         """
         values = self._values.copy()
+        if self._entityid != layout.INITIAL_VALUES_ID:
+            values = self._pre_save_processing(values)
         values['@id']      = self._entityref
         values['@type']    = self._get_types(values.get('@type', None))
         values['@context'] = (
             [ { '@base': self._contextbase }
             , self._contextref
             ])
-        # @TODO: is this next needed?  Put logic in set_values?
-        if self._entityid:
-            values[ANNAL.CURIE.id] = self._entityid
+        #@@TODO: is this next needed?  Put logic in set_values?
+        # if self._entityid:
+        #     values[ANNAL.CURIE.id] = self._entityid
+        #@@
         values.pop(ANNAL.CURIE.url, None)
         return values
 
@@ -241,7 +249,7 @@ class EntityRoot(object):
         successively to access the corresponding value.
         """
         def is_dict(e):
-            return isinstance(e,dict)
+            return isinstance(e, dict)
         def enum_f(p, d):
             for k in d:
                 if isinstance(d[k], (list, tuple)) and all([is_dict(e) for e in d[k]]):
@@ -254,6 +262,8 @@ class EntityRoot(object):
         if self._values:
             for f in enum_f([], self._values):
                 yield f
+        else:
+            log.error("EntityRoot.enum_fields: no entity values present")
         return
 
     def resource_file(self, resource_ref):
@@ -338,17 +348,17 @@ class EntityRoot(object):
         returns path of of object body, or None
         """
         (d, p, u) = self._dir_path_uri()
-        # log.debug("EntityRoot._exists_path %s"%(p))
+        # log.info("EntityRoot._exists_path %s"%(p))
         if d and os.path.isdir(d):
             if p and os.path.isfile(p):
-                # log.debug("EntityRoot._exists_path %s: OK"%(p))
+                # log.info("EntityRoot._exists_path %s: OK"%(p))
                 return p
             mp = self._migrate_path()
             if mp and os.path.isfile(mp):
                 assert mp == p, "EntityRoot._exists_path: Migrated filename %s, expected %s"%(mp, p)
                 # log.info("EntityRoot._exists_path %s: Migrated from %s"%(mp, p))
                 return mp
-        # log.debug("EntityRoot._exists_path %s: not present"%(p))
+        # log.info("EntityRoot._exists_path %s: not present"%(p))
         return None
 
     def _exists(self):
@@ -401,9 +411,9 @@ class EntityRoot(object):
             raise ValueError(msg)
         (body_dir, body_file) = self._dir_path()
         # log.debug("EntityRoot._save: dir %s, file %s"%(body_dir, body_file))
-        fullpath = os.path.join(settings.BASE_DATA_DIR, "annalist_site", body_file)
+        fullpath = os.path.join(settings.BASE_SITE_DIR, body_file)
         # Next is partial protection against code errors
-        if not fullpath.startswith(os.path.join(settings.BASE_DATA_DIR, "annalist_site")):
+        if not fullpath.startswith(settings.BASE_SITE_DIR):
             log.error("EntityRoot._save: Failing to create entity at %s"%(fullpath,))
             log.info("EntityRoot._save: dir %s, file %s"%(body_dir, body_file))
             log.info("EntityRoot._save: settings.BASE_DATA_DIR %s"%(settings.BASE_DATA_DIR,))
@@ -454,11 +464,11 @@ class EntityRoot(object):
                     # log.debug("EntityRoot._load_values: url_path %s"%(self.get_view_url_path()))
                     entitydata[ANNAL.CURIE.url] = self.get_view_url_path()
                     return entitydata
-            except IOError, e:
+            except IOError as e:
                 if e.errno != errno.ENOENT:
                     raise
                 log.error("EntityRoot._load_values: no file %s"%(body_file))
-            except ValueError, e:
+            except ValueError as e:
                 log.error("EntityRoot._load_values: error loading %s"%(body_file))
                 log.error(e)
                 return (
@@ -474,6 +484,10 @@ class EntityRoot(object):
         Returns the values loaded, or None.
         """
         if self._values is None:
+            # log.debug(
+            #     "_ensure_values_loaded: _entitydir %s, _entityfile %s"%
+            #       (self._entitydir, self._entityfile)
+            #     )
             vals = self._load_values()
             if vals:
                 vals = self._migrate_values(vals)
@@ -539,7 +553,8 @@ class EntityRoot(object):
         """
         return entitydata
 
-    def _migrate_values_map_field_names(self, migration_map, entitydata):
+    @classmethod
+    def _migrate_values_map_field_names(cls, migration_map, entitydata):
         """
         Support function to map field names using a supplied map.
 
@@ -555,11 +570,56 @@ class EntityRoot(object):
         # Return result
         return entitydata
 
+    @classmethod
+    def _pre_save_validation(cls, type_id, entity_id, entitydata):
+        """
+        Pre-save value validation.
+
+        This method is called before a value is saved, to validate user-
+        entered data.
+
+        Individual entity classes may provide their own override methods for this
+        (e.g., to perform checks that are specific to a class.  The intent is that
+        this will eventually be used to hook into a user-definable validation
+        framework).
+
+        Returns a list of strings describing any errors detected, or an empty list 
+        if no problems are found.
+        """
+        errs = []
+        if not valid_id(entity_id):
+            log.debug("_pre_save_validation: entity_id not valid ('%s')"%entity_id)
+            errs.append((message.INPUT_VALIDATION_ERROR, message.ENTITY_DATA_ID_INVALID))
+        if not valid_id(type_id):
+            log.debug("_pre_save_validation: type_id not valid_id('%s')"%type_id)
+            errs.append((message.INPUT_VALIDATION_ERROR, message.ENTITY_TYPE_ID_INVALID))
+        return errs
+
+    def _pre_save_processing(self, entitydata):
+        """
+        Pre-save value processing.
+
+        This method is called just before a value is saved to fill in or update
+        any values that were not specified in the form input.
+
+        The specification for this method is that it returns an entitydata value
+        which is a copy of the supplied entitydata with any data updates applied.
+
+        NOTE:  implementations are free to apply updates in-place.  The resulting 
+        entitydata should be exactly as the supplied data *should* appear in storage.
+        The update function should be idempotent; i.e.
+            x._pre_save_processing(x._pre_save_processing(e)) == x._pre_save_processing(e)
+
+        Individual entity classes may provide their own override methods for this
+        (e.g., to fill in values that have not been otherwise specified).
+        """
+        return entitydata
+
     def _post_update_processing(self, entitydata, post_update_flags):
         """
         Default method for post-update processing.
 
-        This method is called when an entity has been ceated or updated.  
+        This method is called just after an entity has been ceated or updated.  
 
         Individual entity classes may provide their own override methods for this.  
         (e.g. to trigger regeneration of context data when groups, views, fields or 
@@ -592,7 +652,7 @@ class EntityRoot(object):
         if os.path.isdir(parent_dir):
             child_files = os.listdir(parent_dir)
         for fil in child_files:
-            if util.valid_id(fil):
+            if util.valid_id(fil, reserved_ok=True):
                 yield fil
         return
 
@@ -762,7 +822,7 @@ class EntityRoot(object):
         Opens a (file-like) stream to read entity data.
 
         Returns the stream object, which implements the context protocol to
-        close the stream on exit from a containign with block; e.g.
+        close the stream on exit from a containing with block; e.g.
 
             with e._read_stream() as f:
                 // read data from f
@@ -775,7 +835,7 @@ class EntityRoot(object):
         if body_file:
             try:
                 f_stream = open(body_file, "rt")
-            except IOError, e:
+            except IOError as e:
                 if e.errno != errno.ENOENT:
                     raise
                 log.error("EntityRoot._read_stream: no file %s"%(body_file))
