@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Gather information about an entity/record type
 """
@@ -26,6 +29,7 @@ from annalist.models.recordview     import RecordView
 from annalist.models.recordgroup    import RecordGroup, RecordGroup_migration
 from annalist.models.recordfield    import RecordField
 from annalist.models.recordvocab    import RecordVocab
+from annalist.models.recordinfo     import RecordInfo
 from annalist.models.recordenum     import RecordEnumFactory
 from annalist.models.recordtypedata import RecordTypeData
 from annalist.models.entitydata     import EntityData
@@ -38,18 +42,19 @@ VIEW_ID     = layout.VIEW_TYPEID
 GROUP_ID    = layout.GROUP_TYPEID
 FIELD_ID    = layout.FIELD_TYPEID
 VOCAB_ID    = layout.VOCAB_TYPEID
+INFO_ID     = layout.INFO_TYPEID
 TASK_ID     = layout.TASK_TYPEID
 
 COLL_MESSAGES = (
-    { 'parent_heading':         "(@@ COLL_MESSAGES.parent_heading - unused message @@)"
-    , 'parent_missing':         "(@@ COLL_MESSAGES.parent_missing - unused message @@)"
+    { 'parent_heading':         "(@@ COLL_MESSAGES.parent_heading @@)"
+    , 'parent_missing':         "(@@ COLL_MESSAGES.parent_missing @@)"
     , 'entity_heading':         message.COLLECTION_ID
     , 'entity_invalid_id':      message.COLLECTION_ID_INVALID
     , 'entity_exists':          message.COLLECTION_EXISTS
     , 'entity_not_exists':      message.COLLECTION_NOT_EXISTS
     , 'entity_removed':         message.COLLECTION_REMOVED
-    , 'entity_type_heading':    "(@@ COLL_MESSAGES.entity_type_heading - unused message @@)"
-    , 'entity_type_invalid':    "(@@ COLL_MESSAGES.entity_type_invalid - unused message @@)"
+    , 'entity_type_heading':    "(@@ COLL_MESSAGES.entity_type_heading @@)"
+    , 'entity_type_invalid':    "(@@ COLL_MESSAGES.entity_type_invalid @@)"
     })
 
 ENTITY_MESSAGES = (
@@ -148,6 +153,18 @@ VOCAB_MESSAGES = (
     , 'entity_type_invalid':    message.ENTITY_TYPE_ID_INVALID
     })
 
+INFO_MESSAGES = (
+    { 'parent_heading':         message.COLLECTION_ID
+    , 'parent_missing':         message.COLLECTION_NOT_EXISTS
+    , 'entity_heading':         message.RECORD_INFO_ID
+    , 'entity_invalid_id':      message.RECORD_INFO_ID_INVALID
+    , 'entity_exists':          message.RECORD_INFO_EXISTS
+    , 'entity_not_exists':      message.RECORD_INFO_NOT_EXISTS
+    , 'entity_removed':         message.RECORD_INFO_REMOVED
+    , 'entity_type_heading':    message.ENTITY_TYPE_ID
+    , 'entity_type_invalid':    message.ENTITY_TYPE_ID_INVALID
+    })
+
 ENUM_MESSAGES = (
     { 'parent_heading':         message.COLLECTION_ID
     , 'parent_missing':         message.COLLECTION_NOT_EXISTS
@@ -184,6 +201,18 @@ ADMIN_PERMISSIONS = (
     , "admin":  "ADMIN"     # Change users or permissions
     })
 
+ADMIN_VIEW_PERMISSIONS = (
+    { "view":   "VIEW"     # View site record
+    , "list":   "VIEW"     # ..
+    , "search": "VIEW"     # ..
+    , "new":    "ADMIN"     # Create site record
+    , "copy":   "ADMIN"     # ..
+    , "edit":   "ADMIN"     # Update site record
+    , "delete": "ADMIN"     # Delete site record
+    , "config": "CONFIG"    # Change collection configuration
+    , "admin":  "ADMIN"     # Change users or permissions
+    })
+
 CONFIG_PERMISSIONS = (
     { "view":   "VIEW"      # View config record
     , "list":   "VIEW"      # ..
@@ -217,6 +246,7 @@ TYPE_CLASS_MAP = (
     , GROUP_ID:                 RecordGroup_migration
     , FIELD_ID:                 RecordField
     , VOCAB_ID:                 RecordVocab
+    , INFO_ID:                  RecordInfo
     , '_enum_field_placement':  RecordEnumFactory('_enum_field_placement',  '_enum_field_placement')
     , '_enum_list_type':        RecordEnumFactory('_enum_list_type',        '_enum_list_type')
     , '_enum_render_type':      RecordEnumFactory('_enum_render_type',      '_enum_render_type')
@@ -233,6 +263,7 @@ TYPE_MESSAGE_MAP = (
     , GROUP_ID:                 GROUP_MESSAGES
     , FIELD_ID:                 FIELD_MESSAGES
     , VOCAB_ID:                 VOCAB_MESSAGES
+    , INFO_ID:                  INFO_MESSAGES
     , '_enum_field_placement':  ENUM_MESSAGES  
     , '_enum_list_type':        ENUM_MESSAGES
     , '_enum_render_type':      ENUM_MESSAGES
@@ -249,6 +280,7 @@ SITE_PERMISSIONS_MAP = (
     , GROUP_ID:                 SITE_PERMISSIONS
     , FIELD_ID:                 SITE_PERMISSIONS
     , VOCAB_ID:                 SITE_PERMISSIONS
+    , INFO_ID:                  ADMIN_VIEW_PERMISSIONS
     , '_enum_field_placement':  SITE_PERMISSIONS  
     , '_enum_list_type':        SITE_PERMISSIONS
     , '_enum_render_type':      SITE_PERMISSIONS
@@ -266,6 +298,7 @@ TYPE_PERMISSIONS_MAP = (
     , GROUP_ID:                 CONFIG_PERMISSIONS
     , FIELD_ID:                 CONFIG_PERMISSIONS
     , VOCAB_ID:                 CONFIG_PERMISSIONS
+    , INFO_ID:                  CONFIG_PERMISSIONS
     , '_enum_field_placement':  SITE_PERMISSIONS  
     , '_enum_list_type':        SITE_PERMISSIONS
     , '_enum_render_type':      SITE_PERMISSIONS
@@ -278,7 +311,7 @@ def get_built_in_type_ids():
     """
     Returns an interator over the built-in types
     """
-    return TYPE_CLASS_MAP.iterkeys()
+    return iter(TYPE_CLASS_MAP)
 
 class EntityTypeInfo(object):
     """
@@ -355,10 +388,7 @@ class EntityTypeInfo(object):
             else:
                 # log.info("@@ EntityTypeInfo: Type %s does not exist for collection %s"%(type_id,coll.get_id()))
                 pass
-            if create_typedata and not RecordTypeData.exists(coll, type_id):
-                self.entityparent   = RecordTypeData.create(coll, type_id, {})
-            else:
-                self.entityparent   = RecordTypeData(coll, type_id)
+            self.parent_typedata(create_typedata=create_typedata)
             self.entityaltparent = None
             self.entityclass     = EntityData
             self.entitymessages  = ENTITY_MESSAGES
@@ -403,6 +433,49 @@ class EntityTypeInfo(object):
             type_uris = [type_uri] + list(self.entitycoll.cache_get_supertype_uris(type_uri))
         return type_uris
 
+    def set_type_uris(self, entity_values):
+        """
+        Set URIs of current type in supplied entity values
+
+        Previous type URIs are overridden.
+        """
+        entity_values[ANNAL.CURIE.type] = self.get_type_uri()
+        entity_values['@type']          = self.get_all_type_uris()
+        return
+
+    def make_entity_uri(self, entity_id):
+        """
+        Return a candidate entity URI for an instance of the current type,
+        based on a namespace prefix declared in the type definition.
+
+        Returns None if no entity namespace prefix is declared for the type.
+        """
+        if ANNAL.CURIE.ns_prefix in self.recordtype:
+            ns_pref = self.recordtype[ANNAL.CURIE.ns_prefix]
+            if ns_pref != "":
+                if not valid_id(ns_pref):
+                    raise ValueError(
+                        "EntityTypeInfo invalid ns_prefix %s for type %s"%
+                          (ns_pref, self.type_id)
+                        )
+                return ns_pref + ":" + entity_id
+        return None
+
+    def set_entity_uri(self, entity_id, entity_values):
+        """
+        Update entity URI in supplied entity values, if value is not already set.
+
+        If current value is blank or same as URL then that value is discarded.
+        """
+        if ANNAL.CURIE.uri in entity_values:
+            if entity_values[ANNAL.CURIE.uri] in {"", entity_values.get(ANNAL.CURIE.url, "")}:
+                entity_values.pop(ANNAL.CURIE.uri)
+        if ANNAL.CURIE.uri not in entity_values:
+            entity_uri = self.make_entity_uri(entity_id)
+            if entity_uri:
+                entity_values[ANNAL.CURIE.uri] = entity_uri
+        return
+
     def get_default_view_id(self):
         """
         Returns the default view id for the current record type
@@ -414,6 +487,17 @@ class EntityTypeInfo(object):
             log.warning("EntityTypeInfo.get_default_view_id: no type data for %s"%(self.type_id))
         return view_id or "Default_view"
 
+    def validate(self, entity_id, entity_values):
+        """
+        Validates the entity values provided.
+
+        (Invokes type-specific validation method)
+
+        Returns a list of strings describing any errors detected, or an empty list 
+        if no problems are found.
+        """
+        return self.entityclass._pre_save_validation(self.type_id, entity_id, entity_values)
+
     # Entity-specific methods
 
     def get_entity_permissions_map(self, entity_id=None):
@@ -455,7 +539,21 @@ class EntityTypeInfo(object):
         """
         Test for existence of parent entity for the current type.
         """
-        return self.entityparent._exists()
+        return self.entityparent and self.entityparent._exists()
+
+    def parent_typedata(self, create_typedata=False):
+        """
+        Get or create reference to parent RecordTypeData entity.
+
+        Optionally, create actual RecordTypeData entity if it does not exist.
+        """
+        if create_typedata and not self.parent_exists():
+            # Only RecordTypeData entities are created dynamically:
+            # others (site, coll) must already exist.
+            self.entityparent = RecordTypeData.create(self.entitycoll, self.type_id, {})
+        elif not self.entityparent:
+            self.entityparent = RecordTypeData(self.entitycoll, self.type_id)
+        return self.entityparent
 
     def entity_exists(self, entity_id, altscope=None):
         """
@@ -470,11 +568,8 @@ class EntityTypeInfo(object):
         log.debug("create_entity: id %s, parent id %s"%(entity_id, self.entityparent.get_id()))
         # log.debug("create_entity: values %r"%(entity_values,))
         # Set type URI for entity; previous types are not carried forwards
-        # Don't save entity URI if same as URL
-        if entity_values.get(ANNAL.CURIE.uri, "") == entity_values.get(ANNAL.CURIE.url, ""):
-            entity_values.pop(ANNAL.CURIE.uri, None)
-        entity_values['@type']          = self.get_all_type_uris() # NOTE: previous types not carried forward
-        entity_values[ANNAL.CURIE.type] = self.get_type_uri()
+        self.set_type_uris(entity_values)
+        self.set_entity_uri(entity_id, entity_values)
         return self.entityclass.create(self.entityparent, entity_id, entity_values)
 
     def remove_entity(self, entity_id):
@@ -502,15 +597,13 @@ class EntityTypeInfo(object):
         #     )
         entity = None
         entity_id = extract_entity_id(entity_id)
-        if valid_id(entity_id):
+        if valid_id(entity_id, reserved_ok=True):
             if action == "new":
                 entity = self._new_entity(entity_id)
                 entity_initial_values = self.get_initial_entity_values(entity_id)
                 entity.set_values(entity_initial_values)
             elif self.entityclass.exists(self.entityparent, entity_id, altscope="all"):
-                entity = self.entityclass.load(
-                    self.entityparent, entity_id, altscope="all"
-                    )
+                entity = self.entityclass.load(self.entityparent, entity_id, altscope="all")
             else:
                 log.debug(
                     "EntityTypeInfo.get_entity %s/%s at %s not found"%
