@@ -2,20 +2,23 @@
 Annalist vocabulary record
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2015, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import os
-import os.path
-import urlparse
-import shutil
-
 import logging
 log = logging.getLogger(__name__)
 
+import os
+import os.path
+import shutil
+
 from django.conf import settings
 
+from annalist                   import message
 from annalist                   import layout
 from annalist.exceptions        import Annalist_Error
 from annalist.identifiers       import ANNAL, RDFS, OWL
@@ -43,6 +46,25 @@ class RecordVocab(EntityData):
         # log.debug("RecordVocab %s: dir %s"%(vocab_id, self._entitydir))
         return
 
+    @classmethod
+    def _pre_save_validation(cls, type_id, entity_id, entitydata):
+        """
+        Pre-save value validation.
+
+        Override EntityRoot method
+
+        Returns a list of strings describing any errors detected, or an empty list 
+        if no problems are found.
+        """
+        errs = super(RecordVocab, cls)._pre_save_validation(type_id, entity_id, entitydata)
+        if ANNAL.CURIE.uri in entitydata:
+            vuri = entitydata[ANNAL.CURIE.uri]
+            if vuri[-1] not in {":", "/", "?", "#"}:
+                msg = message.RECORD_VOCAB_URI_TERM%({"id": entity_id, "uri": vuri})
+                log.info(msg)
+                errs.append(msg)
+        return errs
+
     def _migrate_filenames(self):
         """
         Override EntityData method
