@@ -2,20 +2,23 @@
 Utility functions to support entity data testing
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import os
-import urlparse
-
 import logging
 log = logging.getLogger(__name__)
 
+import os
+
 from django.conf                import settings
 from django.http                import QueryDict
-from django.utils.http          import urlquote, urlunquote
-from django.core.urlresolvers   import resolve, reverse
+from django.urls                import resolve, reverse
+
+from utils.py3porting           import urljoin
 
 from annalist.util              import valid_id, extract_entity_id
 from annalist.identifiers       import RDF, RDFS, ANNAL
@@ -28,7 +31,10 @@ from annalist.views.fields.render_placement import (
     get_placement_classes
     )
 
-from entity_testutils import (
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .entity_testutils import (
     collection_dir, 
     entitydata_list_url_query,
     site_view_url,
@@ -38,9 +44,19 @@ from entity_testutils import (
     site_title,
     context_field_row
     )
-from tests import (
-    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-    )
+from .entity_testfielddesc      import get_field_description, get_bound_field
+
+#   -----------------------------------------------------------------------------
+#
+#   Helper functions
+#
+#   -----------------------------------------------------------------------------
+
+def value_or_default(value, default):
+    """
+    Returns the supplied value of it is non None, otherwise the supplied default.
+    """
+    return value if value is not None else default
 
 #   -----------------------------------------------------------------------------
 #
@@ -66,13 +82,23 @@ def entitydata_dir(coll_id="testcoll", type_id="testtype", entity_id="testentity
 #   These all use the Django `reverse` function so they correspond to
 #   the declared URI patterns.
 
+def entity_uriref(coll_id="testcoll", type_id="testtype", entity_id="entity_id"):
+    """
+    URI for entity data with trailing slash removed.  Used as entity idemntifier in data.
+    """
+    uri = entity_url(coll_id=coll_id, type_id=type_id, entity_id=entity_id)
+    if uri.endswith("/"):
+        uri = uri[0:-1] # Strip traling "/"  
+    return uri
+
 def entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity_id"):
     """
     URI for entity data; also view using default entity view
     """
     if not valid_id(entity_id):
         entity_id = "___"
-    return collection_entity_view_url(coll_id=coll_id, type_id=type_id, entity_id=entity_id)
+    url = collection_entity_view_url(coll_id=coll_id, type_id=type_id, entity_id=entity_id)
+    return url
 
 def entity_resource_url(
     coll_id="testcoll", type_id="testtype", entity_id="entity_id", 
@@ -82,17 +108,20 @@ def entity_resource_url(
     URI for entity resource data
     """
     base = entity_url(coll_id, type_id, entity_id)
-    return urlparse.urljoin(base, resource_ref)
+    return urljoin(base, resource_ref)
 
-def entitydata_edit_url(action=None, coll_id="testcoll", type_id=None, entity_id=None, view_id="Default_view"):
+def entitydata_edit_url(action=None, coll_id="testcoll", type_id=None, entity_id=None, view_id=None):
     viewname = ( 
         'AnnalistEntityNewView'             if action == "new" else
-        'AnnalistEntityEditView'            if action is not None else
-        'AnnalistEntityDataView'
+        'AnnalistEntityEditView'            if action and view_id else
+        'AnnalistEntityDataView'            if            view_id else
+        'AnnalistEntityDefaultDataView'
         )
-    kwargs = {'coll_id': coll_id, 'view_id': view_id}
+    kwargs = {'coll_id': coll_id}
     if action:
         kwargs.update({'action': action})
+    if view_id:
+        kwargs.update({'view_id': view_id})
     if type_id:
         kwargs.update({'type_id': type_id})
     if entity_id:
@@ -232,13 +261,12 @@ def entitydata_values(
         type_uri=None, supertype_uris=None, 
         hosturi=TestHostUri
         ):
-    # type_uri = entity_url(coll_id, "_type", type_id)
     dataurl = entity_url(coll_id, type_id, entity_id)
     d = entitydata_create_values(
         entity_id, update=update, coll_id=coll_id, type_id=type_id, 
         entity_uri=entity_uri, type_uri=type_uri, supertype_uris=supertype_uris,
         hosturi=hosturi
-        ).copy() #@@ copy needed here?
+        )
     d.update(
         { '@id':            "%s/%s"%(type_id, entity_id)
         , '@context':       [{"@base": "../../"}, "../../coll_context.jsonld"]
@@ -249,75 +277,154 @@ def entitydata_values(
     # log.info("entitydata_values %r"%(d,))
     return d
 
-def entitydata_context_data(
-        entity_id=None, orig_id=None, coll_id="testcoll", type_id="testtype", type_ids=[],
-        action=None, update="Entity", view_label="Default record view"
+#   -----------------------------------------------------------------------------
+#
+#   ----- Entity in specified view context data
+#
+#   -----------------------------------------------------------------------------
+
+def specified_view_context_data(
+        coll_id="testcoll", type_id="testtype", 
+        view_id="Default_view", view_heading="Default record view",
+        entity_id=None, orig_id=None,
+        type_ref=None, type_choices=None, type_ids=[],
+        entity_label=None, entity_descr=None, 
+        record_type="annal:EntityData",
+        view_fields=None,
+        update="Entity",
+        action=None, 
+        continuation_url=None
     ):
+    """
+    Returns view context test data for entity presented using specified view
+    """
     if entity_id:
-        entity_label = '%s %s/%s/%s'%(update, coll_id, type_id, entity_id)
-        entity_descr = '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
+        entity_label = value_or_default(entity_label,
+            '%s (%s/%s/%s)'%(update, coll_id, type_id, entity_id)
+            )
+        entity_descr = value_or_default(entity_descr,
+            '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
+            )
     else:
-        entity_label = '%s data ... (%s/%s)'%(update, coll_id, type_id)
-        entity_descr = '%s description ... (%s/%s)'%(update, coll_id, type_id)
+        entity_label = value_or_default(entity_label,
+            '%s (%s/%s/)'%(update, coll_id, type_id)
+            )
+        entity_descr = value_or_default(entity_descr,
+            '%s coll %s, type %s, no entity id'%(update, coll_id, type_id)
+            )
+    continuation_url = value_or_default(continuation_url, 
+        entitydata_list_type_url(coll_id, type_id)
+        )
+    view_title = (
+        "%s - %s - Collection %s"%(entity_label, view_heading, coll_id) if entity_label
+        else
+        "%s - Collection %s"%(view_heading, coll_id)
+        )
+    if view_fields is None:
+        view_fields = (
+            [ context_field_row(
+                get_bound_field("Entity_id", entity_id),                          # 0 (0,0)
+                get_bound_field("Entity_type", type_ref, options=type_choices)    # 1 (0,1)
+                )
+            , context_field_row(
+                get_bound_field("Entity_label", entity_label)                     # 2 (1,0)
+                )
+            , context_field_row(
+                get_bound_field("Entity_comment", entity_descr)                   # 3 (2,0)
+                )
+            ])
     context_dict = (
-        { 'title':              "%s - %s - Collection %s"%(entity_label, view_label, coll_id)
-        , 'heading':            view_label
-        , 'coll_id':            'testcoll'
-        , 'type_id':            'testtype'
-        , 'orig_id':            'orig_entity_id'
-        , 'fields':
-          [ context_field_row(
-              { 'field_label':        'Id'
-              , 'field_id':           'Entity_id'
-              , 'field_name':         'entity_id'
-              , 'field_render_type':  'EntityId'
-              , 'field_placement':    get_placement_classes('small:0,12;medium:0,6')
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   "annal:EntityRef"
-              # , 'field_value':      (Supplied separately)
-              , 'options':            []
-              },
-              { 'field_label':        'Type'
-              , 'field_id':           'Entity_type'
-              , 'field_name':         'entity_type'
-              , 'field_render_type':  'EntityTypeId'
-              , 'field_value_type':   "annal:EntityRef"
-              , 'field_placement':    get_placement_classes('small:0,12;medium:6,6')
-              , 'field_value_mode':   'Value_direct'
-              # , 'field_value':      (Supplied separately)
-              , 'options':            []
-              })
-          , context_field_row(
-              { 'field_label':        'Label'
-              , 'field_id':           'Entity_label'
-              , 'field_name':         'Entity_label'
-              , 'field_render_type':  'Text'
-              , 'field_placement':    get_placement_classes('small:0,12')
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   "annal:Text"
-              , 'field_value':        entity_label
-              , 'options':            []
-              })
-          , context_field_row(
-              { 'field_label':        'Comment'
-              , 'field_id':           'Entity_comment'
-              , 'field_name':         'Entity_comment'
-              , 'field_render_type':  'Markdown'
-              , 'field_placement':    get_placement_classes('small:0,12')
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   "annal:Richtext"
-              , 'field_value':        entity_descr
-              , 'options':            []
-              })
-          ]
-        , 'continuation_url':   entitydata_list_type_url("testcoll", type_id)
+        { 'title':              view_title
+        , 'heading':            view_heading
+        , 'coll_id':            coll_id
+        , 'type_id':            type_id
+        , 'view_id':            view_id
+        , 'entity_id':          entity_id
+        , 'orig_type':          type_id
+        , 'record_type':        record_type
+        , 'fields':             view_fields
+        , 'continuation_url':   continuation_url
         })
-    if entity_id:
-        context_dict['fields'][0]['row_field_descs'][0]['field_value'] = entity_id
-        context_dict['fields'][0]['row_field_descs'][1]['field_value'] = "_type/"+type_id if valid_id(type_id) else None
+    if orig_id is not None:
+        context_dict['orig_id']     = orig_id
+    elif entity_id and action != "new":
         context_dict['orig_id']     = entity_id
+    if action:  
+        context_dict['action']      = action
+    return context_dict
+
+#   -----------------------------------------------------------------------------
+#
+#   ----- Entity data in Default_view
+#
+#   -----------------------------------------------------------------------------
+
+def default_view_context_data(
+        entity_id=None, orig_id=None, 
+        coll_id="testcoll", type_id="testtype", 
+        type_ref=None, type_choices=None, type_ids=[],
+        entity_label=None, entity_descr=None,
+        view_label="Default record view",
+        record_type="annal:EntityData",
+        update="Entity",
+        action=None, 
+        continuation_url=None
+    ):
+    """
+    Returns view context test data for entity presented using default view
+    """
+    if entity_id:
+        type_ref = value_or_default(type_ref,
+            "_type/"+type_id if valid_id(type_id) else None
+            )
+        entity_label = value_or_default(entity_label,
+            '%s %s/%s/%s'%(update, coll_id, type_id, entity_id)
+            )
+        entity_descr = value_or_default(entity_descr,
+            '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
+            )
+    else:
+        type_ref     = type_ref or ""
+        entity_label = value_or_default(entity_label,
+            '%s data ... (%s/%s)'%(update, coll_id, type_id)
+            )
+        entity_descr = value_or_default(entity_descr,
+            '%s description ... (%s/%s)'%(update, coll_id, type_id)
+            )
+    continuation_url = value_or_default(continuation_url, 
+        entitydata_list_type_url("testcoll", type_id)
+        )
+    view_title = (
+        "%s - %s - Collection %s"%(entity_label, view_label, coll_id) if entity_label
+        else
+        "%s - Collection %s"%(view_label, coll_id)
+        )
+    view_fields = (
+        [ context_field_row(
+            get_bound_field("Entity_id", entity_id),                          # 0 (0,0)
+            get_bound_field("Entity_type", type_ref, options=type_choices)    # 1 (0,1)
+            )
+        , context_field_row(
+            get_bound_field("Entity_label", entity_label)                     # 2 (1,0)
+            )
+        , context_field_row(
+            get_bound_field("Entity_comment", entity_descr)                   # 3 (2,0)
+            )
+        ])
+    context_dict = (
+        { 'title':              view_title
+        , 'heading':            view_label
+        , 'coll_id':            coll_id
+        , 'type_id':            type_id
+        , 'orig_id':            orig_id
+        , 'record_type':        record_type
+        , 'fields':             view_fields
+        , 'continuation_url':   continuation_url
+        })
     if orig_id:
         context_dict['orig_id']     = orig_id
+    elif entity_id and action != "new":
+        context_dict['orig_id']     = entity_id
     if action:  
         context_dict['action']      = action
     return context_dict
@@ -339,6 +446,7 @@ def entitydata_context_add_field(
 
     Updates and returns supplied context dictionary.
     """
+    #@@TODO: use field context from  entity_testfielddesc
     field_ids = [ f['field_id'] for f in context_dict['fields'] ]
     if field_id in field_ids:
         suffix = "__%d"%dup_index
@@ -357,91 +465,7 @@ def entitydata_context_add_field(
         })
     return context_dict
 
-def entitydata_form_data(
-        entity_id="", orig_id=None, 
-        type_id="testtype", orig_type=None,
-        coll_id="testcoll", orig_coll=None,
-        action=None, cancel=None, close=None, edit=None, copy=None, 
-        update="Entity"
-        ):
-    form_data_dict = (
-        { 'Entity_label':       '%s data ... (%s/%s)'%(update, coll_id, type_id)
-        , 'Entity_comment':     '%s description ... (%s/%s)'%(update, coll_id, type_id)
-        , 'orig_id':            'orig_entity_id'
-        , 'continuation_url':   entitydata_list_type_url(coll_id, orig_type or type_id)
-        })
-    if entity_id is not None:
-        form_data_dict['entity_id']         = entity_id
-    if entity_id:
-        form_data_dict['entity_id']         = entity_id
-        form_data_dict['entity_type']       = "_type/"+type_id
-        form_data_dict['Entity_label']      = '%s %s/%s/%s'%(update, coll_id, type_id, entity_id)
-        form_data_dict['Entity_comment']    = '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
-        form_data_dict['orig_id']           = entity_id
-        form_data_dict['orig_type']         = type_id
-        form_data_dict['orig_coll']         = coll_id
-    if orig_id:
-        form_data_dict['orig_id']           = orig_id
-    if orig_type:
-        form_data_dict['orig_type']         = orig_type
-    if orig_coll:
-        form_data_dict['orig_coll']         = orig_coll
-    if action:
-        form_data_dict['action']            = action
-    if cancel:
-        form_data_dict['cancel']            = "Cancel"
-    elif close:
-        form_data_dict['close']             = "Close"
-    elif edit:
-        form_data_dict['edit']              = "Edit"
-    elif copy:
-        form_data_dict['copy']              = "Copy"
-    else:
-        form_data_dict['save']              = 'Save'
-    return form_data_dict
-
-def entitydata_form_add_field(form_data_dict, field_name, dup_index, value):
-    """
-    Add field value to form data; if duplicate then reformat appropriately.
-
-    Updates and returns supplied form data dictionary.
-    """
-    if field_name in form_data_dict:
-        suffix = "__%d"%dup_index
-    else:
-        suffix = ""
-    form_data_dict[field_name+suffix] = value
-    return form_data_dict
-
-def entitydata_delete_form_data(entity_id=None, type_id="Default_type", list_id="Default_list"):
-    return (
-        { 'list_choice':        "_list/"+list_id
-        , 'continuation_url':   ""
-        , 'search_for':         ""
-        , 'entity_select':      ["%s/%s"%(type_id, entity_id)]
-        , 'delete':             "Delete"
-        })
-
-def entitydata_delete_confirm_form_data(entity_id=None, search=None):
-    """
-    Form data from entity deletion confirmation
-    """
-    form_data = (
-        { 'entity_id':     entity_id,
-          'entity_delete': 'Delete'
-        })
-    if search:
-        form_data['search'] = search
-    return form_data
-
-
-#   -----------------------------------------------------------------------------
-#
-#   ----- Entity data in Default_view
-#
-#   -----------------------------------------------------------------------------
-
-def entitydata_default_view_form_data(
+def default_view_form_data(
         coll_id="testcoll", orig_coll=None,
         type_id="testtype", orig_type=None,
         entity_id=None, orig_id=None, 
@@ -451,15 +475,17 @@ def entitydata_default_view_form_data(
         new_view=None, new_field=None, new_type=None, 
         new_enum=None, do_import=None
         ):
-    # log.info("entitydata_default_view_form_data: entity_id %s"%(entity_id))
+    # log.info("default_view_form_data: entity_id %s"%(entity_id))
     form_data_dict = (
         { 'Entity_label':       '%s data ... (%s/%s)'%(update, coll_id, type_id)
         , 'Entity_comment':     '%s description ... (%s/%s)'%(update, coll_id, type_id)
         , 'orig_id':            'orig_entity_id'
         , 'continuation_url':   entitydata_list_type_url(coll_id, orig_type or type_id)
         })
-    if entity_id:
+    if entity_id is not None:
+        # Allow setting to blank string...
         form_data_dict['entity_id']       = entity_id
+    if entity_id:
         form_data_dict['entity_type']     = "_type/"+type_id
         form_data_dict['Entity_label']    = '%s %s/%s/%s'%(update, coll_id, type_id, entity_id)
         form_data_dict['Entity_comment']  = '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
@@ -505,133 +531,40 @@ def entitydata_default_view_form_data(
         form_data_dict['save']            = 'Save'
     return form_data_dict
 
-#   -----------------------------------------------------------------------------
-#
-#   ----- Entity data in Type_view
-#
-#   -----------------------------------------------------------------------------
+def entitydata_form_add_field(form_data_dict, field_name, dup_index, value):
+    """
+    Add field value to form data; if duplicate then reformat appropriately.
 
-# Used in test_entitygenericedit - move?
-
-def entitydata_recordtype_view_context_data(
-        entity_id=None, orig_id=None, coll_id="testcoll", type_id="testtype", type_uri=None, type_ids=[],
-        action=None, update="Entity", view_label="Type definition"
-    ):
-    if entity_id:
-        entity_label = '%s %s/%s/%s'%(update, coll_id, type_id, entity_id)
-        entity_descr = '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, entity_id)
+    Updates and returns supplied form data dictionary.
+    """
+    if field_name in form_data_dict:
+        suffix = "__%d"%dup_index
     else:
-        entity_label = '%s data ... (%s/%s)'%(update, coll_id, type_id)
-        entity_descr = '%s description ... (%s/%s)'%(update, coll_id, type_id)
-    context_dict = (
-        { 'title':              "%s - %s - Collection %s"%(entity_label, view_label, coll_id)
-        , 'heading':            view_label
-        , 'coll_id':            coll_id
-        , 'type_id':            type_id
-        , 'orig_id':            'orig_entity_id'
-        , 'fields':
-          [ context_field_row(
-              { 'field_label':        'Type Id'
-              , 'field_name':         'entity_id'
-              , 'field_placement':    get_placement_classes('small:0,12;medium:0,6')
-              , 'field_id':           'Type_id'
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   'annal:EntityRef'
-              # , 'field_value':      (Supplied separately)
-              , 'options':            []
-              })
-          , context_field_row(
-              { 'field_label':        'Label'
-              , 'field_name':         'Type_label'
-              , 'field_placement':    get_placement_classes('small:0,12')
-              , 'field_id':           'Type_label'
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   'annal:Text'
-              , 'field_value':        entity_label
-              , 'options':            []
-              })
-          , context_field_row(
-              { 'field_label':        'Comment'
-              , 'field_name':         'Type_comment'
-              , 'field_placement':    get_placement_classes('small:0,12')
-              , 'field_id':           'Type_comment'
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   'annal:Richtext'
-              , 'field_value':        entity_descr
-              , 'options':            []
-              })
-          , context_field_row(
-              { 'field_label':        'Type URI'
-              , 'field_name':         'Type_uri'
-              , 'field_placement':    get_placement_classes('small:0,12')
-              , 'field_id':           'Type_uri'
-              , 'field_value_mode':   'Value_direct'
-              , 'field_value_type':   'annal:Identifier'
-              , 'field_value':        ""
-              , 'options':            []
-              })
-          ]
-        , 'continuation_url':   entitydata_list_type_url(coll_id, type_id)
-        })
-    if entity_id:
-        context_dict['fields'][0]['row_field_descs'][0]['field_value'] = entity_id
-        context_dict['orig_id']                  = entity_id
-    if type_uri:
-        context_dict['fields'][3]['row_field_descs'][0]['field_value'] = type_uri
-    if orig_id:
-        context_dict['orig_id']     = orig_id
-    if action:  
-        context_dict['action']      = action
-    return context_dict
-
-def entitydata_recordtype_view_form_data(
-        coll_id="testcoll", 
-        type_id="testtype", orig_type=None, type_uri=None,
-        entity_id="", orig_id=None, 
-        action=None, cancel=None, update="Entity",
-        add_view_field=None, open_view=None, customize=None):
-    # log.info("entitydata_recordtype_view_form_data: entity_id %s"%(entity_id))
-    form_data_dict = (
-        { 'Type_label':         '%s data ... (%s/%s)'%(update, coll_id, type_id)
-        , 'Type_comment':       '%s description ... (%s/%s)'%(update, coll_id, type_id)
-        , 'orig_id':            'orig_entity_id'
-        , 'continuation_url':   entitydata_list_type_url(coll_id, orig_type or type_id)
-        })
-    if entity_id is not None:
-        form_data_dict['entity_id']       = entity_id
-    if entity_id and type_id:
-        type_url = entity_url(coll_id=coll_id, type_id=type_id, entity_id=entity_id)
-        type_url = type_url.replace("___", entity_id)  # Preserve bad type in form data
-        form_data_dict['entity_id']       = entity_id
-        form_data_dict['Type_uri']        = "" # type_url
-        form_data_dict['orig_id']         = entity_id
-    if orig_id:
-        form_data_dict['orig_id']         = orig_id
-    label_id = entity_id or orig_id
-    if label_id and type_id:
-        form_data_dict['Type_label']      = '%s %s/%s/%s'%(update, coll_id, type_id, label_id)
-        form_data_dict['Type_comment']    = '%s coll %s, type %s, entity %s'%(update, coll_id, type_id, label_id)
-    if type_id:
-        form_data_dict['entity_type']     = "_type/"+type_id
-        form_data_dict['orig_type']       = extract_entity_id(type_id)
-    if type_uri:
-        form_data_dict['Type_uri']        = type_uri
-    if orig_type:
-        form_data_dict['orig_type']       = orig_type
-    if action:
-        form_data_dict['action']          = action
-    if cancel:
-        form_data_dict['cancel']          = "Cancel"
-    elif add_view_field:
-        form_data_dict['add_view_field']  = add_view_field
-    elif open_view:
-        form_data_dict['open_view']       = open_view
-    elif customize:
-        form_data_dict['customize']       = customize
-    else:
-        form_data_dict['save']            = 'Save'
+        suffix = ""
+    form_data_dict[field_name+suffix] = value
     return form_data_dict
 
+def entitydata_delete_form_data(entity_id=None, type_id="Default_type", list_id="Default_list"):
+    return (
+        { 'list_choice':        "_list/"+list_id
+        , 'continuation_url':   ""
+        , 'search_for':         ""
+        , 'entity_select':      ["%s/%s"%(type_id, entity_id)]
+        , 'delete':             "Delete"
+        })
+
+def entitydata_delete_confirm_form_data(entity_id=None, search=None):
+    """
+    Form data from entity deletion confirmation
+    """
+    form_data = (
+        { 'entity_id':     entity_id,
+          'entity_delete': 'Delete'
+        })
+    if search:
+        form_data['search'] = search
+    return form_data
+
 #   -----------------------------------------------------------------------------
 #
 #   ----- Entity list
@@ -644,21 +577,6 @@ def entitylist_form_data(
         continuation_url=None):
     """
     Form data from entity list form submission
-
-    list_form_data = (
-        { 'search_for':         ""
-        , 'search':             "Find"
-        , 'list_choice':        "_list/Default_list"
-        , 'list_view':          "View"
-        , 'entity_select':      ["{{entity.entity_id}}"]
-        , 'new':                "New"
-        , 'copy':               "Copy"
-        , 'edit':               "Edit"
-        , 'delete':             "Delete"
-        , 'default_view':       "Set default"
-        , 'customize':          "Customize"
-        , 'continuation_url':   "{{continuation_url}}"
-        })
     """
     form_actions = (
         { 'search':             "Find"
@@ -740,10 +658,6 @@ def default_comment(coll_id=None, type_id=None, entity_id=None):
     # Note: for built-in types, default values matches corresponding sitedata _initial_values
     if type_id in ["_type", "_view", "_list", "_field"]:
         return ""
-    #@@
-    # if type_id == "_field":
-    #     return "(tooltip text here)"
-    #@@
     return message.ENTITY_DEFAULT_COMMENT%dict(coll_id=coll_id, type_id=type_id, entity_id=entity_id)
 
 def error_label(coll_id=None, type_id=None, entity_id=None):
