@@ -6,22 +6,23 @@ Test cases should use values returned by this module so that additions to
 the site data can be updated here, in just one place.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import os
-import urlparse
-
 import logging
 log = logging.getLogger(__name__)
 
+import os
+
 from annalist                               import layout
 from annalist.util                          import valid_id, split_type_entity_id
-
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from entity_testentitydata                  import entity_url
+from .entity_testentitydata import entity_url
 
 #   -----------------------------------------------------------------------------
 #
@@ -54,19 +55,20 @@ def add_link_to_field_choice(fc, coll_id, default_type_id=None):
 
 site_types = (
     [ FieldChoice("_type/_initial_values")
-    , FieldChoice("_type/_coll",                label="Collection"        )
-    , FieldChoice("_type/_enum_list_type",      label="List display type" )
-    , FieldChoice("_type/_enum_render_type",    label="Field render type" )
-    , FieldChoice("_type/_enum_value_mode",     label="Field value mode"  )
-    , FieldChoice("_type/_enum_value_type",     label="Field value type"  )
-    , FieldChoice("_type/_field",               label="Field"             )
-    , FieldChoice("_type/_group",               label="Field group"       )
-    , FieldChoice("_type/_list",                label="List"              )
-    , FieldChoice("_type/_type",                label="Type"              )
-    , FieldChoice("_type/_user",                label="User permissions"  )
-    , FieldChoice("_type/_view",                label="View"              )
-    , FieldChoice("_type/_vocab",               label="Namespace"         )
-    , FieldChoice("_type/Default_type",         label="Default record"    )
+    , FieldChoice("_type/_coll",                label="Collection"          )
+    , FieldChoice("_type/_enum_list_type",      label="List display type"   )
+    , FieldChoice("_type/_enum_render_type",    label="Field render type"   )
+    , FieldChoice("_type/_enum_value_mode",     label="Field value mode"    )
+    , FieldChoice("_type/_enum_value_type",     label="Field value type"    )
+    , FieldChoice("_type/_field",               label="Field"               )
+    , FieldChoice("_type/_group",               label="Field group"         )
+    , FieldChoice("_type/_info",                label="General information" )
+    , FieldChoice("_type/_list",                label="List"                )
+    , FieldChoice("_type/_type",                label="Type"                )
+    , FieldChoice("_type/_user",                label="User permissions"    )
+    , FieldChoice("_type/_view",                label="View"                )
+    , FieldChoice("_type/_vocab",               label="Namespace"           )
+    , FieldChoice("_type/Default_type",         label="Default record"      )
     ])
 
 def get_site_types_sorted():
@@ -131,6 +133,7 @@ site_lists = (
     , FieldChoice("_list/Enum_list_all",              label="List enumeration values and types")
     , FieldChoice("_list/Field_group_list",           label="Field groups")
     , FieldChoice("_list/Field_list",                 label="Field definitions")
+    , FieldChoice("_list/Info_list",                  label="General information")
     , FieldChoice("_list/List_list",                  label="List definitions")
     , FieldChoice("_list/Type_list",                  label="Entity types")
     , FieldChoice("_list/User_list",                  label="User permissions")
@@ -218,6 +221,7 @@ site_views = (
     , FieldChoice("_view/Enum_view",        label="Enumerated value view"  )
     , FieldChoice("_view/Field_group_view", label="Field group definition" )
     , FieldChoice("_view/Field_view",       label="Field definition"       )
+    , FieldChoice("_view/Info_view",        label="General information"    )
     , FieldChoice("_view/List_view",        label="List definition"        )
     , FieldChoice("_view/Type_view",        label="Type definition"        )
     , FieldChoice("_view/User_view",        label="User permissions"       )
@@ -256,8 +260,6 @@ def get_site_bib_views_linked(coll_id):
 def get_site_bib_views():
     return set( ( id_from_field_choice(fc) for fc in get_site_bib_views_sorted() )  )
 
-
-
 #   ----- Field groups -----
 
 site_field_groups = (
@@ -283,6 +285,7 @@ site_defined_entity_fields = (
     , FieldChoice("_field/Entity_comment",             label="Comment"          )
     , FieldChoice("_field/Entity_id",                  label="Id"               )
     , FieldChoice("_field/Entity_label",               label="Label"            )
+    , FieldChoice("_field/Entity_ref",                 label="Entity ref"       )
     , FieldChoice("_field/Entity_see_also",            label="See also"         )
     , FieldChoice("_field/Entity_see_also_r",          label="See also"         )
     , FieldChoice("_field/Entity_type",                label="Type"             )
@@ -355,7 +358,6 @@ site_defined_field_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/Field_default",              label="Default value"       )
     , FieldChoice("_field/Field_entity_type",          label="Entity type"         )
-    , FieldChoice("_field/Field_fieldref",             label="Refer to field"      )
     , FieldChoice("_field/Field_fields",               label="Subfields"           )
     , FieldChoice("_field/Field_groupref",             label="Field group"         )
     , FieldChoice("_field/Field_help",                 label="Help"                )
@@ -386,7 +388,7 @@ site_field_subfield_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/Field_subfield_placement",   label="Subfield Pos/size"   )
     , FieldChoice("_field/Field_subfield_property",    label="Subfield URI"        )
-    , FieldChoice("_field/Field_subfield_sel",         label="Subfield Id"         )
+    , FieldChoice("_field/Field_subfield_sel",         label="Subfield ref"        )
     ])  
 
 site_field_all_fields = (
@@ -397,13 +399,13 @@ site_field_all_fields = (
 site_defined_group_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/Group_comment",              label="Help"                )
+    , FieldChoice("_field/Group_entity_type",          label="Group entity type"   )
     , FieldChoice("_field/Group_field_placement",      label="Position/size"       )
     , FieldChoice("_field/Group_field_property",       label="Property URI"        )
-    , FieldChoice("_field/Group_field_sel",            label="Field id"            )
+    , FieldChoice("_field/Group_field_sel",            label="Field ref"           )
     , FieldChoice("_field/Group_fields",               label="Fields"              )
     , FieldChoice("_field/Group_id",                   label="Group Id"            )
     , FieldChoice("_field/Group_label",                label="Label"               )
-    , FieldChoice("_field/Group_target_type",          label="Group entity type"   )
     ])
 
 site_group_fields = (
@@ -420,7 +422,7 @@ site_group_field_group_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/Group_field_placement",      label="Position/size"       )
     , FieldChoice("_field/Group_field_property",       label="Property URI"        )
-    , FieldChoice("_field/Group_field_sel",            label="Field id"            )
+    , FieldChoice("_field/Group_field_sel",            label="Field ref"           )
     ])
 
 site_defined_list_fields = (
@@ -430,13 +432,13 @@ site_defined_list_fields = (
     , FieldChoice("_field/List_default_type",          label="Default type"        )
     , FieldChoice("_field/List_default_view",          label="Default view"        )   
     , FieldChoice("_field/List_entity_selector",       label="Selector"            )
+    , FieldChoice("_field/List_entity_type",           label="List entity type"    )
     , FieldChoice("_field/List_field_placement",       label="Position/size"       )
     , FieldChoice("_field/List_field_property",        label="Property URI"        )
-    , FieldChoice("_field/List_field_sel",             label="Field id"            )
+    , FieldChoice("_field/List_field_sel",             label="Field ref"           )
     , FieldChoice("_field/List_fields",                label="Fields"              )
     , FieldChoice("_field/List_id",                    label="List Id"             )
     , FieldChoice("_field/List_label",                 label="Label"               )
-    , FieldChoice("_field/List_target_type",           label="List entity type"    )
     , FieldChoice("_field/List_type",                  label="List display type"   )
     ])
 
@@ -455,7 +457,7 @@ site_list_field_group_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/List_field_placement",       label="Position/size"       )
     , FieldChoice("_field/List_field_property",        label="Property URI"        )
-    , FieldChoice("_field/List_field_sel",             label="Field id"            )
+    , FieldChoice("_field/List_field_sel",             label="Field ref"           )
     ])
 
 site_defined_type_fields = (
@@ -467,6 +469,7 @@ site_defined_type_fields = (
     , FieldChoice("_field/Type_id",                    label="Type Id"             )
     , FieldChoice("_field/Type_label",                 label="Label"               )
     , FieldChoice("_field/Type_list",                  label="Default list"        )
+    , FieldChoice("_field/Type_prefix",                label="Namespace prefix"    )
     , FieldChoice("_field/Type_supertype_uri",         label="Supertype URI"       )
     , FieldChoice("_field/Type_supertype_uris",        label="Supertype URIs"      )
     , FieldChoice("_field/Type_uri",                   label="Type URI"            )
@@ -504,13 +507,13 @@ site_defined_view_fields = (
     , FieldChoice("_field/View_choice",                label="Choose view"         )
     , FieldChoice("_field/View_comment",               label="Help"                )
     , FieldChoice("_field/View_edit_view",             label="Editable view?"      )
+    , FieldChoice("_field/View_entity_type",           label="View entity type"    )
     , FieldChoice("_field/View_field_placement",       label="Position/size"       )
     , FieldChoice("_field/View_field_property",        label="Property URI"        )
-    , FieldChoice("_field/View_field_sel",             label="Field id"            )
+    , FieldChoice("_field/View_field_sel",             label="Field ref"           )
     , FieldChoice("_field/View_fields",                label="Fields"              )
     , FieldChoice("_field/View_id",                    label="View Id"             )
     , FieldChoice("_field/View_label",                 label="Label"               )
-    , FieldChoice("_field/View_target_type",           label="View entity type"    )
     ])
 
 site_view_fields = (
@@ -528,7 +531,7 @@ site_view_field_group_fields = (
     [ FieldChoice("_field/_initial_values")
     , FieldChoice("_field/View_field_placement",       label="Position/size"       )
     , FieldChoice("_field/View_field_property",        label="Property URI"        )
-    , FieldChoice("_field/View_field_sel",             label="Field id"            )
+    , FieldChoice("_field/View_field_sel",             label="Field ref"           )
     ])
 
 site_vocab_fields = (
@@ -643,6 +646,7 @@ site_field_types = (
     , FieldChoice("_enum_render_type/Group_Set",        label="Field group set"              )
     , FieldChoice("_enum_render_type/Group_Set_Row",    label="Field group set as table"     )
     , FieldChoice("_enum_render_type/Identifier",       label="Identifier"                   )
+    , FieldChoice("_enum_render_type/LangText",         label="Language text"                )
     , FieldChoice("_enum_render_type/Markdown",         label="Markdown rich text"           )
     , FieldChoice("_enum_render_type/Placement",        label="Position/size"                )
     , FieldChoice("_enum_render_type/RefAudio",         label="Audio clip reference"         )
@@ -674,6 +678,30 @@ def get_site_field_types_linked(coll_id):
 def get_site_field_types():
     return set( ( id_from_field_choice(fc) for fc in get_site_field_types_sorted() ) )
 
+#   ----- General information records -----
+
+site_infos = (
+    [ FieldChoice("_info/_initial_values")
+    , FieldChoice("_info/About",           label="About this site")
+    , FieldChoice("_info/About_initial",   label="About this site")
+    , FieldChoice("_info/Contact",         label="Contact information")
+    , FieldChoice("_info/Contact_initial", label="Contact information")
+    , FieldChoice("_info/Sitemap",         label="Navigating this site")
+    , FieldChoice("_info/Sitemap_initial", label="Navigating this site")
+    ])
+
+def get_site_infos_sorted():
+    return site_infos[1:]
+
+def get_site_infos_linked(coll_id):
+    return (
+        [ add_link_to_field_choice(fc, coll_id, layout.ENUM_LIST_TYPE_ID) 
+          for fc in get_site_infos_sorted() 
+        ])
+
+def get_site_infos():
+    return set( ( fc.id for fc in get_site_infos_sorted() )  )
+
 #   ----- Users -----
 
 site_users = (
@@ -722,7 +750,6 @@ site_value_modes = (
     [ FieldChoice("_enum_value_mode/_initial_values")
     , FieldChoice("_enum_value_mode/Value_direct",      label="Direct value"      )
     , FieldChoice("_enum_value_mode/Value_entity",      label="Entity reference"  )
-    , FieldChoice("_enum_value_mode/Value_field",       label="Field reference"   )
     , FieldChoice("_enum_value_mode/Value_import",      label="Import from web"   )
     , FieldChoice("_enum_value_mode/Value_upload",      label="File upload"       )
     ])
@@ -762,8 +789,8 @@ def get_site_value_types():
 #   ----- All site entities (including test collection data) -----
 
 test_types = (
-    [ FieldChoice("_type/testtype",     label="RecordType testcoll/testtype")
-    , FieldChoice("_type/testtype2",    label="RecordType testcoll/testtype2")
+    [ FieldChoice("_type/testtype",     label="RecordType testcoll/_type/testtype")
+    , FieldChoice("_type/testtype2",    label="RecordType testcoll/_type/testtype2")
     ])
 
 def get_test_types_sorted():
@@ -793,6 +820,7 @@ site_entities = (
     get_site_value_types_sorted() +
     get_site_fields_sorted() +
     get_site_field_groups_sorted() +
+    get_site_infos_sorted() +
     get_site_lists_sorted() +
     get_site_types_sorted() +
     get_test_types_sorted() +
