@@ -2,21 +2,23 @@
 Tests for AnnalistUser module and view
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
+import logging
+log = logging.getLogger(__name__)
+
 import os
 import unittest
 import re
 
-import logging
-log = logging.getLogger(__name__)
-
 from django.conf                            import settings
 from django.db                              import models
 from django.http                            import QueryDict
-from django.core.urlresolvers               import resolve, reverse
 from django.contrib.auth.models             import User
 from django.test                            import TestCase # cf. https://docs.djangoproject.com/en/dev/topics/testing/tools/#assertions
 from django.test.client                     import Client
@@ -35,31 +37,36 @@ from annalist.models.annalistuser           import AnnalistUser
 
 from annalist.views.fields.render_tokenset  import get_field_tokenset_renderer
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase                      import AnnalistTestCase
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     site_dir, collection_dir,
     site_view_url, collection_edit_url, 
     collection_entity_view_url,
     collection_create_values,
     create_user_permissions,
     create_test_user,
-    context_view_field
+    context_view_field,
+    context_field
     )
-from entity_testuserdata    import (
+from .entity_testuserdata import (
     annalistuser_dir,
     annalistuser_coll_url, annalistuser_url, annalistuser_edit_url,
     annalistuser_value_keys, annalistuser_load_keys,
     annalistuser_create_values, annalistuser_values, annalistuser_read_values,
-    annalistuser_view_form_data,
+    user_view_form_data,
     annalistuser_delete_confirm_form_data
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_list_type_url,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
 
 #   -----------------------------------------------------------------------------
 #
@@ -104,6 +111,16 @@ class AnnalistUserTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    # @classmethod
+    # def setUpClass(cls):
+    #     super(zzzzzz, cls).setUpClass()
+    #     return
+
+    # @classmethod
+    # def tearDownClass(cls):
+    #     super(zzzzzz, cls).tearDownClass()
+    #     return
+
     def test_AnnalistUserTest(self):
         self.assertEqual(AnnalistUser.__name__, "AnnalistUser", "Check AnnalistUser class name")
         return
@@ -210,7 +227,7 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
             self.testsite, "testcoll", collection_create_values("testcoll")
             )
         # For checking Location: header values...
-        self.continuation_url = TestHostUri + entitydata_list_type_url(
+        self.continuation_url = entitydata_list_type_url(
             coll_id="testcoll", type_id=layout.USER_TYPEID
             )
         # Login and permissions
@@ -273,12 +290,12 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
             , 'label': "small-12 medium-2 columns"
             , 'value': "small-12 medium-10 columns"
             })
-        field = (
+        field = context_field(
             { 'field_placement':    field_placement
             , 'field_label':        "Permissions"
             , 'field_placeholder':  "(user permissions)"
             , 'field_name':         "User_permissions"
-            , 'field_edit_value':   ["VIEW", "CREATE", "UPDATE", "DELETE", "CONFIG", "ADMIN"]
+            , 'field_value':        ["VIEW", "CREATE", "UPDATE", "DELETE", "CONFIG", "ADMIN"]
             })
         context  = Context({'field': field})
         rendered = get_field_tokenset_renderer().label_edit().render(context)
@@ -303,15 +320,15 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
             , 'label': "small-12 medium-2 columns"
             , 'value': "small-12 medium-10 columns"
             })
-        field = (
+        field = context_field(
             { 'field_placement':        field_placement
             , 'field_label':            "Permissions"
             , 'field_placeholder':      "(user permissions)"
             , 'field_name':             "User_permissions"
-            , 'field_edit_value':       ["VIEW", "CREATE", "UPDATE", "DELETE", "CONFIG", "ADMIN"]
+            , 'field_value':            ["VIEW", "CREATE", "UPDATE", "DELETE", "CONFIG", "ADMIN"]
             , 'field_render_object':    get_field_tokenset_renderer().label_edit()
             })
-        template = Template("{% include field.field_render_object %}")
+        template = Template("{% include field.description.field_render_object %}")
         context  = Context({ 'render_object': get_field_tokenset_renderer().label_edit(), 'field': field})
         rendered = template.render(context)
         rendered = re.sub(r'\s+', " ", rendered)
@@ -499,7 +516,7 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
     def test_post_edit_user(self):
         # The main purpose of this test is to check that user permissions are saved properly
         self.assertFalse(AnnalistUser.exists(self.testcoll, "edituser"))
-        f = annalistuser_view_form_data(
+        f = user_view_form_data(
             action="edit", orig_id="_default_user_perms", orig_coll="_annalist_site",
             user_id="edituser",
             user_name="User edituser",
@@ -513,8 +530,8 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         self.assertEqual(r['location'], self.continuation_url)
         # Check that new user exists
         self.assertTrue(AnnalistUser.exists(self.testcoll, "edituser"))
@@ -526,7 +543,7 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
     def test_post_copy_user(self):
         # The main purpose of this test is to check that user permissions are saved properly
         self.assertFalse(AnnalistUser.exists(self.testcoll, "copyuser"))
-        f = annalistuser_view_form_data(
+        f = user_view_form_data(
             action="copy", orig_id="_default_user_perms", orig_coll="_annalist_site",
             user_id="copyuser",
             user_name="User copyuser",
@@ -540,8 +557,8 @@ class AnnalistUserEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         self.assertEqual(r['location'], self.continuation_url)
         # Check that new user exists
         self.assertTrue(AnnalistUser.exists(self.testcoll, "copyuser"))
