@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for authorization functions
 """
@@ -15,7 +18,7 @@ log = logging.getLogger(__name__)
 from django.conf                    import settings
 from django.contrib.auth.models     import User
 from django.test                    import TestCase
-from django.core.urlresolvers       import resolve, reverse
+from django.urls                    import resolve, reverse
 from django.test.client             import Client
 
 from utils.SuppressLoggingContext   import SuppressLogging
@@ -35,39 +38,41 @@ from annalist.models.annalistuser   import (
     unknown_user_id, unknown_user_uri
     )
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase              import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     create_user_permissions,
     collection_new_form_data, collection_remove_form_data,
     context_list_entities,
     context_list_item_fields, context_list_item_field_value
     )
-from entity_testentitydata  import (
-    # recorddata_dir,  entitydata_dir,
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_delete_confirm_url,
     entitydata_list_type_url, entitydata_list_all_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
-    entitydata_context_data, entitydata_form_data, 
-    entitydata_delete_form_data,
+    default_view_form_data, entitydata_delete_form_data,
     entitydata_delete_confirm_form_data
     )
-from entity_testuserdata    import (
+from .entity_testuserdata import (
     annalistuser_dir,
     annalistuser_coll_url, annalistuser_url, annalistuser_edit_url,
     annalistuser_value_keys, annalistuser_load_keys,
     annalistuser_create_values, annalistuser_values, annalistuser_read_values,
-    annalistuser_view_form_data,
+    user_view_form_data,
     annalistuser_delete_form_data,
     annalistuser_delete_confirm_form_data
     )
-from entity_testcolldata    import (
-    collectiondata_view_form_data
+from .entity_testcolldata import (
+    coll_view_form_data
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_create_values, 
-    recordtype_entity_view_form_data,
+    type_view_form_data,
     recordtype_delete_form_data,
     recordtype_delete_confirm_form_data
     )
@@ -212,8 +217,14 @@ class AuthorizationTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(AuthorizationTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(AuthorizationTest, cls).tearDownClass()
         resetSitedata(scope="all")
         return
 
@@ -263,7 +274,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id="_annalist_site", type_id="_coll", entity_id=self.access_collection_id, 
             view_id="Collection_view"
             )
-        f = collectiondata_view_form_data(action="view",
+        f = coll_view_form_data(action="view",
             coll_id=self.access_collection_id,
             edit="edit"
             )
@@ -283,7 +294,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id="_annalist_site", type_id="_coll", entity_id=self.access_collection_id, 
             view_id="Collection_view"
             )
-        f = collectiondata_view_form_data(action="edit",
+        f = coll_view_form_data(action="edit",
             coll_id=self.access_collection_id,
             edit="edit"
             )
@@ -334,7 +345,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_user", entity_id="view_user", 
             view_id="Default_view"
             )
-        f = annalistuser_view_form_data(action="view",
+        f = user_view_form_data(action="view",
             coll_id=self.access_collection_id, user_id="view_user",
             user_name="View User",
             user_uri="mailto:view_user@%s"%(TestHost), 
@@ -351,7 +362,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_user", entity_id="view_user", 
             view_id="Default_view"
             )
-        f = annalistuser_view_form_data(action="view",
+        f = user_view_form_data(action="view",
             coll_id=self.access_collection_id, user_id="view_user",
             user_name="View User",
             user_uri="mailto:view_user@%s"%(TestHost), 
@@ -367,7 +378,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_user",
             view_id="Default_view"
             )
-        f = annalistuser_view_form_data(action="new",
+        f = user_view_form_data(action="new",
             coll_id=self.access_collection_id, user_id="new_user",
             user_name="New User",
             user_uri="mailto:new_user@%s"%(TestHost), 
@@ -383,7 +394,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_user", entity_id="copy_user", 
             view_id="Default_view"
             )
-        f = annalistuser_view_form_data(action="copy",
+        f = user_view_form_data(action="copy",
             coll_id=self.access_collection_id, user_id="copy_user_new", orig_id="copy_user",
             user_name="Copy User",
             user_uri="mailto:copy_user_new@%s"%(TestHost), 
@@ -398,7 +409,7 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_user", entity_id="edit_user", 
             view_id="Default_view"
             )
-        f = annalistuser_view_form_data(action="edit",
+        f = user_view_form_data(action="edit",
             coll_id=self.access_collection_id, user_id="edit_user",
             user_name="Edit User",
             user_uri="mailto:edit_user@%s"%(TestHost), 
@@ -462,8 +473,9 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_type", entity_id="view_type", 
             view_id="Default_view"
             )
-        f = recordtype_entity_view_form_data(action="view",
-            coll_id=self.access_collection_id, type_id="_type", orig_id="view_type",
+        f = type_view_form_data(action="view",
+            coll_id=self.access_collection_id, type_type_id="_type", 
+            type_entity_id="view_type", orig_id="view_type",
             edit="edit"
             )
         r = self.client.post(u, f)
@@ -473,11 +485,13 @@ class AuthorizationTest(AnnalistTestCase):
         # requires CONFIG
         e = self.create_type("view_type")
         u = entitydata_edit_url(action="view", 
-            coll_id=self.access_collection_id, type_id="_type", entity_id="view_type", 
+            coll_id=self.access_collection_id, type_id="_type", 
+            entity_id="view_type", 
             view_id="Default_view"
             )
-        f = recordtype_entity_view_form_data(action="view",
-            coll_id=self.access_collection_id, type_id="_type", orig_id="view_type",
+        f = type_view_form_data(action="view",
+            coll_id=self.access_collection_id, type_type_id="_type", 
+            type_entity_id="view_type", orig_id="view_type",
             copy="copy"
             )
         r = self.client.post(u, f)
@@ -489,9 +503,9 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_type",
             view_id="Default_view"
             )
-        f = recordtype_entity_view_form_data(action="new",
+        f = type_view_form_data(action="new",
             coll_id=self.access_collection_id, 
-            type_id="new_type", orig_id="orig_type"
+            type_entity_id="new_type", orig_id="orig_type"
             )
         r = self.client.post(u, f)
         return r
@@ -503,9 +517,9 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_type", entity_id="copy_type", 
             view_id="Default_view"
             )
-        f = recordtype_entity_view_form_data(action="copy",
+        f = type_view_form_data(action="copy",
             coll_id=self.access_collection_id, 
-            type_id="copy_type_new", orig_id="copy_type"
+            type_entity_id="copy_type_new", orig_id="copy_type"
             )
         r = self.client.post(u, f)
         return r
@@ -517,9 +531,9 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="_type", entity_id="edit_type", 
             view_id="Default_view"
             )
-        f = recordtype_entity_view_form_data(action="edit",
+        f = type_view_form_data(action="edit",
             coll_id=self.access_collection_id, 
-            type_id="edit_type"
+            type_entity_id="edit_type"
             )
         r = self.client.post(u, f)
         return r
@@ -583,11 +597,11 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="Default_type", entity_id="view_data", 
             view_id="Default_view"
             )
-        f = entitydata_form_data(action="edit",
-            coll_id=self.access_collection_id, type_id="Default_type", 
-            entity_id="view_data", orig_id="view_data",
-            edit="edit"
-            )
+        f = default_view_form_data(action="edit",
+                coll_id=self.access_collection_id, type_id="Default_type", 
+                entity_id="view_data", orig_id="view_data",
+                edit="edit"
+                )
         r = self.client.post(u, f)
         return r
 
@@ -598,11 +612,11 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="Default_type", entity_id="view_data", 
             view_id="Default_view"
             )
-        f = entitydata_form_data(action="copy",
-            coll_id=self.access_collection_id, type_id="Default_type", 
-            entity_id="copy_view_data", orig_id="view_data",
-            copy="copy"
-            )
+        f = default_view_form_data(action="copy",
+                coll_id=self.access_collection_id, type_id="Default_type", 
+                entity_id="copy_view_data", orig_id="view_data",
+                copy="copy"
+                )
         r = self.client.post(u, f)
         return r
 
@@ -612,9 +626,10 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="Default_type",
             view_id="Default_view"
             )
-        f = entitydata_form_data(action="new",
-            coll_id=self.access_collection_id, type_id="Default_type", entity_id="new_entity"
-            )
+        f = default_view_form_data(action="new",
+                coll_id=self.access_collection_id, type_id="Default_type", 
+                entity_id="new_entity"
+                )
         r = self.client.post(u, f)
         return r
 
@@ -625,10 +640,10 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="Default_type", entity_id="copy_entity", 
             view_id="Default_view"
             )
-        f = entitydata_form_data(action="copy",
-            coll_id=self.access_collection_id, type_id="Default_type", 
-            entity_id="copy_entity_new", orig_id="copy_entity"
-            )
+        f = default_view_form_data(action="copy",
+                coll_id=self.access_collection_id, type_id="Default_type", 
+                entity_id="copy_entity_new", orig_id="copy_entity"
+                )
         r = self.client.post(u, f)
         # log.info("r %s"%r)
         return r
@@ -640,9 +655,10 @@ class AuthorizationTest(AnnalistTestCase):
             coll_id=self.access_collection_id, type_id="Default_type", entity_id="edit_entity", 
             view_id="Default_view"
             )
-        f = entitydata_form_data(action="edit",
-            coll_id=self.access_collection_id, type_id="Default_type", entity_id="edit_entity"
-            )
+        f = default_view_form_data(action="edit",
+                coll_id=self.access_collection_id, type_id="Default_type", 
+                entity_id="edit_entity"
+                )
         r = self.client.post(u, f)
         # log.info("r %s"%r)
         return r
@@ -1289,7 +1305,7 @@ class AuthorizationTest(AnnalistTestCase):
         entities = context_list_entities(r.context)
         self.assertEqual(len(entities), 2)
         entity_fields = (
-            [ ('testtype',    '_type',    'RecordType testcoll/testtype')
+            [ ('testtype',    '_type',    'RecordType testcoll/_type/testtype')
             , ('entity1',     'testtype', 'Entity testcoll/testtype/entity1')
             ])
         for eid in range(2):
