@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for RecordView module and view with inherited bibliographic definitioins
 """
@@ -33,15 +36,17 @@ from annalist.views.uri_builder             import uri_with_params
 from annalist.views.recordviewdelete        import RecordViewDeleteConfirmedView
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
     init_annalist_test_site, 
     init_annalist_test_coll,
     init_annalist_named_test_coll,
     resetSitedata
     )
-from entity_testutils       import (
+from .entity_testutils import (
     site_dir, collection_dir,
     site_view_url, collection_edit_url, 
     collection_entity_view_url,
@@ -50,21 +55,18 @@ from entity_testutils       import (
     create_test_user,
     context_view_field
     )
-from entity_testviewdata    import (
+from .entity_testviewdata import (
     recordview_dir,
     recordview_coll_url, recordview_url, recordview_edit_url,
     recordview_value_keys, recordview_load_keys, 
     recordview_create_values, recordview_values, recordview_read_values,
-    recordview_entity_view_context_data, recordview_entity_view_form_data, 
-    # recordview_view_context_data, recordview_view_form_data, 
-    recordview_delete_confirm_form_data
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_list_type_url,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     make_field_choices, no_selection,
     get_site_default_entity_fields_sorted,
     get_site_bibentry_fields_sorted
@@ -72,7 +74,7 @@ from entity_testsitedata    import (
 
 #   -----------------------------------------------------------------------------
 #
-#   RecordView edit view tests
+#   BibEntryView edit view tests
 #
 #   -----------------------------------------------------------------------------
 
@@ -126,9 +128,14 @@ class BibRecordViewEditViewTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(BibRecordViewEditViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        # @@checkme@@ resetSitedata(scope="all")
+        super(BibRecordViewEditViewTest, cls).tearDownClass()
         return
 
     #   -----------------------------------------------------------------------------
@@ -211,17 +218,17 @@ class BibRecordViewEditViewTest(AnnalistTestCase):
             <div class="small-12 medium-4 columns" title="%(tooltip6)s">
               <div class="row show-for-small-only">
                 <div class="view-label small-12 columns">
-                  <span>Field id</span>
+                  <span>Field ref</span>
                 </div>
               </div>
               <div class="row view-value-col">
                 <div class="view-value small-12 columns">
                 """+
                   render_select_options(
-                    "View_fields__0__Field_id", "Field id",
-                    no_selection("(field sel)") + get_site_bibentry_fields_sorted(),
+                    "View_fields__0__View_field_sel", "Field ref",
+                    no_selection("(field reference)") + get_site_bibentry_fields_sorted(),
                     layout.FIELD_TYPEID+"/Entity_id",
-                    placeholder="(field sel)"
+                    placeholder="(field reference)"
                     )+
                 """
                 </div>
@@ -248,6 +255,13 @@ class BibRecordViewEditViewTest(AnnalistTestCase):
 
     # Test view rendering of BibEntry_view: field selectors should include Bib_* fields
     def test_get_recordview_edit_bibentry(self):
+        # coll_id      = "testcoll"
+        # type_id      = layout.VIEW_TYPEID
+        # entity_id    = "BibEntry_view"
+        # view_label   = "@@@BibEntry_view_label"
+        # entity_label = "%s/%s/%s"%(coll_id, type_id, entity_id)
+        # entity_descr = "coll %s, type %s, entity %s"%(coll_id, type_id, entity_id)
+        # Retrieve view form
         u = entitydata_edit_url(
             "edit", "testcoll", layout.VIEW_TYPEID, entity_id="BibEntry_view", 
             view_id="View_view"
@@ -313,14 +327,15 @@ class BibRecordViewEditViewTest(AnnalistTestCase):
         # NOTE: context['fields'][i]['field_id'] comes from FieldDescription instance via
         #       bound_field, so type prefix is stripped.  This does not apply to the field
         #       ids actually coming from the view form.
-        self.assertEqual(r.context['fields'][5]['field_id'],           'View_fields')
-        self.assertEqual(r.context['fields'][5]['field_name'],         'View_fields')
-        self.assertEqual(r.context['fields'][5]['field_label'],        'Fields')
-        self.assertEqual(r.context['fields'][5]['field_property_uri'], "annal:view_fields")
-        self.assertEqual(r.context['fields'][5]['field_value_mode'],   "Value_direct")
-        self.assertEqual(r.context['fields'][5]['field_value_type'],  "annal:View_field")
-        self.assertEqual(r.context['fields'][5]['field_value'],        expect_field_data)
-        self.assertEqual(r.context['fields'][5]['options'],            self.no_options)
+        f5 = r.context['fields'][5]
+        self.assertEqual(f5.field_id,           'View_fields')
+        self.assertEqual(f5.field_name,         'View_fields')
+        self.assertEqual(f5.field_label,        'Fields')
+        self.assertEqual(f5.description['field_property_uri'], "annal:view_fields")
+        self.assertEqual(f5.description['field_value_mode'],   "Value_direct")
+        self.assertEqual(f5.description['field_value_type'],   "annal:View_field")
+        self.assertEqual(f5['field_value'],                    expect_field_data)
+        self.assertEqual(f5['options'],                        self.no_options)
         return
 
     #   -----------------------------------------------------------------------------
