@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for collection data viewing and editing.
 """
@@ -17,7 +20,7 @@ log = logging.getLogger(__name__)
 from django.conf                            import settings
 from django.db                              import models
 from django.http                            import QueryDict
-from django.core.urlresolvers               import resolve, reverse
+from django.urls                            import resolve, reverse
 from django.contrib.auth.models             import User
 from django.test                            import TestCase # cf. https://docs.djangoproject.com/en/dev/topics/testing/tools/#assertions
 from django.test.client                     import Client
@@ -35,10 +38,14 @@ from annalist.models.sitedata               import SiteData
 from annalist.models.collection             import Collection
 from annalist.models.annalistuser           import AnnalistUser
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     site_dir, collection_dir,
     site_view_url, collection_view_url, collection_edit_url, 
     collection_entity_view_url,
@@ -47,20 +54,20 @@ from entity_testutils       import (
     create_test_user,
     context_view_field
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_list_type_url,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
-from entity_testcolldata    import (
+from .entity_testcolldata import (
     collectiondata_url, collectiondata_resource_url,
     collectiondata_view_url, collectiondata_view_resource_url,
     collectiondata_value_keys, collectiondata_load_keys,
     collectiondata_create_values, collectiondata_values, collectiondata_read_values,
-    collectiondata_view_form_data
+    coll_view_form_data
     )
-from entity_testuserdata    import (
-    annalistuser_view_form_data
+from .entity_testuserdata import (
+    user_view_form_data
     )
 
 
@@ -329,7 +336,7 @@ class CollectionDataEditViewTest(AnnalistTestCase):
         u = collectiondata_url(coll_id="testcoll")
         r = self.client.get(u, HTTP_ACCEPT="application/ld+json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         v = r['Location']
         self.assertEqual(v, TestHostUri+collection_url+layout.COLL_META_REF)
         r = self.client.get(v)
@@ -389,12 +396,12 @@ class CollectionDataEditViewTest(AnnalistTestCase):
     # collection named view edit post update
     def test_post_named_edit(self):
         u = collectiondata_view_url(coll_id="testcoll", action="edit")
-        f = collectiondata_view_form_data(coll_id="testcoll", action="edit")
+        f = coll_view_form_data(coll_id="testcoll", action="edit")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'],   TestBaseUri+"/c/_annalist_site/d/_coll/")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   TestBasePath+"/c/_annalist_site/d/_coll/")
         # Check updated collection data
         self._check_collection_data_values(coll_id="testcoll")
         return
@@ -453,7 +460,7 @@ class CollectionDataEditViewTest(AnnalistTestCase):
         orig_coll = r.context['orig_coll']
         # Assemble and POST form data to =updated collection metadata
         new_label = "Updated collection metadata"
-        f = collectiondata_view_form_data(
+        f = coll_view_form_data(
             coll_id="testcoll", 
             action="edit", 
             coll_label=new_label,
@@ -463,9 +470,9 @@ class CollectionDataEditViewTest(AnnalistTestCase):
         u = collectiondata_view_url(coll_id="testcoll", action="edit")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'],   TestBaseUri+"/c/_annalist_site/d/_coll/")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   TestBasePath+"/c/_annalist_site/d/_coll/")
         # Check updated collection data
         self._check_collection_data_values(coll_id="testcoll", coll_label=new_label)
         return
@@ -474,7 +481,7 @@ class CollectionDataEditViewTest(AnnalistTestCase):
         # The main purpose of this test is to check that user permissions are 
         # saved properly
         self.assertFalse(AnnalistUser.exists(self.testcoll, "copyuser"))
-        f = annalistuser_view_form_data(
+        f = user_view_form_data(
             action="copy", orig_id="_default_user_perms",
             user_id="copyuser",
             user_name="User copyuser",
@@ -487,9 +494,9 @@ class CollectionDataEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestBaseUri+"/c/testcoll/d/_user/")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'], TestBasePath+"/c/testcoll/d/_user/")
         # Check that new record type exists
         self.assertTrue(AnnalistUser.exists(self.testcoll, "copyuser"))
         self._check_annalist_user_perms("copyuser", ["VIEW", "CREATE", "UPDATE", "DELETE"])
