@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for collection type cache class.
 """
@@ -12,26 +15,25 @@ import unittest
 import logging
 log = logging.getLogger(__name__)
 
-from AnnalistTestCase                       import AnnalistTestCase
-from tests                                  import (
-    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-    )
-from init_tests                             import (
-    init_annalist_test_site, init_annalist_test_coll, resetSitedata
-    )
-from entity_testtypedata                    import (
-    recordtype_coll_url, recordtype_url, recordtype_edit_url,
-    recordtype_value_keys, recordtype_load_keys, 
-    recordtype_create_values, recordtype_values, recordtype_read_values,
-    recordtype_entity_view_context_data, 
-    recordtype_entity_view_form_data, recordtype_delete_confirm_form_data
-    )
-
 from annalist.models.site                   import Site
 from annalist.models.collection             import Collection
 from annalist.models.recordtype             import RecordType
 from annalist.models.collectiontypecache    import CollectionTypeCache
 
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testtypedata import (
+    recordtype_coll_url, recordtype_url, recordtype_edit_url,
+    recordtype_value_keys, recordtype_load_keys, 
+    recordtype_create_values, recordtype_values, recordtype_read_values,
+    recordtype_delete_confirm_form_data
+    )
+
 #   -----------------------------------------------------------------------------
 #
 #   CollectionTypeCache tests
@@ -120,7 +122,7 @@ class CollectionTypeCacheTest(AnnalistTestCase):
         self.expect_site_type_ids = (
             { "_coll"
             , "_enum_list_type", "_enum_render_type", "_enum_value_mode", "_enum_value_type"
-            , "_field", "_group", "_list", "_type", "_user", "_view", "_vocab"
+            , "_field", "_group", "_info", "_list", "_type", "_user", "_view", "_vocab"
             , "Default_type"
             })
         self.expect_coll_type_ids = (
