@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for entity module
 """
@@ -20,9 +23,14 @@ from django.test.client         import Client
 from annalist.identifiers       import ANNAL
 from annalist.models.entity     import EntityRoot, Entity
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    test_layout,
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
 
 #   -----------------------------------------------------------------------------
 #
@@ -53,8 +61,14 @@ class EntityRootTest(TestCase):
     def tearDown(self):
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityRootTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(EntityRootTest, cls).tearDownClass()
         resetSitedata(scope="all")
         return
 
@@ -307,8 +321,14 @@ class EntityTest(AnnalistTestCase):
     def tearDown(self):
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(EntityTest, cls).tearDownClass()
         resetSitedata(scope="all")
         return
 
