@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for EntityData subtype selection in list views and select dropdowns
 """
@@ -25,21 +28,25 @@ from annalist.models.entitydata     import EntityData
 
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from AnnalistTestCase       import AnnalistTestCase
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    test_layout,
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     collection_create_values,
     create_test_user,
     context_view_field,
     context_list_entities,
     context_list_head_fields
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_create_values
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_delete_confirm_url,
     entitydata_list_type_url, entitydata_list_all_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
@@ -123,8 +130,14 @@ class SubtypeSelectionTest(AnnalistTestCase):
         # resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(SubtypeSelectionTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(SubtypeSelectionTest, cls).tearDownClass()
         resetSitedata(scope="all")
         return
 
@@ -148,14 +161,15 @@ class SubtypeSelectionTest(AnnalistTestCase):
             self.assertEqual(entities[eid]['entity_id'], expect_entities[eid][1])
         return
 
-    def _create_ref_type_view(self, view_id="Test_ref_type_view", record_type="test:testtypes"):
+    def _create_ref_type_view(self, 
+        view_id="Test_ref_type_view", view_entity_type="test:testtypes"
+        ):
         ref_type_view = RecordView.create(self.testcoll, view_id,
-            { 'annal:type':         "annal:View"
-            , 'annal:uri':          "test:"+view_id
-            , 'rdfs:label':         "Test view label"
-            , 'rdfs:comment':       "Test view comment"
-            , 'annal:record_type':  record_type
-            #@@ , 'annal:add_field':    True
+            { 'annal:type':             "annal:View"
+            , 'annal:uri':              "test:"+view_id
+            , 'rdfs:label':             "Test view label"
+            , 'rdfs:comment':           "Test view comment"
+            , 'annal:view_entity_type': view_entity_type
             , 'annal:view_fields':
               [ { 'annal:field_id':         layout.FIELD_TYPEID+"/Entity_id"
                 , 'annal:field_placement':  "small:0,12;medium:0,6"
@@ -168,7 +182,7 @@ class SubtypeSelectionTest(AnnalistTestCase):
         self.assertTrue(ref_type_view is not None)
         return ref_type_view
 
-    def _create_ref_type_field(self, entity_type="test:testtypes"):
+    def _create_ref_type_field(self, field_entity_type="test:testtypes"):
         ref_type_field = RecordField.create(self.testcoll, "Test_ref_type_field",
             { "annal:type":                     "annal:Field"
             , "rdfs:label":                     "Type reference"
@@ -180,8 +194,8 @@ class SubtypeSelectionTest(AnnalistTestCase):
             , "annal:property_uri":             "test:ref_type"
             , "annal:field_placement":          "small:0,12;medium:0,6"
             , "annal:field_ref_type":           "_type/testtypes"
-            , "annal:field_ref_restriction":    "[test:turi] subtype %s"%entity_type
-            , "annal:field_entity_type":        entity_type
+            , "annal:field_ref_restriction":    "[test:turi] subtype %s"%field_entity_type
+            , "annal:field_entity_type":        field_entity_type
             })
         self.assertTrue(ref_type_field is not None)
         return ref_type_field
@@ -228,11 +242,11 @@ class SubtypeSelectionTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 2)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 2)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
-        self.assertEqual(f0['field_id'], "Entity_id")
-        self.assertEqual(f1['field_id'], "Test_ref_type_field")
+        self.assertEqual(f0.field_id, "Entity_id")
+        self.assertEqual(f1.field_id, "Test_ref_type_field")
         baselabel = "Entity testcoll/"
         baseuri   = TestBasePath+"/c/testcoll/d/%s/"
         ref_options = (
@@ -243,8 +257,10 @@ class SubtypeSelectionTest(AnnalistTestCase):
         return
 
     def test_select_notype_fields(self):
-        ref_view  = self._create_ref_type_view(view_id="Test_ref_notype_view", record_type="test:notypes")
-        ref_field = self._create_ref_type_field(entity_type="test:sometypes")
+        ref_view  = self._create_ref_type_view(
+            view_id="Test_ref_notype_view", view_entity_type="test:notypes"
+            )
+        ref_field = self._create_ref_type_field(field_entity_type="test:sometypes")
         u = entitydata_edit_url(
             "new", "testcoll", "ref_type", view_id="Test_ref_notype_view"
             )
@@ -257,11 +273,11 @@ class SubtypeSelectionTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 2)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 2)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
-        self.assertEqual(f0['field_id'], "Entity_id")
-        self.assertEqual(f1['field_id'], "Test_ref_type_field")
+        self.assertEqual(f0.field_id, "Entity_id")
+        self.assertEqual(f1.field_id, "Test_ref_type_field")
         baselabel = "Entity testcoll/"
         baseuri   = TestBasePath+"/c/testcoll/d/%s/"
         ref_options = []
@@ -269,8 +285,10 @@ class SubtypeSelectionTest(AnnalistTestCase):
         return
 
     def test_select_subtype1_fields(self):
-        ref_view  = self._create_ref_type_view(view_id="Test_ref_type1_view", record_type="test:testtypes")
-        ref_field = self._create_ref_type_field(entity_type="test:testtype1")
+        ref_view  = self._create_ref_type_view(
+            view_id="Test_ref_type1_view", view_entity_type="test:testtypes"
+            )
+        ref_field = self._create_ref_type_field(field_entity_type="test:testtype1")
         u = entitydata_edit_url(
             "new", "testcoll", "ref_type", view_id="Test_ref_type1_view"
             )
@@ -283,11 +301,11 @@ class SubtypeSelectionTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 2)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 2)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
-        self.assertEqual(f0['field_id'], "Entity_id")
-        self.assertEqual(f1['field_id'], "Test_ref_type_field")
+        self.assertEqual(f0.field_id, "Entity_id")
+        self.assertEqual(f1.field_id, "Test_ref_type_field")
         baselabel = "Entity testcoll/"
         baseuri   = TestBasePath+"/c/testcoll/d/%s/"
         ref_options = (
@@ -297,38 +315,4 @@ class SubtypeSelectionTest(AnnalistTestCase):
         self.assertEqual(f1['options'], ref_options)
         return
 
-    def _no_test_test_select_view_subtype_fields(self):
-        # @@INCOMPLETE:  this was an attempt to check field selction from the view context,
-        #                but abandoned to to complexity of reconstructing bound fields.
-        #                NOTE: sitedata tests use Beautifulsoup representation of rendered
-        #                page for these tests
-        ref_view  = self._create_ref_type_view()
-        ref_field = self._create_ref_type_field()
-        u = entitydata_edit_url(
-            "edit", "testcoll", "_view", "Test_ref_type_view", view_id="View_view"
-            )
-        r = self.client.get(u)
-        self.assertEqual(r.status_code,   200)
-        self.assertEqual(r.reason_phrase, "OK")
-        # Check render context
-        self.assertEqual(r.context['coll_id'],          "testcoll")
-        self.assertEqual(r.context['type_id'],          "_view")
-        # Fields
-        self.assertEqual(len(r.context['fields']), 6)
-        self.assertEqual(r.context['fields'][0]['field_id'], "View_id")
-        self.assertEqual(r.context['fields'][1]['field_id'], "View_label")
-        self.assertEqual(r.context['fields'][2]['field_id'], "View_comment")
-        self.assertEqual(r.context['fields'][3]['field_id'], "View_target_type")
-        self.assertEqual(r.context['fields'][4]['field_id'], "View_edit_view")
-        self.assertEqual(r.context['fields'][5]['field_id'], "View_fields")
-        print repr(r.context['fields'][5])
-        baselabel = "Entity testcoll/"
-        baseuri   = TestBasePath+"/c/testcoll/d/%s/"
-        ref_options = (
-            [ FieldChoice(opt, label=baselabel+opt, link=baseuri%opt)
-              for opt in ['testtype1/entity1', 'testtype2/entity2', 'testtypes/entitys']
-            ])
-        self.assertEqual(r.context['fields'][5]['options'], ref_options)
-        return
-
 # End.
