@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for EntityData default editing view
 """
@@ -29,13 +32,17 @@ from annalist.models.recordtype     import RecordType
 from annalist.models.recordtypedata import RecordTypeData
 from annalist.models.entitydata     import EntityData
 
-#@@ from annalist.views.defaultedit             import EntityDefaultEditView
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    test_layout,
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     make_message, make_quoted_message,
     site_dir, collection_dir, 
     collection_edit_url,
@@ -46,22 +53,24 @@ from entity_testutils       import (
     context_view_field,
     context_bind_fields
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_url,
     recordtype_edit_url,
     recordtype_create_values,
+    type_view_context_data, 
+    type_view_form_data,
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     recorddata_dir,  entitydata_dir,
     entity_url, entitydata_edit_url, 
     entitydata_list_type_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
-    entitydata_context_data, entitydata_form_data, entitydata_delete_confirm_form_data,
-    entitydata_recordtype_view_form_data,
+    default_view_context_data, 
+    default_view_form_data, entitydata_delete_confirm_form_data,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     get_site_types, get_site_types_sorted, get_site_types_linked,
     get_site_lists, get_site_lists_sorted,
     get_site_list_types, get_site_list_types_sorted,
@@ -91,7 +100,7 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self.testdata = RecordTypeData.create(self.testcoll, "testtype", {})
         self.type_ids = get_site_types_linked("testcoll")
         self.type_ids.append(FieldChoice("_type/testtype", 
-                label="RecordType testcoll/testtype",
+                label="RecordType testcoll/_type/testtype",
                 link=recordtype_url("testcoll", "testtype")
             ))
         self.no_options = [ FieldChoice('', label="(no options)") ]
@@ -106,9 +115,14 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityDefaultEditViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        #@@checkme@@ resetSitedata()
+        super(EntityDefaultEditViewTest, cls).tearDownClass()
         return
 
     #   -----------------------------------------------------------------------------
@@ -145,14 +159,8 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
     #   Form rendering tests
     #   -----------------------------------------------------------------------------
 
-    #@@
-    # def test_EntityDefaultEditView(self):
-    #     self.assertEqual(EntityDefaultEditView.__name__, "EntityDefaultEditView", "Check EntityDefaultEditView class name")
-    #     return
-    #@@
-
     def test_get_form_rendering(self):
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.get(u+"?continuation_url=/xyzzy/")
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
@@ -234,76 +242,22 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         return
 
     def test_get_new(self):
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.get(u+"?continuation_url=/xyzzy/")
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         # Test context
-        view_url = entity_url(coll_id="testcoll", type_id="testtype", entity_id="00000001")
-        self.assertEqual(r.context['coll_id'],          "testcoll")
-        self.assertEqual(r.context['type_id'],          "testtype")
-        self.assertEqual(r.context['entity_id'],        "00000001")
-        self.assertEqual(r.context['orig_id'],          None)
-        self.assertEqual(r.context['action'],           "new")
-        self.assertEqual(r.context['continuation_url'], "/xyzzy/")
-        # Fields
-        self.assertEqual(len(r.context['fields']), 3)
-        f0  = context_view_field(r.context, 0, 0)
-        f1  = context_view_field(r.context, 0, 1)
-        f2  = context_view_field(r.context, 1, 0)
-        f3  = context_view_field(r.context, 2, 0)
-        # 1st field
-        self.assertEqual(f0['field_id'],            'Entity_id')
-        self.assertEqual(f0['field_name'],          'entity_id')
-        self.assertEqual(f0['field_label'],         'Id')
-        self.assertEqual(f0['field_placeholder'],   "(entity id)")
-        self.assertEqual(f0['field_property_uri'],  "annal:id")
-        self.assertEqual(f0['field_render_type'],   "EntityId")
-        self.assertEqual(f0['field_value_mode'],    "Value_direct")
-        self.assertEqual(f0['field_value_type'],    "annal:EntityRef")
-        self.assertEqual(f0.field_value,            "00000001")
-        self.assertEqual(f0['field_value'],         "00000001")
-        self.assertEqual(f0['entity_type_id'],      "testtype")
-        self.assertEqual(f0['options'],             self.no_options)
-        # 2nd field
-        self.assertEqual(f1['field_id'],            'Entity_type')
-        self.assertEqual(f1['field_name'],          'entity_type')
-        self.assertEqual(f1['field_label'],         'Type')
-        self.assertEqual(f1['field_placeholder'],   "(type id)")
-        self.assertEqual(f1['field_property_uri'],  "annal:type_id")
-        self.assertEqual(f1['field_render_type'],   "EntityTypeId")
-        self.assertEqual(f1['field_value_mode'],    "Value_direct")
-        self.assertEqual(f1['field_value_type'],    "annal:EntityRef")
-        self.assertEqual(f1.field_value,            "testtype")
-        self.assertEqual(f1['field_value'],         "testtype")
-        self.assertEqual(f1['entity_type_id'],      "testtype")
-        self.assertEqual(set(f1['options']),        set(self.type_ids))
-        # 3rd field
-        field_label_value = default_label("testcoll", "testtype", "00000001")
-        self.assertEqual(f2['field_id'],            'Entity_label')
-        self.assertEqual(f2['field_name'],          'Entity_label')
-        self.assertEqual(f2['field_label'],         'Label')
-        self.assertEqual(f2['field_placeholder'],   "(label)")
-        self.assertEqual(f2['field_property_uri'],  "rdfs:label")
-        self.assertEqual(f2['field_render_type'],   "Text")
-        self.assertEqual(f2['field_value_mode'],    "Value_direct")
-        self.assertEqual(f2['field_value_type'],    "annal:Text")
-        self.assertEqual(f2['field_value'],         field_label_value)
-        self.assertEqual(f2['entity_type_id'],      "testtype")
-        self.assertEqual(f2['options'],             self.no_options)
-        # 4th field
-        field_comment_value = default_comment("testcoll", "testtype", "00000001")
-        self.assertEqual(f3['field_id'],            'Entity_comment')
-        self.assertEqual(f3['field_name'],          'Entity_comment')
-        self.assertEqual(f3['field_label'],         'Comment')
-        self.assertEqual(f3['field_placeholder'],   "(description)")
-        self.assertEqual(f3['field_property_uri'],  "rdfs:comment")
-        self.assertEqual(f3['field_render_type'],   "Markdown")
-        self.assertEqual(f3['field_value_mode'],    "Value_direct")
-        self.assertEqual(f3['field_value_type'],    "annal:Richtext")
-        self.assertEqual(f3['field_value'],         field_comment_value)
-        self.assertEqual(f3['entity_type_id'],      "testtype")
-        self.assertEqual(f3['options'],             self.no_options)
+        expect_context = default_view_context_data(
+            coll_id="testcoll", type_id="testtype", entity_id="00000001", orig_id=None,
+            type_ref="testtype", type_choices=self.type_ids,
+            entity_label="",
+            entity_descr="",
+            action="new", 
+            update="Entity",
+            continuation_url="/xyzzy/"
+            )
+        self.assertEqual(len(r.context['fields']), 3) # 4 fields over 3 rows
+        self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
 
     def test_get_edit(self):
@@ -314,82 +268,60 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         # log.info(r.content)
         self.assertContains(r, "<title>Entity testcoll/testtype/entity1 - Default record view - Collection testcoll</title>")
         # Test context
-        view_url = entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity1")
-        self.assertEqual(r.context['coll_id'],          "testcoll")
-        self.assertEqual(r.context['type_id'],          "testtype")
-        self.assertEqual(r.context['entity_id'],        "entity1")
-        self.assertEqual(r.context['orig_id'],          "entity1")
-        self.assertEqual(r.context['action'],           "edit")
-        self.assertEqual(r.context['continuation_url'], "/xyzzy/")
-        # Fields
-        self.assertEqual(len(r.context['fields']), 3)
-        f0  = context_view_field(r.context, 0, 0)
-        f1  = context_view_field(r.context, 0, 1)
-        f2  = context_view_field(r.context, 1, 0)
-        f3  = context_view_field(r.context, 2, 0)
-        # 1st field
-        self.assertEqual(f0['field_id'],            'Entity_id')
-        self.assertEqual(f0['field_name'],          'entity_id')
-        self.assertEqual(f0['field_label'],         'Id')
-        self.assertEqual(f0['field_placeholder'],   "(entity id)")
-        self.assertEqual(f0['field_property_uri'],  "annal:id")
-        self.assertEqual(f0['field_render_type'],   "EntityId")
-        self.assertEqual(f0['field_value_mode'],    "Value_direct")
-        self.assertEqual(f0['field_value_type'],    "annal:EntityRef")
-        self.assertEqual(f0['field_value'],         "entity1")
-        self.assertEqual(f0['options'],             self.no_options)
-        # 2nd field
-        self.assertEqual(f1['field_id'],            'Entity_type')
-        self.assertEqual(f1['field_name'],          'entity_type')
-        self.assertEqual(f1['field_label'],         'Type')
-        self.assertEqual(f1['field_placeholder'],   "(type id)")
-        self.assertEqual(f1['field_property_uri'],  "annal:type_id")
-        self.assertEqual(f1['field_render_type'],   "EntityTypeId")
-        self.assertEqual(f1['field_value_mode'],    "Value_direct")
-        self.assertEqual(f1['field_value_type'],    "annal:EntityRef")
-        self.assertEqual(f1['field_value'],         "testtype")
-        self.assertEqual(set(f1['options']),        set(self.type_ids))
-        # 3rd field
-        field_label_value = (
-            "Entity testcoll/testtype/entity1"
+        expect_context = default_view_context_data(
+            coll_id="testcoll", type_id="testtype", entity_id="entity1", 
+            type_ref="testtype", type_choices=self.type_ids,
+            entity_label="Entity testcoll/testtype/entity1",
+            entity_descr="Entity coll testcoll, type testtype, entity entity1",
+            action="edit", 
+            update="Entity",
+            continuation_url="/xyzzy/"
             )
-        self.assertEqual(f2['field_id'],            'Entity_label')
-        self.assertEqual(f2['field_name'],          'Entity_label')
-        self.assertEqual(f2['field_label'],         'Label')
-        self.assertEqual(f2['field_placeholder'],   "(label)")
-        self.assertEqual(f2['field_property_uri'],  "rdfs:label")
-        self.assertEqual(f2['field_render_type'],   "Text")
-        self.assertEqual(f2['field_value_mode'],    "Value_direct")
-        self.assertEqual(f2['field_value_type'],    "annal:Text")
-        self.assertEqual(f2['field_value'],         field_label_value)
-        self.assertEqual(f2['options'],             self.no_options)
-        # 4th field
-        field_comment_value = (
-            "Entity coll testcoll, type testtype, entity entity1"
-            )
-        self.assertEqual(f3['field_id'],            'Entity_comment')
-        self.assertEqual(f3['field_name'],          'Entity_comment')
-        self.assertEqual(f3['field_label'],         'Comment')
-        self.assertEqual(f3['field_placeholder'],   "(description)")
-        self.assertEqual(f3['field_property_uri'],  "rdfs:comment")
-        self.assertEqual(f3['field_render_type'],   "Markdown")
-        self.assertEqual(f3['field_value_mode'],    "Value_direct")
-        self.assertEqual(f3['field_value_type'],    "annal:Richtext")
-        self.assertEqual(f3['field_value'],         field_comment_value)
-        self.assertEqual(f3['options'],             self.no_options)
+        self.assertEqual(len(r.context['fields']), 3) # 4 fields over 3 rows
+        self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
 
     def test_get_edit_not_exists(self):
-        u = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entitynone")
+        u = entitydata_edit_url("edit", "testcoll", "testtype", 
+            entity_id="entitynone"
+            )
         r = self.client.get(u+"?continuation_url=/xyzzy/")
-        self.assertEqual(r.status_code,   404)
-        self.assertEqual(r.reason_phrase, "Not found")
-        self.assertContains(r, "<title>Annalist error</title>", status_code=404)
-        self.assertContains(r, "<h3>404: Not found</h3>", status_code=404)
-        # log.debug(r.content)
-        err_label = error_label("testcoll", "testtype", "entitynone")
-        msg_text  = make_message(message.ENTITY_DOES_NOT_EXIST, id="entitynone", label=err_label)
-        self.assertContains(r, "<p>%s</p>"%msg_text, status_code=404)
+        self.check_entity_not_found_response(r, 
+            err_msg=make_message(
+                message.ENTITY_DOES_NOT_EXIST, 
+                id="entitynone", 
+                label=error_label("testcoll", "testtype", "entitynone")
+                ),
+            redirect_url="/xyzzy/"
+            )
+        return
+
+    def test_head_new(self):
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
+        r = self.client.head(u)
+        self.assertEqual(r.status_code,   200)
+        self.assertEqual(r.reason_phrase, "OK")
+        self.assertEqual(r.content,       b"")
+        return
+
+    def test_head_edit(self):
+        u = entitydata_edit_url("edit", "testcoll", "testtype", 
+            entity_id="entity1"
+            )
+        r = self.client.head(u)
+        self.assertEqual(r.status_code,   200)
+        self.assertEqual(r.reason_phrase, "OK")
+        self.assertEqual(r.content,       b"")
+        return
+
+    def test_head_edit_not_exists(self):
+        u = entitydata_edit_url("edit", "testcoll", "testtype", 
+            entity_id="entitynone"
+            )
+        r = self.client.head(u)
+        self.check_entity_not_found_response(r, 
+            redirect_url="/testsite/c/testcoll/d/testtype/"
+            )
         return
 
     #   -----------------------------------------------------------------------------
@@ -400,55 +332,64 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
 
     def test_post_new_entity(self):
         self.assertFalse(EntityData.exists(self.testdata, "newentity"))
-        f = entitydata_form_data(entity_id="newentity", action="new")
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        f = default_view_form_data(entity_id="newentity", action="new")
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check new entity data created
         self._check_entity_data_values("newentity")
         return
 
     def test_post_new_entity_cancel(self):
         self.assertFalse(EntityData.exists(self.testdata, "newentity"))
-        f = entitydata_form_data(entity_id="newentity", action="new", cancel="Cancel")
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        f = default_view_form_data(entity_id="newentity", action="new", cancel="Cancel")
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that new record type still does not exist
         self.assertFalse(EntityData.exists(self.testdata, "newentity"))
         return
 
     def test_post_new_entity_missing_id(self):
-        f = entitydata_form_data(action="new")
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        f = default_view_form_data(action="new", entity_id="")
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
         # Test context
-        expect_context = entitydata_context_data(action="new")
+        expect_context = default_view_context_data(
+            coll_id="testcoll", type_id="testtype", 
+            entity_id="", orig_id="orig_entity_id",
+            type_ref="", type_choices=self.type_ids,
+            action="new"
+            )
+        self.assertEqual(len(r.context['fields']), 3) # 4 fields over 3 rows
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
 
     def test_post_new_entity_invalid_id(self):
-        f = entitydata_form_data(entity_id="!badentity", orig_id="orig_entity_id", action="new")
-        u = entitydata_edit_url("new", "testcoll", "testtype")
+        f = default_view_form_data(
+            entity_id="!badentity", orig_id="orig_entity_id", action="new"
+            )
+        u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
         # Test context
-        expect_context = entitydata_context_data(
-            entity_id="!badentity", orig_id="orig_entity_id", action="new"
+        expect_context = default_view_context_data(
+            coll_id="testcoll", type_id="testtype", 
+            entity_id="!badentity", orig_id="orig_entity_id",
+            type_ref="_type/testtype", type_choices=self.type_ids,
+            action="new"
             )
-        # log.info(repr(f))
-        # log.info(repr(context_bind_fields(r.context)['fields'][1]))
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
 
@@ -456,13 +397,13 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         # Checks logic related to creating a new recorddata entity in collection 
         # for type defined in site data
         self.assertFalse(EntityData.exists(self.testdata, "newentity"))
-        f = entitydata_form_data(entity_id="newentity", type_id="Default_type", action="new")
-        u = entitydata_edit_url("new", "testcoll", "Default_type")
+        f = default_view_form_data(entity_id="newentity", type_id="Default_type", action="new")
+        u = entitydata_edit_url("new", "testcoll", "Default_type", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "Default_type"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "Default_type"))
         # Check new entity data created
         self._check_entity_data_values(
             "newentity", type_id="Default_type", type_uri="annal:Default_type",
@@ -475,26 +416,26 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         # Checks logic for creating an entity which may require creation of new recorddata
         # Create new type
         self.assertFalse(RecordType.exists(self.testcoll, "newtype"))
-        f = entitydata_recordtype_view_form_data(
-            coll_id="testcoll", type_id="_type", entity_id="newtype",
-            action="new"
+        f = type_view_form_data(action="new",
+            coll_id="testcoll", 
+            type_entity_id="newtype",            
             )
         u = entitydata_edit_url("new", "testcoll", type_id="_type", view_id="Type_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "_type"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "_type"))
         self.assertTrue(RecordType.exists(self.testcoll, "newtype"))
         # Create new entity
         self.assertFalse(EntityData.exists(self.testdata, "newentity"))
-        f = entitydata_form_data(entity_id="newentity", type_id="newtype", action="new")
-        u = entitydata_edit_url("new", "testcoll", "newtype")
+        f = default_view_form_data(entity_id="newentity", type_id="newtype", action="new")
+        u = entitydata_edit_url("new", "testcoll", "newtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "newtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "newtype"))
         # Check new entity data created
         self._check_entity_data_values("newentity", type_id="newtype")
         return
@@ -503,50 +444,56 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
 
     def test_post_copy_entity(self):
         self.assertFalse(EntityData.exists(self.testdata, "copytype"))
-        f = entitydata_form_data(entity_id="copytype", action="copy")
+        f = default_view_form_data(entity_id="copytype", action="copy")
         u = entitydata_edit_url("copy", "testcoll", "testtype", entity_id="entity1")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that new record type exists
         self._check_entity_data_values("copytype")
         return
 
     def test_post_copy_entity_cancel(self):
         self.assertFalse(EntityData.exists(self.testdata, "copytype"))
-        f = entitydata_form_data(entity_id="copytype", action="copy", cancel="Cancel")
+        f = default_view_form_data(entity_id="copytype", action="copy", cancel="Cancel")
         u = entitydata_edit_url("copy", "testcoll", "testtype", entity_id="entity1")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that target record type still does not exist
         self.assertFalse(EntityData.exists(self.testdata, "copytype"))
         return
 
     def test_post_copy_entity_missing_id(self):
-        f = entitydata_form_data(action="copy")
+        f = default_view_form_data(action="copy", entity_id="", orig_id="entity1")
         u = entitydata_edit_url("copy", "testcoll", "testtype", entity_id="entity1")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
-        expect_context = entitydata_context_data(action="copy")
+        expect_context = default_view_context_data(
+            action="copy", orig_id="entity1",
+            type_ref="", type_choices=self.type_ids
+            )
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
 
     def test_post_copy_entity_invalid_id(self):
-        f = entitydata_form_data(entity_id="!badentity", orig_id="orig_entity_id", action="copy")
+        f = default_view_form_data(
+            entity_id="!badentity", orig_id="entity1", action="copy"
+            )
         u = entitydata_edit_url("copy", "testcoll", "testtype", entity_id="entity1")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
-        expect_context = entitydata_context_data(
-            entity_id="!badentity", orig_id="orig_entity_id", action="copy"
+        expect_context = default_view_context_data(
+            action="copy", entity_id="!badentity", orig_id="entity1",
+            type_ref="_type/testtype", type_choices=self.type_ids,
             )
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         return
@@ -556,13 +503,13 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
     def test_post_edit_entity(self):
         self._create_entity_data("entityedit")
         self._check_entity_data_values("entityedit")
-        f  = entitydata_form_data(entity_id="entityedit", action="edit", update="Updated entity")
+        f  = default_view_form_data(entity_id="entityedit", action="edit", update="Updated entity")
         u  = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entityedit")
         r  = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         self._check_entity_data_values("entityedit", update="Updated entity")
         return
 
@@ -570,13 +517,13 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self._create_entity_data("entityeditid1")
         e1 = self._check_entity_data_values("entityeditid1")
         # Now post edit form submission with different values and new id
-        f  = entitydata_form_data(entity_id="entityeditid2", orig_id="entityeditid1", action="edit")
+        f  = default_view_form_data(entity_id="entityeditid2", orig_id="entityeditid1", action="edit")
         u  = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entityeditid1")
         r  = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that new record type exists and old does not
         self.assertFalse(EntityData.exists(self.testdata, "entityeditid1"))
         self._check_entity_data_values("entityeditid2")
@@ -591,7 +538,7 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self.assertTrue(RecordType.exists(self.testcoll, "newtype"))
         self.assertFalse(RecordTypeData.exists(self.testcoll, "newtype"))
         # Now post edit form submission with new type id
-        f = entitydata_form_data(
+        f = default_view_form_data(
             entity_id="entityedittype", orig_id="entityedittype", 
             type_id="newtype", orig_type="testtype",
             action="edit")
@@ -599,9 +546,9 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         r = self.client.post(u, f)
         # log.info("***********\n"+r.content)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that new record type data now exists, and that new record exists and old does not
         self.assertTrue(RecordTypeData.exists(self.testcoll, "newtype"))
         self.assertFalse(EntityData.exists(self.testdata, "entityedittype"))
@@ -613,13 +560,13 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self._create_entity_data("edittype")
         self._check_entity_data_values("edittype")
         # Post from cancelled edit form
-        f = entitydata_form_data(entity_id="edittype", action="edit", cancel="Cancel", update="Updated entity")
+        f = default_view_form_data(entity_id="edittype", action="edit", cancel="Cancel", update="Updated entity")
         u = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="edittype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], TestHostUri + entitydata_list_type_url("testcoll", "testtype"))
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   entitydata_list_type_url("testcoll", "testtype"))
         # Check that target record type still does not exist and unchanged
         self._check_entity_data_values("edittype")
         return
@@ -628,14 +575,24 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self._create_entity_data("edittype")
         self._check_entity_data_values("edittype")
         # Form post with ID missing
-        f = entitydata_form_data(action="edit", update="Updated entity")
+        f = default_view_form_data(
+            action="edit", 
+            entity_id="", orig_id="edittype",
+            update="Updated entity"
+            )
         u = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="edittype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
         # Test context for re-rendered form
-        expect_context = entitydata_context_data(action="edit", update="Updated entity")
+        expect_context = default_view_context_data(
+            action="edit", update="Updated entity",
+            orig_id="edittype",
+            type_ref="", type_choices=self.type_ids,
+            record_type="/testsite/c/testcoll/d/_type/testtype/"
+            )
+        self.assertEqual(len(r.context['fields']), 3) # 4 fields over 3 rows
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         # Check stored entity is unchanged
         self._check_entity_data_values("edittype")
@@ -645,8 +602,8 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self._create_entity_data("edittype")
         self._check_entity_data_values("edittype")
         # Form post with ID malformed
-        f = entitydata_form_data(
-            entity_id="!badentity", orig_id="orig_entity_id", action="edit"
+        f = default_view_form_data(
+            entity_id="!badentity", orig_id="edittype", action="edit"
             )
         u = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="edittype")
         r = self.client.post(u, f)
@@ -654,8 +611,10 @@ class EntityDefaultEditViewTest(AnnalistTestCase):
         self.assertEqual(r.reason_phrase, "OK")
         self.assertContains(r, "<h3>Problem with entity identifier</h3>")
         # Test context for re-rendered form
-        expect_context = entitydata_context_data(
-            entity_id="!badentity", orig_id="orig_entity_id", action="edit"
+        expect_context = default_view_context_data(
+            entity_id="!badentity", orig_id="edittype", action="edit",
+            type_ref="_type/testtype", type_choices=self.type_ids,
+            record_type="/testsite/c/testcoll/d/_type/testtype/"
             )
         self.assertDictionaryMatch(context_bind_fields(r.context), expect_context)
         # Check stored entity is unchanged
