@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Entity editing tests for enumerated value fields
 """
@@ -34,26 +37,31 @@ from annalist.models.recordfield    import RecordField
 from annalist.models.recordtypedata import RecordTypeData
 from annalist.models.entitydata     import EntityData
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    test_layout,
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     collection_create_values,
     continuation_url_param,
     create_test_user
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_create_values, 
     )
-from entity_testviewdata    import (
+from .entity_testviewdata import (
     recordview_url, 
     recordview_create_values, recordview_values,
-    recordview_entity_view_form_data, 
+    view_view_form_data, 
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, 
     entitydata_value_keys, entitydata_create_values, entitydata_values,
-    entitydata_default_view_form_data,
+    default_view_form_data,
     )
 
 #   -----------------------------------------------------------------------------
@@ -82,8 +90,14 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityEditEnumFieldTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(EntityEditEnumFieldTest, cls).tearDownClass()
         resetSitedata(scope="collections") #@@checkme@@
         return
 
@@ -105,7 +119,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
         self.assertTrue(typeinfo.entityclass.exists(typeinfo.entityparent, entity_id))
         e = typeinfo.entityclass.load(typeinfo.entityparent, entity_id)
         self.assertEqual(e.get_id(), entity_id)
-        self.assertEqual(e.get_view_url(""), TestHostUri + entity_url("testcoll", type_id, entity_id))
+        self.assertEqual(
+            e.get_view_url(""), 
+            TestHostUri+entity_url("testcoll", type_id, entity_id)
+            )
         v = entitydata_values(entity_id, type_id=type_id, update=update)
         if update_dict:
             v.update(update_dict)
@@ -120,7 +137,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
         "Helper function creates record view entry with supplied view_id"
         t = RecordView.create(
             self.testcoll, view_id, 
-            recordview_create_values(view_id=view_id, target_record_type="annal:View")
+            recordview_create_values(view_id=view_id, view_entity_type="annal:View")
             )
         return t
 
@@ -133,10 +150,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
         self.assertTrue(RecordView.exists(self.testcoll, view_id))
         t = RecordView.load(self.testcoll, view_id)
         self.assertEqual(t.get_id(), view_id)
-        self.assertEqual(t.get_view_url(), TestHostUri + recordview_url("testcoll", view_id))
+        self.assertEqual(t.get_view_url(), TestHostUri+recordview_url("testcoll", view_id))
         v = recordview_values(
             view_id=view_id, view_uri=view_uri, 
-            target_record_type="annal:View",
+            view_entity_type="annal:View",
             update=update, 
             num_fields=num_fields,
             )
@@ -158,16 +175,16 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_view(self):
         self.assertFalse(EntityData.exists(self.testdata, "entitynewview"))
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewview", action="new", update="Updated entity", 
-            new_view="New view"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewview", action="new", update="Updated entity", 
+                new_view="New view"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_view", view_id="View_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_view", view_id="View_view")
         w = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entitynewview", view_id="Default_view")
         c = continuation_url_param(w)
         self.assertIn(v, r['location'])
@@ -177,10 +194,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_view_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewview", action="new", update="Updated entity", 
-            new_view="New view"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewview", action="new", update="Updated entity", 
+                new_view="New view"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   401)
@@ -189,16 +206,16 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_field(self):
         self.assertFalse(EntityData.exists(self.testdata, "entitynewfield"))
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewfield", action="new", update="Updated entity", 
-            new_field="New field"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewfield", action="new", update="Updated entity", 
+                new_field="New field"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_field", view_id="Field_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_field", view_id="Field_view")
         w = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entitynewfield", view_id="Default_view")
         c = continuation_url_param(w)
         self.assertIn(v, r['location'])
@@ -208,10 +225,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_field_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewfield", action="new", update="Updated entity", 
-            new_field="New field"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewfield", action="new", update="Updated entity", 
+                new_field="New field"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   401)
@@ -220,16 +237,16 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_type(self):
         self.assertFalse(EntityData.exists(self.testdata, "entitynewtype"))
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewtype", action="new", update="Updated entity", 
-            new_type="New type"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewtype", action="new", update="Updated entity", 
+                new_type="New type"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
         w = entitydata_edit_url("edit", "testcoll", "testtype", entity_id="entitynewtype", view_id="Default_view")
         c = continuation_url_param(w)
         self.assertIn(v, r['location'])
@@ -239,10 +256,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_new_type_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewtype", action="new", update="Updated entity", 
-            new_type="New type"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewtype", action="new", update="Updated entity", 
+                new_type="New type"
+                )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   401)
@@ -251,30 +268,29 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_new_entity_enum_type_new(self):
         self.assertFalse(EntityData.exists(self.testdata, "entitynewtype"))
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
                 entity_id="entitynewtype", action="new", update="Updated entity", 
                 new_enum="entity_type__new_edit"
                 )
         u = entitydata_edit_url("new", "testcoll", "testtype", view_id="Default_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        # v = entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         v = entitydata_edit_url("edit", "testcoll", "_type", "testtype", view_id="Type_view")
         w = entitydata_edit_url(
             "edit", "testcoll", "testtype", entity_id="entitynewtype", 
             view_id="Default_view"
             )
         c = continuation_url_param(w)
-        self.assertIn(TestHostUri+v, r['location'])
+        self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
         self._check_entity_data_values("entitynewtype", update="Updated entity")
         return
 
     def test_post_new_entity_enum_type_new_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
                 entity_id="entitynewtype", action="new", update="Updated entity", 
                 new_enum="entity_type__new_edit"
                 )
@@ -289,7 +305,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
     def test_post_edit_entity_new_view(self):
         self._create_entity_data("entitynewview")
         e1 = self._check_entity_data_values("entitynewview")
-        f  = entitydata_default_view_form_data(
+        f  = default_view_form_data(
                 entity_id="entitynewview", action="edit", update="Updated entity", 
                 new_view="New view"
                 )
@@ -299,9 +315,9 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
             )
         r  = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_view", view_id="View_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_view", view_id="View_view")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -310,10 +326,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_edit_entity_new_view_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
-            entity_id="entitynewview", action="edit", update="Updated entity", 
-            new_view="New view"
-            )
+        f = default_view_form_data(
+                entity_id="entitynewview", action="edit", update="Updated entity", 
+                new_view="New view"
+                )
         u = entitydata_edit_url(
             "edit", "testcoll", "testtype", entity_id="entitynewview", 
             view_id="Default_view"
@@ -326,7 +342,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
     def test_post_edit_entity_new_field(self):
         self._create_entity_data("entitynewfield")
         e1 = self._check_entity_data_values("entitynewfield")
-        f  = entitydata_default_view_form_data(
+        f  = default_view_form_data(
                 entity_id="entitynewfield", action="edit", update="Updated entity", 
                 new_field="New field"
                 )
@@ -336,9 +352,9 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
             )
         r  = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_field", view_id="Field_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_field", view_id="Field_view")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -347,7 +363,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_edit_entity_new_field_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
                 entity_id="entitynewfield", action="edit", update="Updated entity", 
                 new_field="New field"
                 )
@@ -363,7 +379,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
     def test_post_edit_entity_new_type(self):
         self._create_entity_data("entitynewtype")
         e1 = self._check_entity_data_values("entitynewtype")
-        f  = entitydata_default_view_form_data(
+        f  = default_view_form_data(
                 entity_id="entitynewtype", action="edit", update="Updated entity", 
                 new_type="New type"
                 )
@@ -373,9 +389,9 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
             )
         r  = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -384,7 +400,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
 
     def test_post_edit_entity_new_type_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
                 entity_id="entitynewtype", action="edit", update="Updated entity", 
                 new_type="New type"
                 )
@@ -400,7 +416,7 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
     def test_post_edit_entity_enum_type_new(self):
         self._create_entity_data("entitynewtype")
         e1 = self._check_entity_data_values("entitynewtype")
-        f  = entitydata_default_view_form_data(
+        f  = default_view_form_data(
                 entity_id="entitynewtype", action="edit", update="Updated entity", 
                 new_enum="entity_type__new_edit"
                 )
@@ -410,8 +426,8 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         # v = entitydata_edit_url("new", "testcoll", "_type", view_id="Type_view")
         v = entitydata_edit_url("edit", "testcoll", "_type", "testtype", view_id="Type_view")
         w = entitydata_edit_url(
@@ -419,14 +435,14 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
             view_id="Default_view"
             )
         c = continuation_url_param(w)
-        self.assertIn(TestHostUri+v, r['location'])
+        self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
         self._check_entity_data_values("entitynewtype", update="Updated entity")
         return
 
     def test_post_edit_entity_enum_type_new_no_login(self):
         self.client.logout()
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
                 entity_id="entitynewtype", action="edit", update="Updated entity", 
                 new_enum="entity_type__new_edit"
                 )
@@ -444,10 +460,10 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
     def test_post_edit_view_enum_field_new(self):
         self._create_record_view("editview")
         self._check_record_view_values("editview")
-        f = recordview_entity_view_form_data(
+        f = view_view_form_data(
             view_id="editview", orig_id="editview", 
             action="edit", update="Updated RecordView",
-            new_enum="View_fields__3__Field_id__new_edit"
+            new_enum="View_fields__3__View_field_sel__new_edit"
             )
         u = entitydata_edit_url(
             "edit", "testcoll", "_view", 
@@ -456,16 +472,15 @@ class EntityEditEnumFieldTest(AnnalistTestCase):
         r = self.client.post(u, f)
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        # v = entitydata_edit_url("new", "testcoll", "_field", view_id="Field_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         v = entitydata_edit_url("edit", "testcoll", "_field", "Entity_comment", view_id="Field_view")
         w = entitydata_edit_url(
             "edit", "testcoll", "_view", entity_id="editview", 
             view_id="View_view"
             )
         c = continuation_url_param(w)
-        self.assertIn(TestHostUri+v, r['location'])
+        self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
         self._check_record_view_values("editview", update="Updated RecordView")
         return
