@@ -4,28 +4,31 @@ Tests for EntityData generic list view
 This test suite focuses on listing of record fields used by 
 record views and lists.  This serves two purposes:
 - it tests some additional options of the entity list logic 
-  that are not tested by the dfeault list view, and
+  that are not tested by the default list view, and
 - it tests the logic that access site-wide data in addition to
   local data.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import os
-import urlparse
-import unittest
 import logging
 log = logging.getLogger(__name__)
 
+import os
+import unittest
+
 from django.conf                    import settings
 from django.db                      import models
 from django.http                    import QueryDict
-# from django.contrib.auth.models     import User
 from django.test                    import TestCase # cf. https://docs.djangoproject.com/en/dev/topics/testing/tools/#assertions
 from django.test.client             import Client
 
+from utils.py3porting               import urlparse, urljoin
 from utils.SuppressLoggingContext   import SuppressLogging
 
 from annalist                       import layout
@@ -49,10 +52,15 @@ from annalist.views.uri_builder     import (
 from annalist.views.entitylist      import EntityGenericListView
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    test_layout,
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, init_annalist_test_coll, resetSitedata
+    )
+from .entity_testutils import (
     make_message, make_quoted_message,
     site_dir, collection_dir,
     entitydata_list_url_query,
@@ -70,20 +78,20 @@ from entity_testutils       import (
     context_list_item_field, context_list_item_field_value,
     check_field_list_context_fields,
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_dir, 
     recordtype_url,
     recordtype_create_values, 
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     recorddata_dir,  entitydata_dir,
     entity_url, entitydata_edit_url, entitydata_delete_confirm_url,
     entitydata_list_type_url, entitydata_list_all_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
-    entitydata_context_data, entitydata_form_data, entitydata_delete_confirm_form_data,
+    entitydata_delete_confirm_form_data,
     entitylist_form_data
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     make_field_choices, no_selection,
     get_site_types, get_site_types_sorted, get_site_types_linked,
     get_site_lists, get_site_lists_sorted, get_site_lists_linked,
@@ -94,7 +102,11 @@ from entity_testsitedata    import (
     get_site_field_types, get_site_field_types_sorted, 
     get_site_entities, get_site_entities_sorted,  
     )
-from entity_testlistdata    import recordlist_url
+from .entity_testlistdata import (
+    recordlist_url, 
+    num_testcoll_enumerate_all_entities, 
+    num_testcoll_all_entities_scope_all
+    )
 
 #   -----------------------------------------------------------------------------
 #
@@ -134,9 +146,15 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # resetSitedata()
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityGenericListViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        resetSitedata(scope="collections")
+        super(EntityGenericListViewTest, cls).tearDownClass()
+        resetSitedata(scope="all")
         return
 
     #   -----------------------------------------------------------------------------
@@ -171,11 +189,11 @@ class EntityGenericListViewTest(AnnalistTestCase):
             )
         actual_entity_ids = [ "%s/%s"%(e.get_type_id(), e.get_id()) for e in entity_list ]
         # log.debug("@@ actual_entity_ids: \n"+"\n".join([repr(eti) for eti in actual_entity_ids]))
-        self.assertEqual(len(actual_entity_ids), 175)    # Will change with site data
+        # self.assertEqual(len(actual_entity_ids), num_testcoll_enumerate_all_entities)    # Will change with site data
         expect_entities   = get_site_entities_sorted()
         expect_entity_ids = [ fc.id for fc in expect_entities ]
-        # log.debug("@@ actual_entity_ids: \n"+"\n".join([ repr(eti) for eti in actual_entity_ids[145:] ]))
-        # log.debug("@@ expect_entity_ids: \n"+"\n".join([ repr(eti) for eti in expect_entity_ids[145:] ]))
+        # log.info("@@ actual_entity_ids: \n"+"\n".join([ repr(eti) for eti in actual_entity_ids[145:] ]))
+        # log.info("@@ expect_entity_ids: \n"+"\n".join([ repr(eti) for eti in expect_entity_ids[145:] ]))
         self.assertEqual(actual_entity_ids, expect_entity_ids)
         return
 
@@ -193,7 +211,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Enumerate enumeration types
         entity_types_ids = [ (e.get_type_id(), e.get_id()) for e in entity_list ]
         # log.info("@@ entity_types_ids: \n"+"\n".join([repr(eti) for eti in entity_types_ids]))
-        self.assertEqual(len(entity_types_ids), 5)
+        self.assertEqual(len(entity_types_ids), 4)
         return
 
     def test_get_default_all_list(self):
@@ -224,7 +242,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
                     <a href="%(base)s/c/testcoll/d/testtype/entity1/%(cont)s">entity1</a>
                   </div>
                   <div class="view-value small-2 columns" %(tooltip2)s>
-                    <a href="/testsite/c/testcoll/d/_type/testtype/%(cont)s">RecordType testcoll/testtype</a>
+                    <a href="/testsite/c/testcoll/d/_type/testtype/%(cont)s">RecordType testcoll/_type/testtype</a>
                   </div>
                   <div class="view-value small-7 columns" %(tooltip3)s>
                     <span>Entity testcoll/testtype/entity1</span>
@@ -256,20 +274,20 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Unbound field descriptions
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 3 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_id'], 'Entity_type')
-        self.assertEqual(f2['field_id'], 'Entity_label')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f1.field_id, 'Entity_type')
+        self.assertEqual(f2.field_id, 'Entity_label')
         # Entities and bound fields
         # log.info(entities)  #@@
         entities = context_list_entities(r.context)
         self.assertEqual(len(entities), 6)
         entity_fields = (
-            [ {'entity_type_id': "_type",     'annal:id': "testtype",  'rdfs:label': "RecordType testcoll/testtype"}
-            , {'entity_type_id': "_type",     'annal:id': "testtype2", 'rdfs:label': "RecordType testcoll/testtype2"}
+            [ {'entity_type_id': "_type",     'annal:id': "testtype",  'rdfs:label': "RecordType testcoll/_type/testtype"}
+            , {'entity_type_id': "_type",     'annal:id': "testtype2", 'rdfs:label': "RecordType testcoll/_type/testtype2"}
             , {'entity_type_id': "testtype",  'annal:id': "entity1",   'rdfs:label': "Entity testcoll/testtype/entity1"}
             , {'entity_type_id': "testtype",  'annal:id': "entity2",   'rdfs:label': "Entity testcoll/testtype/entity2"}
             , {'entity_type_id': "testtype",  'annal:id': "entity3",   'rdfs:label': "Entity testcoll/testtype/entity3"}
@@ -280,13 +298,13 @@ class EntityGenericListViewTest(AnnalistTestCase):
             item_fields = context_list_item_fields(r.context, entities[eid])
             for fid in range(3):
                 item_field = item_fields[fid]
-                head_field = head_fields[0]['row_field_descs'][fid]
+                head_field = head_fields[0].description['row_field_descs'][fid]
                 # Check that row field descriptions match corresponding heading feld descriptions
                 for fkey in (
                         'field_id', 'field_name', 'field_label', 
                         'field_property_uri', 'field_render_type',
                         'field_placement', 'field_value_type'):
-                    self.assertEqual(item_field[fkey], head_field[fkey])
+                    self.assertEqual(item_field.description[fkey], head_field[fkey])
                 # Check row field values
                 fkey = field_keys[fid]
                 self.assertEqual(item_field['field_value'],    entity_fields[eid][fkey])
@@ -294,7 +312,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
         return
 
     def test_get_default_all_scope_all_list(self):
-        # List all entities in current collection and site-wiude
+        # List all entities in current collection and site-wide
         # This repeats parts of the previous test but with scope='all'
         u = entitydata_list_all_url(
             "testcoll", list_id="Default_list_all", 
@@ -318,19 +336,19 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Unbound field descriptions
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 3 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_id'], 'Entity_type')
-        self.assertEqual(f2['field_id'], 'Entity_label')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f1.field_id, 'Entity_type')
+        self.assertEqual(f2.field_id, 'Entity_label')
         # Entities and bound fields
         entities = context_list_entities(r.context)
         # listed_entities = { e['entity_id']: e for e in entities }
         # for eid in listed_entities:
         #     print "@@ eid %s"%(eid)
-        self.assertEqual(len(entities), 172)    # Will change with site data
+        self.assertEqual(len(entities), num_testcoll_all_entities_scope_all)    # Will change with site data
         return
 
     def test_get_types_list(self):
@@ -354,19 +372,19 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 3 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
         # 1st field
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f0['field_name'], 'entity_id')
+        self.assertEqual(f0.field_id,   'Entity_id')
+        self.assertEqual(f0.field_name, 'entity_id')
         # 2nd field
-        self.assertEqual(f1['field_id'], 'Type_uri')
-        self.assertEqual(f1['field_name'], 'Type_uri')
+        self.assertEqual(f1.field_id,   'Type_uri')
+        self.assertEqual(f1.field_name, 'Type_uri')
         # 3rd field
-        self.assertEqual(f2['field_id'], 'Entity_label')
-        self.assertEqual(f2['field_name'], 'Entity_label')
+        self.assertEqual(f2.field_id,   'Entity_label')
+        self.assertEqual(f2.field_name, 'Entity_label')
         # Entities
         entities   = context_list_entities(r.context)
         listed_entities = { e['entity_id']: e for e in entities }
@@ -396,19 +414,19 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
         # 1st field
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f0['field_name'], 'entity_id')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f0.field_name, 'entity_id')
         # 2nd field
-        self.assertEqual(f1['field_id'], 'Type_uri')
-        self.assertEqual(f1['field_name'], 'Type_uri')
+        self.assertEqual(f1.field_id, 'Type_uri')
+        self.assertEqual(f1.field_name, 'Type_uri')
         # 3rd field
-        self.assertEqual(f2['field_id'], 'Entity_label')
-        self.assertEqual(f2['field_name'], 'Entity_label')
+        self.assertEqual(f2.field_id, 'Entity_label')
+        self.assertEqual(f2.field_name, 'Entity_label')
         # Entities
         entities   = context_list_entities(r.context)
         listed_entities = { e['entity_id']: e for e in entities }
@@ -465,7 +483,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
             , ('Type_uri',          "Identifier",      "annal:Identifier", "Type URI")
             , ('List_choice',       "Enum_choice",     "annal:EntityRef",  "List view")
             , ('View_choice',       "View_choice",     "annal:EntityRef",  "Choose view")
-            , ('Group_field_sel',   "Enum_optional",   "annal:EntityRef",  "Field id")
+            , ('Group_field_sel',   "Enum_optional",   "annal:EntityRef",  "Field ref")
             })
         check_field_list_context_fields(self, r, field_entities)
         return
@@ -485,7 +503,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
         curi = continuation_params_url(u)
         field_params = (
             { 'base':           TestBasePath
-            , 'list_base':      urlparse.urlparse(u).path.rstrip("/")
+            , 'list_base':      urlparse(u).path.rstrip("/")
             , 'cont':           uri_params({"continuation_url": curi})
             , 'tooltip1':       "" # 'title="%s"'%r.context['fields'][0]['field_help']
             , 'tooltip2':       "" # 'title="%s"'%r.context['fields'][1]['field_help']
@@ -600,7 +618,7 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 4 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 4)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 4)
         return
 
     def test_get_fields_list_search(self):
@@ -627,15 +645,15 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 4 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 4)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 4)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
         f3 = context_view_field(r.context, 0, 3)
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_id'], 'Field_render_type')
-        self.assertEqual(f2['field_id'], 'Field_value_type')
-        self.assertEqual(f3['field_id'], 'Entity_label')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f1.field_id, 'Field_render_type')
+        self.assertEqual(f2.field_id, 'Field_value_type')
+        self.assertEqual(f3.field_id, 'Entity_label')
         # Entities
         entities = context_list_entities(r.context)
         self.assertEqual(len(entities), 7)
@@ -704,9 +722,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("new", "testcoll", layout.FIELD_TYPEID, view_id="Field_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("new", "testcoll", layout.FIELD_TYPEID, view_id="Field_view")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -719,9 +737,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll", list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url(
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url(
             "new", "testcoll", layout.FIELD_TYPEID, view_id="Field_view"
             )
         c = continuation_url_param(u, continuation_url_param(s))
@@ -737,9 +755,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url(
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url(
             "new", "testcoll", layout.FIELD_TYPEID, view_id="Field_view"
             )
         c = continuation_url_param(u)
@@ -755,12 +773,11 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         e2 = "error_head=%s"%(uri_quote_param(message.INPUT_ERROR),)
         e3 = "error_message="
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -774,9 +791,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url("copy", "testcoll", layout.FIELD_TYPEID, "field1", view_id="Field_view")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("copy", "testcoll", layout.FIELD_TYPEID, "field1")
         c = continuation_url_param(u, continuation_url_param(s))
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -787,11 +804,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll", list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url(
-            "copy", "testcoll", layout.FIELD_TYPEID, "field1", view_id="Field_view"
-            )
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("copy", "testcoll", layout.FIELD_TYPEID, "field1")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -802,11 +817,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url(
-            "copy", "testcoll", "testtype", "entity1", view_id="Field_view"
-            )
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("copy", "testcoll", "testtype", "entity1")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -817,13 +830,12 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         c  = "continuation_url"
-        e1 = TestHostUri + u
         e2 = "error_head=%s"%(uri_quote_param(message.INPUT_ERROR),)
         e3 = "error_message="
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         self.assertNotIn(c, r['location'])
@@ -837,12 +849,11 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "testtype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         e2 = "error_head=%s"%(uri_quote_param(message.INPUT_ERROR),)
         e3 = "error_message="
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -863,12 +874,10 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         c = continuation_url_param(u)
-        v = TestHostUri + entitydata_edit_url(
-            "edit", "testcoll", layout.FIELD_TYPEID, "field1", view_id="Field_view"
-            )
+        v = entitydata_edit_url("edit", "testcoll", layout.FIELD_TYPEID, "field1")
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
         return
@@ -878,11 +887,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll", list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_edit_url(
-            "edit", "testcoll", layout.FIELD_TYPEID, "field1", view_id="Field_view"
-            )
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_edit_url("edit", "testcoll", layout.FIELD_TYPEID, "field1")
         c = continuation_url_param(u)
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -893,12 +900,11 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         e2 = "error_head=%s"%(uri_quote_param(message.INPUT_ERROR),)
         e3 = "error_message="
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -911,12 +917,11 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", layout.FIELD_TYPEID, list_id="Field_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         e2 = "error_head=%s"%(uri_quote_param(message.INPUT_ERROR),)
         e3 = "error_message="
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -966,15 +971,14 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll", list_id="Type_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         l = r['location']
-        e1 = TestHostUri + u
         e2 = "error_head="    + uri_quote_param(message.INPUT_ERROR)
         e3 = "error_message=" + make_quoted_message(message.CANNOT_DELETE_ENTITY, 
                 type_id="_type",
                 id="sitetype"
                 )
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -984,14 +988,13 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
         e2 = "error_head="    + uri_quote_param(message.INPUT_ERROR)
         e3 = "error_message=" + make_quoted_message(message.TYPE_VALUES_FOR_DELETE, 
                 type_id="_type",
                 id="testtype"
                 )
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -1002,15 +1005,14 @@ class EntityGenericListViewTest(AnnalistTestCase):
         # log.info("entitydata_list_all_url: %s"%u)
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        e1 = TestHostUri + u
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         e2 = "error_head="    + uri_quote_param(message.INPUT_ERROR)
         e3 = "error_message=" + make_quoted_message(message.CANNOT_DELETE_ENTITY, 
                 type_id=layout.FIELD_TYPEID,
                 id="Field_comment"
                 )
-        self.assertIn(e1, r['location'])
+        self.assertIn(u,  r['location'])
         self.assertIn(e2, r['location'])
         self.assertIn(e3, r['location'])
         return
@@ -1024,10 +1026,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "testtype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + c
-        self.assertEqual(v, r['location'])
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(c, r['location'])
         return
 
     def test_post_close_no_continuation(self):
@@ -1039,9 +1040,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "testtype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + collection_view_url(coll_id="testcoll")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = collection_view_url(coll_id="testcoll")
         self.assertEqual(v, r['location'])
         return
 
@@ -1051,9 +1052,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_type_url("testcoll", "_type", list_id="View_list")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_type_url("testcoll", "_type", list_id="View_list")
         c = continuation_url_param(collection_view_url("testcoll"))
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -1065,9 +1066,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_type_url("testcoll", "_type", list_id="View_list")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_type_url("testcoll", "_type", list_id="View_list")
         c = continuation_url_param(collection_view_url("testcoll"))
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -1079,9 +1080,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "testtype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_type_url(
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_type_url(
             "testcoll", "testtype", list_id="Default_list"
             )
         c = continuation_url_param("/xyzxy/")
@@ -1102,9 +1103,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "testtype")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_type_url(
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_type_url(
             "testcoll", "testtype", list_id="Default_list"
             )
         c = continuation_url_param("/xyzxy/")
@@ -1121,9 +1122,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll", list_id="Default_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_all_url("testcoll", list_id="Type_list")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_all_url("testcoll", list_id="Type_list")
         c = continuation_url_param(collection_view_url("testcoll"))
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
@@ -1135,9 +1136,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = entitydata_list_type_url("testcoll", "_type", list_id="Type_list")
         c = continuation_url_param(collection_view_url("testcoll"))
         h = "info_head="    + uri_quote_param(message.ACTION_COMPLETED)
         m = "info_message=" + make_quoted_message(message.DEFAULT_LIST_UPDATED, 
@@ -1154,9 +1155,9 @@ class EntityGenericListViewTest(AnnalistTestCase):
         u = entitydata_list_all_url("testcoll")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        v = TestHostUri + collection_edit_url("testcoll")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        v = collection_edit_url("testcoll")
         c = continuation_url_param(u, continuation_url_param("/xyzxy/"))
         self.assertIn(v, r['location'])
         self.assertIn(c, r['location'])
