@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for EntityData list view with additional inherited bibliography data
 """
@@ -33,9 +36,11 @@ from annalist.views.uri_builder             import uri_params, uri_with_params,
 from annalist.views.entitylist              import EntityGenericListView
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
     init_annalist_test_site,
     init_annalist_test_coll,
     install_annalist_named_coll,
@@ -43,7 +48,7 @@ from init_tests             import (
     init_annalist_named_test_coll,
     resetSitedata
     )
-from entity_testutils       import (
+from .entity_testutils import (
     site_dir, collection_dir,
     site_view_url,
     collection_view_url, collection_edit_url,
@@ -59,27 +64,27 @@ from entity_testutils       import (
     check_context_field, check_context_field_value, check_context_list_field_value,
     check_field_list_context_fields,
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_dir, 
     recordtype_url,
     recordtype_create_values, 
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     recorddata_dir,  entitydata_dir,
     entity_url, entitydata_edit_url, entitydata_delete_confirm_url,
     entitydata_list_type_url, entitydata_list_all_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
-    entitydata_context_data, entitydata_form_data, entitydata_delete_confirm_form_data,
+    entitydata_delete_confirm_form_data,
     entitylist_form_data
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     make_field_choices, no_selection,
     get_site_bib_types, get_site_bib_types_sorted, get_site_bib_types_linked,
     get_site_bib_lists, get_site_bib_lists_sorted, get_site_bib_lists_linked,
     get_site_schema_types, get_site_schema_types_sorted, get_site_schema_types_linked,
     get_site_schema_lists, get_site_schema_lists_sorted, get_site_schema_lists_linked,
     )
-from entity_testlistdata    import recordlist_url
+from .entity_testlistdata import recordlist_url, num_testcoll_inherit_entities_scope_all
 
 #   -----------------------------------------------------------------------------
 #
@@ -117,9 +122,15 @@ class EntityInheritListViewTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(EntityInheritListViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        # resetSitedata()
+        super(EntityInheritListViewTest, cls).tearDownClass()
+        resetSitedata()
         return
 
     #   -----------------------------------------------------------------------------
@@ -160,19 +171,19 @@ class EntityInheritListViewTest(AnnalistTestCase):
         # Unbound field descriptions
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 3 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_id'], 'Entity_type')
-        self.assertEqual(f2['field_id'], 'Entity_label')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f1.field_id, 'Entity_type')
+        self.assertEqual(f2.field_id, 'Entity_label')
         # Entities and bound fields
         entities = context_list_entities(r.context)
-        if len(entities) != 213:
+        if len(entities) != num_testcoll_inherit_entities_scope_all:
             for e in entities:
                 log.debug("All entities: %s/%s"%(e['annal:type_id'], e['annal:id']))
-        self.assertEqual(len(entities), 226)    # Will change with site data
+        self.assertEqual(len(entities), num_testcoll_inherit_entities_scope_all)    # Will change with site data
         return
 
     def test_get_types_scope_all_list(self):
@@ -190,33 +201,19 @@ class EntityInheritListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 3 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 3)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 3)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
         # 1st field
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f0['field_name'], 'entity_id')
+        self.assertEqual(f0.field_id,   'Entity_id')
+        self.assertEqual(f0.field_name, 'entity_id')
         # 2nd field
-        self.assertEqual(f1['field_id'], 'Type_uri')
-        self.assertEqual(f1['field_name'], 'Type_uri')
+        self.assertEqual(f1.field_id,   'Type_uri')
+        self.assertEqual(f1.field_name, 'Type_uri')
         # 3rd field
-        self.assertEqual(f2['field_id'], 'Entity_label')
-        self.assertEqual(f2['field_name'], 'Entity_label')
-
-
-        # self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-        # self.assertEqual(len(head_fields[0]['row_field_descs']), 2)
-        # # 1st field
-        # f0 = context_view_field(r.context, 0, 0)
-        # self.assertEqual(f0['field_id'], 'Entity_id')
-        # self.assertEqual(f0['field_name'], 'entity_id')
-        # # 2nd field
-        # f1 = context_view_field(r.context, 0, 1)
-        # self.assertEqual(f1['field_id'], 'Entity_label')
-        # self.assertEqual(f1['field_name'], 'Entity_label')
-
-
+        self.assertEqual(f2.field_id,   'Entity_label')
+        self.assertEqual(f2.field_name, 'Entity_label')
         # Entities
         entities   = context_list_entities(r.context)
         listed_entities = { e['entity_id']: e for e in entities }
@@ -262,13 +259,13 @@ class EntityInheritListViewTest(AnnalistTestCase):
             , ('List_comment',      "Markdown",      "annal:Richtext",      "Help")
             , ('List_default_type', "Enum_optional", "annal:Type",          "Default type")
             , ('List_default_view', "Enum_optional", "annal:View",          "Default view")
-            , ('List_target_type',  "Identifier",    "annal:Identifier",    "List entity type")
+            , ('List_entity_type',  "Identifier",    "annal:Identifier",    "List entity type")
             , ('Type_label',        "Text",          "annal:Text",          "Label")
             , ('Type_comment',      "Markdown",      "annal:Richtext",      "Comment")
             , ('Type_uri',          "Identifier",    "annal:Identifier",    "Type URI")
             , ('List_choice',       "Enum_choice",   "annal:EntityRef",     "List view")
             , ('View_choice',       "View_choice",   "annal:EntityRef",     "Choose view")
-            , ('Group_field_sel',   "Enum_optional", "annal:EntityRef",     "Field id")
+            , ('Group_field_sel',   "Enum_optional", "annal:EntityRef",     "Field ref")
             })
         check_field_list_context_fields(self, r, field_entities)
         return
@@ -334,7 +331,7 @@ class EntityInheritListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 4 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 4)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 4)
         return
 
     def test_get_fields_list_search(self):
@@ -359,15 +356,15 @@ class EntityInheritListViewTest(AnnalistTestCase):
         # Fields
         head_fields = context_list_head_fields(r.context)
         self.assertEqual(len(head_fields), 1)       # One row of 4 cols..
-        self.assertEqual(len(head_fields[0]['row_field_descs']), 4)
+        self.assertEqual(len(head_fields[0].description['row_field_descs']), 4)
         f0 = context_view_field(r.context, 0, 0)
         f1 = context_view_field(r.context, 0, 1)
         f2 = context_view_field(r.context, 0, 2)
         f3 = context_view_field(r.context, 0, 3)
-        self.assertEqual(f0['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_id'], 'Field_render_type')
-        self.assertEqual(f2['field_id'], 'Field_value_type')
-        self.assertEqual(f3['field_id'], 'Entity_label')
+        self.assertEqual(f0.field_id, 'Entity_id')
+        self.assertEqual(f1.field_id, 'Field_render_type')
+        self.assertEqual(f2.field_id, 'Field_value_type')
+        self.assertEqual(f3.field_id, 'Entity_label')
         # Entities
         entities = context_list_entities(r.context)
         self.assertEqual(len(entities), 36)
@@ -400,12 +397,12 @@ class EntityInheritListViewTest(AnnalistTestCase):
                 if item_fields[0]['field_value'] == f[0]:
                     for fid in range(3):
                         item_field = item_fields[fid]
-                        head_field = head_fields[0]['row_field_descs'][fid]
+                        head_field = head_fields[0].description['row_field_descs'][fid]
                         for fkey in (
                                 'field_id', 'field_name', 'field_label', 
                                 'field_property_uri', 'field_render_type',
                                 'field_placement', 'field_value_type'):
-                            self.assertEqual(item_field[fkey], head_field[fkey])
+                            self.assertEqual(item_field.description[fkey], head_field[fkey])
                         check_context_list_field_value(self, item_field, f[fid])
                     break
             else:
@@ -454,35 +451,46 @@ class EntityInheritListViewTest(AnnalistTestCase):
         self.assertEqual(list_choices['field_value'],   "Classes")
         # Entities
         entities = context_list_entities(r.context)
-        self.assertEqual(len(entities), 27)
+        self.assertEqual(len(entities), 38)
         field_entities = (
-            { ('Audio',         'Class',    'Audio clip'                     )
-            , ('Collection',    'Class',    'Data collection'                )
-            , ('Default_type',  'Class',    'Default type'                   )
-            , ('Entity',        'Class',    'Entity'                         )
-            , ('EntityData',    'Class',    'EntityData'                     )
-            , ('EntityRoot',    'Class',    'Root entity'                    )
-            , ('Enum',          'Class',    'Enumerated type'                )
-            , ('Field',         'Class',    'Field definition'               )
-            , ('Field_group',   'Class',    'Field group'                    )
-            , ('Image',         'Class',    'Image'                          )
-            , ('List',          'Class',    'List definition'                )
-            , ('Resource',      'Class',    'Resource'                       )
-            , ('Site',          'Class',    'Annalist site'                  )
-            , ('SiteData',      'Class',    'Site data'                      )
-            , ('Type',          'Class',    'Type definition'                )
-            , ('Type_Data',     'Class',    'Type data'                      )
-            , ('Unknown_type',  'Class',    'Unknown type'                   )
-            , ('User',          'Class',    'User permissions'               )
-            , ('View',          'Class',    'View definition'                )
-            , ('Vocabulary',    'Class',    'Vocabulary namespace definition')
-            , ('Boolean',       'Datatype', 'Boolean'                        )
-            , ('EntityRef',     'Datatype', 'Local entity reference'         )
-            , ('Identifier',    'Datatype', 'Identifier'                     )
-            , ('Longtext',      'Datatype', 'Multiline text'                 )
-            , ('Placement',     'Datatype', 'Field placement'                )
-            , ('Richtext',      'Datatype', 'Rich text'                      )
-            , ('Text',          'Datatype', 'Text'                           )
+            { ('Audio',                   'Class',    'Audio clip'              )
+            , ('Collection',              'Class',    'Data collection'         )
+            , ('Default_type',            'Class',    'Default type'            )
+            , ('Entity',                  'Class',    'Entity'                  )
+            , ('EntityData',              'Class',    'EntityData'              )
+            , ('EntityRoot',              'Class',    'Root entity'             )
+            , ('Enum',                    'Class',    'Enumerated type'         )
+            , ('Enum_field_placement',    'Class',    'Field placement'         )
+            , ('Enum_list_type',          'Class',    'List type'               )
+            , ('Enum_render_type',        'Class',    'Field render type'       )
+            , ('Enum_value_mode',         'Class',    'Field value mode'        )
+            , ('Field',                   'Class',    'Field definition'        )
+            , ('Field_group',             'Class',    'Field group'             )
+            , ('Field_list',              'Class',    'Field list'              )
+            , ('Field_superproperty_uri', 'Class',    'Superproperty URI'       )
+            , ('Group_field',             'Class',    'Group field (@@deprecated)')
+            , ('Image',                   'Class',    'Image'                   )
+            , ('List',                    'Class',    'List definition'         )
+            , ('List_field',              'Class',    'List field'              )
+            , ('Metadata',                'Class',    'Metadata resource'       )
+            , ('Resource',                'Class',    'Resource'                )
+            , ('Site',                    'Class',    'Annalist site'           )
+            , ('SiteData',                'Class',    'Site data'               )
+            , ('Type',                    'Class',    'Type definition'         )
+            , ('Type_Data',               'Class',    'Type data'               )
+            , ('Type_supertype_uri',      'Class',    'Supertype URI'           )
+            , ('Unknown_type',            'Class',    'Unknown type'            )
+            , ('User',                    'Class',    'User permissions'        )
+            , ('View',                    'Class',    'View definition'         )
+            , ('View_field',              'Class',    'View field'              )
+            , ('Vocabulary',              'Class',    'Vocabulary namespace'    )
+            , ('Boolean',                 'Datatype', 'Boolean'                 )
+            , ('EntityRef',               'Datatype', 'Local entity reference'  )
+            , ('Identifier',              'Datatype', 'Identifier'              )
+            , ('Longtext',                'Datatype', 'Multiline text'          )
+            , ('Placement',               'Datatype', 'Field placement'         )
+            , ('Richtext',                'Datatype', 'Rich text'               )
+            , ('Text',                    'Datatype', 'Text'                    )
             })
         for f in field_entities:
             for eid in range(len(entities)):
