@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for views and edits that use field subproperty URIs.
 """
@@ -30,15 +33,17 @@ from annalist.models.recordview     import RecordView
 from annalist.models.recordfield    import RecordField
 from annalist.models.entitydata     import EntityData
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
     init_annalist_test_site,
     init_annalist_test_coll,
     init_annalist_named_test_coll,
     resetSitedata
     )
-from entity_testutils       import (
+from .entity_testutils import (
     collection_create_values,
     create_test_user, create_user_permissions,
     context_view_field, context_view_repeat_fields,
@@ -46,12 +51,12 @@ from entity_testutils       import (
     context_list_head_fields, context_list_item_fields,
     context_list_item_field, context_list_item_field_value
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, 
     entitydata_list_type_url,
     entitydata_value_keys, entitydata_create_values, entitydata_values, 
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_create_values, 
     )
 
@@ -81,60 +86,6 @@ class FieldSubpropertyTest(AnnalistTestCase):
             )
         # Create test type data parents
         self.testdata = RecordTypeData.create(self.testcoll, "testtype", {})
-        # #@@@@
-        # # Create test field using superproperty
-        # self.test_sup_field = RecordField.create(self.testcoll, "Test_sup_field",
-        #     { ANNAL.CURIE.type:                 "annal:Field"
-        #     , RDFS.CURIE.label:                 "Field using superproperty URI"
-        #     , RDFS.CURIE.comment:               "Field using superproperty URI"
-        #     , ANNAL.CURIE.field_render_type:    "_enum_render_type/Text"
-        #     , ANNAL.CURIE.field_value_mode:     "_enum_value_mode/Value_direct"
-        #     , ANNAL.CURIE.field_entity_type:    "test:testtype"
-        #     , ANNAL.CURIE.placeholder:          "(Test_sup_field)"
-        #     , ANNAL.CURIE.property_uri:         "test:superprop_uri"
-        #     , ANNAL.CURIE.field_placement:      "small:0,12;medium:0,6"
-        #     })
-        # self.assertTrue(self.test_sup_field is not None)
-        # # Create test field using subproperty and declaring superproperty
-        # self.test_sub_field = RecordField.create(self.testcoll, "Test_sub_field",
-        #     { ANNAL.CURIE.type:                 "annal:Field"
-        #     , RDFS.CURIE.label:                 "Field using superproperty URI"
-        #     , RDFS.CURIE.comment:               "Field using superproperty URI"
-        #     , ANNAL.CURIE.field_render_type:    "_enum_render_type/Text"
-        #     , ANNAL.CURIE.field_value_mode:     "_enum_value_mode/Value_direct"
-        #     , ANNAL.CURIE.field_entity_type:    "test:testtype"
-        #     , ANNAL.CURIE.placeholder:          "(Test_sub_field)"
-        #     , ANNAL.CURIE.property_uri:         "test:subprop_uri"
-        #     , ANNAL.CURIE.superproperty_uri:    [{"@id": "test:superprop_uri"}]
-        #     , ANNAL.CURIE.field_placement:      "small:0,12;medium:0,6"
-        #     })
-        # self.assertTrue(self.test_sub_field is not None)
-        # # Create test view using superproperty
-        # self.test_view = RecordView.create(self.testcoll, "testview",
-        #     { ANNAL.CURIE.type:         "annal:View"
-        #     , ANNAL.CURIE.uri:          "test:view"
-        #     , RDFS.CURIE.label:         "Test view label"
-        #     , RDFS.CURIE.comment:       "Test view comment"
-        #     , ANNAL.CURIE.record_type:  "test:testtype"
-        #     , ANNAL.CURIE.view_fields:
-        #       [ { ANNAL.CURIE.field_id:         layout.FIELD_TYPEID+"/Entity_id"
-        #         , ANNAL.CURIE.field_placement:  "small:0,12;medium:0,6"
-        #         }
-        #       , { ANNAL.CURIE.field_id:         layout.FIELD_TYPEID+"/Test_sup_field"
-        #         , ANNAL.CURIE.field_placement:  "small:0,12;medium:0,6"
-        #         }
-        #       ]
-        #     })
-        # self.assertTrue(self.test_view is not None)
-        # # Create test entity using subproperty
-        # self.testentity_data = EntityData.create(self.testdata, "testentity", 
-        #     entitydata_create_values(
-        #         "testentity", type_id="testtype",
-        #         type_uri="test:testtype",
-        #         extra_fields={"test:subprop_uri": "Test field value"} 
-        #         )
-        #     )
-        # #@@@@
         # Login and permissions
         create_test_user(self.testcoll, "testuser", "testpassword")
         self.client = Client(HTTP_HOST=TestHost)
@@ -146,6 +97,17 @@ class FieldSubpropertyTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(FieldSubpropertyTest, cls).setUpClass()
+        return
+
+    @classmethod
+    def tearDownClass(cls):
+        super(FieldSubpropertyTest, cls).tearDownClass()
+        resetSitedata()
+        return
+
     def create_subproperty_field_view_entity(self):
         # Create test field using superproperty
         self.test_sup_field = RecordField.create(self.testcoll, "Test_sup_field",
@@ -176,11 +138,11 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertTrue(self.test_sub_field is not None)
         # Create test view using superproperty
         self.test_view = RecordView.create(self.testcoll, "testview",
-            { ANNAL.CURIE.type:         "annal:View"
-            , ANNAL.CURIE.uri:          "test:view"
-            , RDFS.CURIE.label:         "Test view label"
-            , RDFS.CURIE.comment:       "Test view comment"
-            , ANNAL.CURIE.record_type:  "test:testtype"
+            { ANNAL.CURIE.type:             "annal:View"
+            , ANNAL.CURIE.uri:              "test:view"
+            , RDFS.CURIE.label:             "Test view label"
+            , RDFS.CURIE.comment:           "Test view comment"
+            , ANNAL.CURIE.view_entity_type: "test:testtype"
             , ANNAL.CURIE.view_fields:
               [ { ANNAL.CURIE.field_id:         layout.FIELD_TYPEID+"/Entity_id"
                 , ANNAL.CURIE.field_placement:  "small:0,12;medium:0,6"
@@ -250,11 +212,11 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertTrue(self.test_sub_set is not None)
         # Create test view using superproperty
         self.test_view = RecordView.create(self.testcoll, "testsetview",
-            { ANNAL.CURIE.type:         "annal:View"
-            , ANNAL.CURIE.uri:          "test:setview"
-            , RDFS.CURIE.label:         "Test setview label"
-            , RDFS.CURIE.comment:       "Test setview comment"
-            , ANNAL.CURIE.record_type:  "test:testtype"
+            { ANNAL.CURIE.type:             "annal:View"
+            , ANNAL.CURIE.uri:              "test:setview"
+            , RDFS.CURIE.label:             "Test setview label"
+            , RDFS.CURIE.comment:           "Test setview comment"
+            , ANNAL.CURIE.view_entity_type: "test:testtype"
             , ANNAL.CURIE.view_fields:
               [ { ANNAL.CURIE.field_id:         layout.FIELD_TYPEID+"/Entity_id"
                 , ANNAL.CURIE.field_placement:  "small:0,12;medium:0,6"
@@ -327,11 +289,11 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertTrue(self.test_sub_list is not None)
         # Create test view using superproperty
         self.test_view = RecordView.create(self.testcoll, "testlistview",
-            { ANNAL.CURIE.type:         "annal:View"
-            , ANNAL.CURIE.uri:          "test:listview"
-            , RDFS.CURIE.label:         "Test listview label"
-            , RDFS.CURIE.comment:       "Test listview comment"
-            , ANNAL.CURIE.record_type:  "test:testtype"
+            { ANNAL.CURIE.type:             "annal:View"
+            , ANNAL.CURIE.uri:              "test:listview"
+            , RDFS.CURIE.label:             "Test listview label"
+            , RDFS.CURIE.comment:           "Test listview comment"
+            , ANNAL.CURIE.view_entity_type: "test:testtype"
             , ANNAL.CURIE.view_fields:
               [ { ANNAL.CURIE.field_id:         layout.FIELD_TYPEID+"/Entity_id"
                 , ANNAL.CURIE.field_placement:  "small:0,12;medium:0,6"
@@ -358,11 +320,6 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertTrue(self.testlistentity_data is not None)
         return
 
-    @classmethod
-    def tearDownClass(cls):
-        # resetSitedata()
-        return
-
     # -------------------------------------------------------------------------
     # Tests
     # -------------------------------------------------------------------------
@@ -389,54 +346,16 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertEqual(len(r.context['fields']), 2)
         # Check id field for sanity
         f1 = context_view_field(r.context, 0, 0)
-        self.assertEqual(f1['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_property_uri'], ANNAL.CURIE.id)
+        self.assertEqual(f1.field_id,           "Entity_id")
+        self.assertEqual(f1.description['field_property_uri'], ANNAL.CURIE.id)
         self.assertEqual(f1['field_value'], self.testentity_data[ANNAL.CURIE.id])
         # Check superproperty field value
         f2 = context_view_field(r.context, 1, 0)
-        self.assertEqual(f2['field_id'], 'Test_sup_field')
-        self.assertEqual(f2['field_property_uri'], "test:superprop_uri")
+        self.assertEqual(f2.field_id,           "Test_sup_field")
+        self.assertEqual(f2.description['field_property_uri'], "test:superprop_uri")
         self.assertEqual(f2['field_value'], self.testentity_data["test:subprop_uri"])
         return
 
-    # def test_list_field_alias(self):
-    #     # List BibEntry fields in Default_list
-    #     u = entitydata_list_type_url("testcoll", "testtype", list_id="Default_list")
-    #     r = self.client.get(u)
-    #     self.assertEqual(r.status_code,   200)
-    #     self.assertEqual(r.reason_phrase, "OK")
-    #     # log.info(r.content) #@@
-    #     # Test context
-    #     self.assertEqual(r.context['coll_id'],  "testcoll")
-    #     self.assertEqual(r.context['type_id'],  "testtype")
-    #     self.assertEqual(r.context['list_choices']['field_value'], "Default_list")
-    #     # Fields
-    #     head_fields = context_list_head_fields(r.context)
-    #     self.assertEqual(len(head_fields), 1)       # One row of 2 cols..
-    #     self.assertEqual(len(head_fields[0]['row_field_descs']), 2)
-    #     f0 = context_view_field(r.context, 0, 0)
-    #     f1 = context_view_field(r.context, 0, 1)
-    #     # 1st field
-    #     self.assertEqual(f0['field_id'], 'Entity_id')
-    #     self.assertEqual(f0['field_property_uri'], "annal:id")
-    #     self.assertEqual(f0['field_value'], "")
-    #     # 2nd field
-    #     self.assertEqual(f1['field_id'], 'Entity_label')
-    #     self.assertEqual(f1['field_property_uri'], "rdfs:label")
-    #     self.assertEqual(f1['field_value'], "")
-    #     # List entities (actually, just the one)
-    #     entities = context_list_entities(r.context)
-    #     self.assertEqual(len(entities), 1)
-    #     self.assertEqual(
-    #         context_list_item_field_value(r.context, entities[0], 0), 
-    #         "testentity"
-    #         )
-    #     self.assertEqual(
-    #         context_list_item_field_value(r.context, entities[0], 1), 
-    #         self.testentity_data['bib:title']
-    #         )
-    #     return
-
     def test_save_subproperty_field(self):
         self.create_subproperty_field_view_entity()
         # Post edit form response
@@ -456,7 +375,7 @@ class FieldSubpropertyTest(AnnalistTestCase):
             })
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Check entity exists,and compare data with expected
         typeinfo = EntityTypeInfo(self.testcoll, "testtype")
         self.assertTrue(typeinfo.entityclass.exists(typeinfo.entityparent, "testentity"))
@@ -493,13 +412,13 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertEqual(len(r.context['fields']), 2)
         # Check id field for sanity
         f1 = context_view_field(r.context, 0, 0)
-        self.assertEqual(f1['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_property_uri'], ANNAL.CURIE.id)
+        self.assertEqual(f1.field_id,           "Entity_id")
+        self.assertEqual(f1.description['field_property_uri'], ANNAL.CURIE.id)
         self.assertEqual(f1['field_value'], self.testsetentity_data[ANNAL.CURIE.id])
         # Check superproperty field value
         f2    = context_view_field(r.context, 1, 0)
-        self.assertEqual(f2['field_id'], 'Test_sup_set')
-        self.assertEqual(f2['field_property_uri'], "test:superprop_uri")
+        self.assertEqual(f2.field_id,           "Test_sup_set")
+        self.assertEqual(f2.description['field_property_uri'], "test:superprop_uri")
         f2rfs = context_view_repeat_fields(r.context, f2)
         self.assertEqual(f2rfs[0][0].field_value, "Test field 1 value")
         self.assertEqual(f2rfs[1][0].field_value, "Test field 2 value")
@@ -543,7 +462,7 @@ class FieldSubpropertyTest(AnnalistTestCase):
             })
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Check entity exists,and compare data with expected
         typeinfo = EntityTypeInfo(self.testcoll, "testtype")
         self.assertTrue(typeinfo.entityclass.exists(typeinfo.entityparent, "testsetentity"))
@@ -583,13 +502,13 @@ class FieldSubpropertyTest(AnnalistTestCase):
         self.assertEqual(len(r.context['fields']), 2)
         # Check id field for sanity
         f1 = context_view_field(r.context, 0, 0)
-        self.assertEqual(f1['field_id'], 'Entity_id')
-        self.assertEqual(f1['field_property_uri'], ANNAL.CURIE.id)
+        self.assertEqual(f1.field_id,           "Entity_id")
+        self.assertEqual(f1.description['field_property_uri'], ANNAL.CURIE.id)
         self.assertEqual(f1['field_value'], self.testlistentity_data[ANNAL.CURIE.id])
         # Check superproperty field value
         f2    = context_view_field(r.context, 1, 0)
-        self.assertEqual(f2['field_id'], 'Test_sup_list')
-        self.assertEqual(f2['field_property_uri'], "test:superprop_list_uri")
+        self.assertEqual(f2.field_id,           "Test_sup_list")
+        self.assertEqual(f2.description['field_property_uri'], "test:superprop_list_uri")
         f2rfs = context_view_repeat_fields(r.context, f2)
         self.assertEqual(f2rfs[0][0].field_value, "Test field 1 value")
         self.assertEqual(f2rfs[1][0].field_value, "Test field 2 value")
@@ -633,12 +552,11 @@ class FieldSubpropertyTest(AnnalistTestCase):
             })
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Check entity exists,and compare data with expected
         typeinfo = EntityTypeInfo(self.testcoll, "testtype")
         self.assertTrue(typeinfo.entityclass.exists(typeinfo.entityparent, "testlistentity"))
         e = typeinfo.entityclass.load(typeinfo.entityparent, "testlistentity")
-        # print("@@@@ e: "+repr(e.get_values()))
         self.assertEqual(e.get_id(), "testlistentity")
         # Check superproperty value remains undefined
         self.assertEqual(e.get_values().get("test:superprop_uri", "undefined"), "undefined")
