@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests image URL display field.
 
@@ -20,7 +23,7 @@ log = logging.getLogger(__name__)
 from django.conf                    import settings
 from django.contrib.auth.models     import User
 from django.test                    import TestCase
-from django.core.urlresolvers       import resolve, reverse
+from django.urls                    import resolve, reverse
 from django.test.client             import Client
 
 from annalist                       import util
@@ -34,10 +37,16 @@ from annalist.models.recordview     import RecordView
 from annalist.models.recordfield    import RecordField
 from annalist.models.entitytypeinfo import EntityTypeInfo
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site,
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testutils import (
     create_test_user,
     create_user_permissions,
     context_view_field,
@@ -45,7 +54,7 @@ from entity_testutils       import (
     context_list_head_fields,
     context_list_item_fields
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url
     )
 
@@ -68,8 +77,7 @@ test_image_ref_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_image_view label"
     , 'rdfs:comment':               "test_image_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -152,8 +160,14 @@ class ImageReferenceTest(AnnalistTestCase):
         # resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(ImageReferenceTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(ImageReferenceTest, cls).tearDownClass()
         resetSitedata(scope="collections")
         return
 
@@ -171,14 +185,14 @@ class ImageReferenceTest(AnnalistTestCase):
         # Check display context
         self.assertEqual(len(r.context['fields']), 4)
         f0 = context_view_field(r.context, 0, 0)
-        self.assertEqual(f0.field_id,     "Entity_id")
-        self.assertEqual(f0.field_value,  "test1")
+        self.assertEqual(f0.field_id,           "Entity_id")
+        self.assertEqual(f0.field_value,        "test1")
         f1 = context_view_field(r.context, 1, 0)
-        self.assertEqual(f1.field_id,     "Entity_label")
-        self.assertEqual(f1.field_value,  "test_ref_image label")
+        self.assertEqual(f1.field_id,           "Entity_label")
+        self.assertEqual(f1.field_value,        "test_ref_image label")
         f2 = context_view_field(r.context, 2, 0)
-        self.assertEqual(f2.field_id,     "Entity_comment")
-        self.assertEqual(f2.field_value,  "test_ref_image comment")
+        self.assertEqual(f2.field_id,           "Entity_comment")
+        self.assertEqual(f2.field_value,        "test_ref_image comment")
         f3 = context_view_field(r.context, 3, 0)
         basepath = TestBasePath + "/c/testcoll/d/testreftype/"
         # print "\n*****\n"+repr(f3)+"\n*****\n"
