@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for resource import functions.
 """
@@ -15,7 +18,7 @@ log = logging.getLogger(__name__)
 from django.conf                    import settings
 from django.contrib.auth.models     import User
 from django.test                    import TestCase
-from django.core.urlresolvers       import resolve, reverse
+from django.urls                    import resolve, reverse
 from django.test.client             import Client
 
 from annalist                       import util
@@ -29,10 +32,16 @@ from annalist.models.recordview     import RecordView
 from annalist.models.recordfield    import RecordField
 from annalist.models.entitytypeinfo import EntityTypeInfo
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site,
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testutils import (
     create_test_user,
     create_user_permissions,
     context_view_field,
@@ -40,9 +49,9 @@ from entity_testutils       import (
     context_list_head_fields,
     context_list_item_fields
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, 
-    entitydata_default_view_form_data,
+    default_view_form_data,
     )
 
 #   -----------------------------------------------------------------------------
@@ -73,8 +82,7 @@ test_import_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_import_view label"
     , 'rdfs:comment':               "test_import_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -95,8 +103,7 @@ test_reference_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_reference_view label"
     , 'rdfs:comment':               "test_reference_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -133,7 +140,7 @@ test_reference_field_create_values = (
     , 'rdfs:comment':                   "test_reference_field comment"
     , 'annal:property_uri':             "test:reference"
     , 'annal:field_render_type':        "URILink"
-    , 'annal:field_value_mode':         "Value_field"
+    , 'annal:field_value_mode':         "Value_direct"
     , 'annal:field_value_type':         "annal:Identifier"
     , 'annal:field_ref_type':           "testimptype"
     , 'annal:field_ref_restriction':    "ALL"
@@ -227,8 +234,14 @@ class ImportResourceTest(AnnalistTestCase):
         # resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(ImportResourceTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(ImportResourceTest, cls).tearDownClass()
         resetSitedata(scope="collections")
         return
 
@@ -242,13 +255,13 @@ class ImportResourceTest(AnnalistTestCase):
         testobj1 = self.test_imp_type_info.get_fileobj(
             "test1", "test1res", "annal:Text", "text/plain", "wb"
             )
-        testobj1.write("Test data test1res.txt")
+        testobj1.write(b"Test data test1res.txt")
         self.assertEqual(testobj1.name, test1dir+"/test1res.txt")
         testobj1.close()
         testobj2 = self.test_imp_type_info.get_fileobj(
             "test1", "test1res", "annal:Text", "text/plain", "rb"
             )
-        self.assertEqual(testobj2.read(), "Test data test1res.txt")
+        self.assertEqual(testobj2.read(), b"Test data test1res.txt")
         testobj2.close()
         return
 
@@ -263,15 +276,16 @@ class ImportResourceTest(AnnalistTestCase):
         resource_fileobj.close()
         testobj1.close()
         # Read back both and compare
-        siteobj = open(TestBaseDir+"/README.md", "rb")
-        testobj = self.test_imp_type_info.get_fileobj(
-            "test1", "test1res", "annal:Richtext", resource_type, "rb"
-            )
-        self.assertEqual(siteobj.read(), testobj.read())
+        with open(TestBaseDir+"/README.md", "rb") as siteobj:
+            testobj = self.test_imp_type_info.get_fileobj(
+                "test1", "test1res", "annal:Richtext", resource_type, "rb"
+                )
+            self.assertEqual(siteobj.read(), testobj.read())
+            testobj.close()
         return
 
     def test_import_resource(self):
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
             entity_id="test1", type_id="testimptype", action="edit", 
             do_import="imp_field__import"
             )
@@ -281,8 +295,8 @@ class ImportResourceTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertMatch(r['location'], TestHostUri+u)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertMatch(r['location'], u)
         # Read back form following redirect
         r = self.client.get(u)
         self.assertEqual(r.status_code,   200)
@@ -300,16 +314,17 @@ class ImportResourceTest(AnnalistTestCase):
         self.assertEqual(f3.field_id,     "Test_import")
         self.assertDictionaryMatch(f3.field_value, test_import_field_value())
         # Read back and compare entity resource just created
-        siteobj = open(TestBaseDir+"/README.md", "rb")
-        testobj = self.test_imp_type_info.get_fileobj(
-            "test1", "imp_field", "annal:Richtext", "text/markdown", "rb"
-            )
-        self.assertEqual(siteobj.read(), testobj.read())
+        with open(TestBaseDir+"/README.md", "rb") as siteobj:
+            testobj = self.test_imp_type_info.get_fileobj(
+                "test1", "imp_field", "annal:Richtext", "text/markdown", "rb"
+                )
+            self.assertEqual(siteobj.read(), testobj.read())
+            testobj.close()
         return
 
     def test_reference_imported_resource(self):
         # Create imported resource (see previous test)
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
             entity_id="test1", type_id="testimptype", action="edit", 
             do_import="imp_field__import"
             )
@@ -319,7 +334,7 @@ class ImportResourceTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Display resource with reference
         u = entitydata_edit_url(
             "view", "testcoll", "testreftype", entity_id="test1", view_id="testrefview"
