@@ -2,22 +2,27 @@
 Test JSON-LD and context generation logic
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2015, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import os
-import urlparse
-import unittest
-import traceback
 import logging
 log = logging.getLogger(__name__)
 
+import os
+import unittest
+import traceback
+
 from rdflib                         import Graph, URIRef, Literal
 
 from django.test.client             import Client
 
+from utils.py3porting               import urljoin
 from utils.SuppressLoggingContext   import SuppressLogging
+from miscutils.MockHttpResources    import MockHttpFileResources, MockHttpDictResources
 
 import annalist
 from annalist                       import layout
@@ -37,38 +42,32 @@ from annalist.models.recordenum     import RecordEnumFactory
 from annalist.models.entitydata     import EntityData
 from annalist.models.entitytypeinfo import EntityTypeInfo
 
-# from annalist.views.form_utils.fieldchoice  import FieldChoice
-
-from miscutils.MockHttpResources    import MockHttpFileResources, MockHttpDictResources
-
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site,
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testutils import (
     site_dir, collection_dir,
     site_view_url, collection_view_url,
     collection_create_values,
     create_test_user
     )
-from entity_testtypedata            import (
+from .entity_testtypedata import (
     recordtype_url
     )
-from entity_testentitydata          import (
-    entity_url, entity_resource_url,
+from .entity_testentitydata import (
+    entity_url, entity_resource_url, entity_uriref,
     entitydata_list_type_url, entitydata_list_all_url
     )
-from entity_testsitedata    import (
-    # make_field_choices, no_selection,
+from .entity_testsitedata import (
     get_site_types, get_site_types_sorted, get_site_types_linked,
-    # get_site_lists, get_site_lists_sorted, get_site_lists_linked,
-    # get_site_views, get_site_views_sorted, get_site_views_linked,
-    # get_site_list_types, get_site_list_types_sorted,
-    # get_site_field_groups, get_site_field_groups_sorted, 
-    # get_site_fields, get_site_fields_sorted, 
-    # get_site_field_types, get_site_field_types_sorted, 
     )
 
-
 #   -----------------------------------------------------------------------------
 #
 #   RDF graph utilities
@@ -106,12 +105,20 @@ _test_test_vocab_create_values = (
 test_blob_vocab_create_values = (
     { "annal:type":     "annal:Vocabulary"
     , "rdfs:label":     "Vocabulary namespace for test terms"
-    , "rdfs:comment":   "Vocabulary namespace for URIs that are used internally by Annalist to identify application types and properties."
+    , "rdfs:comment":   "Vocabulary namespace for URIs that are used internally by this test."
     , "annal:uri":      "http://example.org/blob/yyy#"
     })
 
+test_image_ref_vocab_create_values = (
+    { "annal:type":     "annal:Vocabulary"
+    , "rdfs:label":     "Vocabulary namespace for image_ref"
+    , "rdfs:comment":   "Vocabulary namespace for image_ref."
+    , "annal:uri":      "http://example.org/image_ref#"
+    })
+
 test_image_ref_type_create_values = (
     { 'annal:type':                 "annal:Type"
+    , 'annal:ns_prefix':            "image_ref"
     , 'rdfs:label':                 "test_reference_type label"
     , 'rdfs:comment':               "test_reference_type comment"
     , 'annal:uri':                  "blob:type/test_reference_type"
@@ -123,8 +130,7 @@ test_image_ref_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_image_view label"
     , 'rdfs:comment':               "test_image_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -172,7 +178,7 @@ def test_ref_entity_create_values(image_uri):
 
 from rdflib.parser import InputSource
 
-class StreamInputSource(InputSource):
+class StreamInputSource_unused_(InputSource):
 
     def __init__(self, stream, system_id):
         super(StreamInputSource, self).__init__(system_id)
@@ -214,8 +220,14 @@ class JsonldContextTest(AnnalistTestCase):
         # resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(JsonldContextTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(JsonldContextTest, cls).tearDownClass()
         resetSitedata(scope="all")
         return
 
@@ -242,25 +254,25 @@ class JsonldContextTest(AnnalistTestCase):
         return self.dir_base_url(self.entity_basedir(coll_id, type_id, entity_id))
 
     def coll_url(self, coll_id):
-        return urlparse.urljoin(self.coll_baseurl(coll_id), layout.META_COLL_REF)
+        return urljoin(self.coll_baseurl(coll_id), layout.META_COLL_REF)
 
     def entity_url(self, coll_id, type_id, entity_id):
         return "file://" + self.entity_basedir(coll_id, type_id, entity_id)
 
     def resolve_coll_url(self, coll, ref):
-        coll_base    = urlparse.urljoin(self.testcoll.get_url(), layout.COLL_BASE_REF)
-        resolved_url = urlparse.urljoin(coll_base, ref)
+        coll_base    = urljoin(self.testcoll.get_url(), layout.COLL_BASE_REF)
+        resolved_url = urljoin(coll_base, ref)
         return resolved_url
 
     def scan_rdf_list(self, graph, head):
         """
         Iterate over nodes in an RDF list
         """
-        next = head
-        while (next is not None) and (next != URIRef(RDF.URI.nil)):
-            item = graph.value(subject=next, predicate=URIRef(RDF.URI.first))
+        next_item = head
+        while (next_item is not None) and (next_item != URIRef(RDF.URI.nil)):
+            item = graph.value(subject=next_item, predicate=URIRef(RDF.URI.first))
             yield item
-            next = graph.value(subject=next, predicate=URIRef(RDF.URI.rest))
+            next_item = graph.value(subject=next_item, predicate=URIRef(RDF.URI.rest))
         return
 
     def assertTripleIn(self, t, g):
@@ -281,7 +293,7 @@ class JsonldContextTest(AnnalistTestCase):
             ])
         mock_dict = {}
         for mock_ref in mock_refs:
-            mu = urlparse.urljoin(base_path, mock_ref)
+            mu = urljoin(base_path, mock_ref)
             log.debug(
                 "get_context_mock_dict: base_path %s, mock_ref %s, mu %s"%
                 (base_path, mock_ref, mu)
@@ -406,7 +418,7 @@ class JsonldContextTest(AnnalistTestCase):
         # print(g.serialize(format='turtle', indent=4))
 
         # Check the resulting graph contents
-        subj        = b #@@ entity1.get_url()
+        subj        = b
         entity_data = entity1.get_values()
         for (s, p, o) in (
             [ (subj, RDFS.URI.label,     Literal(entity_data[RDFS.CURIE.label])    )
@@ -430,7 +442,7 @@ class JsonldContextTest(AnnalistTestCase):
         s = type_vocab._read_stream()
         # print("***** s.read():   (type_vocab)")
         # print(s.read())
-        b = urlparse.urljoin(
+        b = urljoin(
                 self.collbaseurl, 
                 layout.COLL_BASE_TYPE_REF%{ 'id': type_vocab.get_id() }
                 )
@@ -443,8 +455,8 @@ class JsonldContextTest(AnnalistTestCase):
         # Check the resulting graph contents
         subj            = b
         type_vocab_data = type_vocab.get_values()
-        vocab_list_url  = urlparse.urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_list])
-        vocab_view_url  = urlparse.urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_view])
+        vocab_list_url  = urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_list])
+        vocab_view_url  = urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_view])
         for (s, p, o) in (
             [ (subj, RDF.URI.type,        URIRef(ANNAL.URI.Type)                        )
             , (subj, RDFS.URI.label,      Literal(type_vocab_data[RDFS.CURIE.label])    )
@@ -468,7 +480,7 @@ class JsonldContextTest(AnnalistTestCase):
         # Read view data as JSON-LD
         g = Graph()
         s = view_user._read_stream()
-        b = urlparse.urljoin(
+        b = urljoin(
                 self.collbaseurl, 
                 layout.COLL_BASE_VIEW_REF%{ 'id': view_user.get_id() }
                 )
@@ -480,7 +492,7 @@ class JsonldContextTest(AnnalistTestCase):
         # print(g.serialize(format='turtle', indent=4))
 
         # Check the resulting graph contents
-        subj           = b    # b #@@ view_user.get_url()
+        subj           = b
         view_user_data = view_user.get_values()
         view_uri       = ANNAL.to_uri(view_user_data[ANNAL.CURIE.uri])
         for (s, p, o) in (
@@ -491,7 +503,7 @@ class JsonldContextTest(AnnalistTestCase):
             , (subj, ANNAL.URI.type_id,     Literal(view_user_data[ANNAL.CURIE.type_id]) )
             , (subj, ANNAL.URI.uri,         URIRef(view_uri)                             )
             , (subj, ANNAL.URI.open_view,   Literal(False)                               )
-            , (subj, ANNAL.URI.record_type, URIRef(ANNAL.URI.User)                       )
+            , (subj, ANNAL.URI.view_entity_type, URIRef(ANNAL.URI.User)                       )
             ]):
             self.assertIn( (URIRef(s), URIRef(p), o), g )
         # Check field list contents
@@ -499,16 +511,16 @@ class JsonldContextTest(AnnalistTestCase):
         head   = property_value(g, URIRef(subj), ANNAL.URI.view_fields)
         items  = scan_list(g, head)
         for f in fields:
-            fi  = URIRef(urlparse.urljoin(self.collbaseurl, f[ANNAL.CURIE.field_id]))
+            fi  = URIRef(urljoin(self.collbaseurl, f[ANNAL.CURIE.field_id]))
             fp  = Literal(f[ANNAL.CURIE.field_placement])
-            fn  = items.next()
+            fn  = next(items)
             fni = property_value(g, fn, ANNAL.URI.field_id)
             fnp = property_value(g, fn, ANNAL.URI.field_placement)
             self.assertEqual(fni, fi)
             self.assertEqual(fnp, fp)
         # self.assertRaises as context manager, see http://stackoverflow.com/a/28223420/324122
         with self.assertRaises(StopIteration):
-            items.next()
+            next(items)
         return
 
     def test_jsonld_user_default(self):
@@ -523,7 +535,7 @@ class JsonldContextTest(AnnalistTestCase):
         # Read user data as JSON-LD
         g = Graph()
         s = user_default._read_stream()
-        b = urlparse.urljoin(
+        b = urljoin(
                 self.collbaseurl, 
                 layout.COLL_BASE_USER_REF%{ 'id': user_default.get_id() }
                 )
@@ -534,7 +546,7 @@ class JsonldContextTest(AnnalistTestCase):
         # print("***** g: (user_default)")
         # print(g.serialize(format='turtle', indent=4))
         # Check the resulting graph contents
-        subj              = b #@@ user_default.get_url()
+        subj              = b
         user_default_data = user_default.get_values()
         user_uri          = ANNAL.to_uri(user_default_data[ANNAL.CURIE.user_uri])
         user_perms        = user_default_data[ANNAL.CURIE.user_permission]
@@ -563,7 +575,7 @@ class JsonldContextTest(AnnalistTestCase):
         # Read user data as JSON-LD
         g = Graph()
         s = list_type_list._read_stream()
-        b = urlparse.urljoin(
+        b = urljoin(
                 self.collbaseurl,
                 layout.COLL_BASE_ENUM_REF%
                     { 'type_id': list_type_list.get_type_id()
@@ -580,7 +592,7 @@ class JsonldContextTest(AnnalistTestCase):
         # print(g.serialize(format='turtle', indent=4))
         # Check the resulting graph contents
         # @@TODO: currently have to deal here with inconsistency between file and URL layouts
-        subj                = b #@@ list_type_list.get_url()
+        subj                = b
         subj                = ( "file://" + 
               os.path.join(
                 TestBaseDir, 
@@ -606,6 +618,8 @@ class JsonldContextTest(AnnalistTestCase):
     def test_jsonld_image_ref(self):
         """
         Read image reference data as JSON-LD, and check resulting RDF triples
+
+        Also tests addition of URI value if type has a namespace prefix.
         """
         # Populate collection with record type, view and field
         imagepath = "%s/test-image.jpg"%TestBaseDir
@@ -613,6 +627,9 @@ class JsonldContextTest(AnnalistTestCase):
         test_ref_type = RecordVocab.create(
             self.testcoll, "blob", test_blob_vocab_create_values
             )
+        test_ref_type = RecordVocab.create(
+            self.testcoll, "image_ref", test_image_ref_vocab_create_values
+            )
         test_ref_type = RecordType.create(
             self.testcoll, "testreftype", test_image_ref_type_create_values
             )
@@ -642,14 +659,17 @@ class JsonldContextTest(AnnalistTestCase):
         # print("***** s.read()"+s.read())
         # s.seek(0)
         result = g.parse(source=s, publicID="file://"+b+"/", format="json-ld")
-        # print "*****"+repr(result)
+        # print("*****"+repr(result))
         # print("***** g: (ref_image)")
+        # for s in g:
+        #     print(repr(s))
         # print(g.serialize(format='turtle', indent=4))
         # Check the resulting graph contents
         subj           = self.entity_url("testcoll", "testreftype", "refentity")
         ref_image_data = ref_image.get_values()
         blobns         = makeNamespace("blob", "http://example.org/blob/yyy#", ["reference"])
         type_uri       = blobns.to_uri(ref_image_data['@type'][0]) 
+        ns_uri         = test_image_ref_vocab_create_values[ANNAL.CURIE.uri]
         for (s, p, o) in (
             [ (subj, RDF.URI.type,          URIRef(ANNAL.URI.EntityData)                 )
             , (subj, RDF.URI.type,          URIRef(type_uri)                             )
@@ -657,6 +677,7 @@ class JsonldContextTest(AnnalistTestCase):
             , (subj, RDFS.URI.comment,      Literal(ref_image_data[RDFS.CURIE.comment])  )
             , (subj, ANNAL.URI.id,          Literal(ref_image_data[ANNAL.CURIE.id])      )
             , (subj, ANNAL.URI.type_id,     Literal(ref_image_data[ANNAL.CURIE.type_id]) )
+            , (subj, ANNAL.URI.uri,         URIRef(ns_uri+"refentity")                   )
             , (subj, blobns.URI.reference,  URIRef(imageurl)                             )
             ]):
             self.assertIn( (URIRef(s), URIRef(p), o), g )
@@ -737,8 +758,8 @@ class JsonldContextTest(AnnalistTestCase):
         # Check the resulting graph contents
         subj            = TestHostUri + v.rstrip("/")
         type_vocab_data = type_vocab.get_values()
-        # vocab_list_url  = urlparse.urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_list])
-        # vocab_view_url  = urlparse.urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_view])
+        # vocab_list_url  = urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_list])
+        # vocab_view_url  = urljoin(self.collbaseurl, type_vocab_data[ANNAL.CURIE.type_view])
         vocab_list_url  = self.resolve_coll_url(self.testcoll, type_vocab_data[ANNAL.CURIE.type_list])
         vocab_view_url  = self.resolve_coll_url(self.testcoll, type_vocab_data[ANNAL.CURIE.type_view])
         for (s, p, o) in (
@@ -799,8 +820,8 @@ class JsonldContextTest(AnnalistTestCase):
         # Check the resulting graph contents
         subj          = TestHostUri + v.rstrip("/")
         type_new_data = type_new.get_values()
-        # new_list_url  = urlparse.urljoin(self.collbaseurl, type_new_data[ANNAL.CURIE.type_list])
-        # new_view_url  = urlparse.urljoin(self.collbaseurl, type_new_data[ANNAL.CURIE.type_view])
+        # new_list_url  = urljoin(self.collbaseurl, type_new_data[ANNAL.CURIE.type_list])
+        # new_view_url  = urljoin(self.collbaseurl, type_new_data[ANNAL.CURIE.type_view])
         new_list_url  = self.resolve_coll_url(self.testcoll, type_new_data[ANNAL.CURIE.type_list])
         new_view_url  = self.resolve_coll_url(self.testcoll, type_new_data[ANNAL.CURIE.type_view])
         for (s, p, o) in (
@@ -888,7 +909,7 @@ class JsonldContextTest(AnnalistTestCase):
         # print "@@ test_http_conneg_jsonld_entity1: uri %s"%u
         r = self.client.get(u, HTTP_ACCEPT="application/ld+json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         v = r['Location']
         self.assertEqual(v, TestHostUri+u+layout.ENTITY_DATA_FILE)
         r = self.client.get(v)
@@ -930,7 +951,7 @@ class JsonldContextTest(AnnalistTestCase):
         u = entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity1")
         r = self.client.get(u, HTTP_ACCEPT="application/json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         v = r['Location']
         self.assertEqual(v, TestHostUri+u+layout.ENTITY_DATA_FILE)
         r = self.client.get(v)
@@ -971,7 +992,7 @@ class JsonldContextTest(AnnalistTestCase):
         u = recordtype_url(coll_id="testcoll", type_id=type_vocab.get_id())
         r = self.client.get(u, HTTP_ACCEPT="application/ld+json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         v = r['Location']
         self.assertEqual(v, TestHostUri+u+layout.TYPE_META_FILE)
         r = self.client.get(v)
@@ -1014,18 +1035,11 @@ class JsonldContextTest(AnnalistTestCase):
         """
         Return list of entity nodes from JSON list
         """
-        #@@
-        # list_url_abs    = urlparse.urljoin(TestHostUri, list_url)
-        # list_url_query = urlparse.urlsplit(list_url).query
-        # if list_url_query != "":
-        #     list_url_query = "?" + list_url_query
-        # expect_json_url = list_url_abs + layout.ENTITY_LIST_FILE + list_url_query
-        #@@
         self.testcoll.generate_coll_jsonld_context()
         r = self.client.get(list_url, HTTP_ACCEPT="application/ld+json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        json_url = r['Location']
+        self.assertEqual(r.reason_phrase, "Found")
+        json_url = TestHostUri + r['Location']
         expect_json_url = make_resource_url(TestHostUri, list_url, layout.ENTITY_LIST_FILE)
         self.assertEqual(json_url, expect_json_url)
         r = self.client.get(json_url)
@@ -1043,7 +1057,7 @@ class JsonldContextTest(AnnalistTestCase):
         # for t in g.triples((None, None, None)):
         #     print repr(t)
         # print("*****")
-        subj = urlparse.urljoin(json_url, subj_ref)
+        subj = urljoin(json_url, subj_ref)
         for (s, p, o) in (
             [ (subj, ANNAL.URI.entity_list, None)
             ]):
@@ -1068,7 +1082,10 @@ class JsonldContextTest(AnnalistTestCase):
         (json_url, list_items) = self.get_list_json(
             list_url, subj_ref, coll_id="testcoll", type_id=None, context_path="../"
             )
-        t_uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="_type", entity_id="testtype"))
+        t_uri = urljoin(
+            json_url, 
+            entity_uriref(coll_id="testcoll", type_id="_type", entity_id="testtype")
+            )
         self.assertEqual(len(list_items), 1)
         self.assertIn(URIRef(t_uri), list_items)
         return
@@ -1084,8 +1101,14 @@ class JsonldContextTest(AnnalistTestCase):
         (json_url, list_items) = self.get_list_json(
             list_url, subj_ref, coll_id="testcoll", type_id=None, context_path=""
             )
-        t_uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="_type", entity_id="testtype"))
-        e1uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity1"))
+        t_uri = urljoin(
+            json_url, 
+            entity_uriref(coll_id="testcoll", type_id="_type", entity_id="testtype")
+            )
+        e1uri = urljoin(
+            json_url, 
+            entity_uriref(coll_id="testcoll", type_id="testtype", entity_id="entity1")
+            )
         self.assertEqual(len(list_items), 2)
         self.assertIn(URIRef(t_uri), list_items)
         self.assertIn(URIRef(e1uri), list_items)
@@ -1104,8 +1127,11 @@ class JsonldContextTest(AnnalistTestCase):
         (json_url, list_items) = self.get_list_json(
             list_url, subj_ref, coll_id="testcoll", type_id=None, context_path="../../d/"
             )
-        t_uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="_type", entity_id="testtype"))
-        e1uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity1"))
+        t_uri = urljoin(
+            json_url, 
+            entity_uriref(coll_id="testcoll", type_id="_type", entity_id="testtype")
+            )
+        e1uri = urljoin(json_url, entity_url(coll_id="testcoll", type_id="testtype", entity_id="entity1"))
         self.assertEqual(len(list_items), 1)
         self.assertIn(URIRef(t_uri), list_items)
         return
@@ -1126,12 +1152,14 @@ class JsonldContextTest(AnnalistTestCase):
         (json_url, list_items) = self.get_list_json(
             list_url, subj_ref, coll_id="testcoll", type_id=None, context_path="../"
             )
-        # print "@@ "+repr(list_items)
         expect_type_ids = get_site_types()
         expect_type_ids.add("testtype")
         self.assertEqual(len(list_items), len(expect_type_ids))
         for entity_id in expect_type_ids:
-            t_uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="_type", entity_id=entity_id))
+            t_uri = urljoin(
+                json_url, 
+                entity_uriref(coll_id="testcoll", type_id="_type", entity_id=entity_id)
+                )
             self.assertIn(URIRef(t_uri), list_items)
         return
 
@@ -1153,7 +1181,10 @@ class JsonldContextTest(AnnalistTestCase):
         expect_type_ids.add("testtype")
         self.assertEqual(len(list_items), len(expect_type_ids))
         for entity_id in expect_type_ids:
-            t_uri = urlparse.urljoin(json_url, entity_url(coll_id="testcoll", type_id="_type", entity_id=entity_id))
+            t_uri = urljoin(
+                json_url, 
+                entity_uriref(coll_id="testcoll", type_id="_type", entity_id=entity_id)
+                )
             self.assertIn(URIRef(t_uri), list_items)
         return
 
