@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for RecordType module and view
 
@@ -40,10 +43,19 @@ from annalist.models.recordlist         import RecordList
 from annalist.views.recordtypedelete        import RecordTypeDeleteConfirmedView
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site,
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testfielddesc import (
+    get_field_description, get_bound_field
+    )
+from .entity_testutils import (
     make_message, make_quoted_message,
     site_dir, collection_dir,
     site_view_url, collection_edit_url, 
@@ -56,20 +68,20 @@ from entity_testutils       import (
     context_bind_fields,
     check_context_field, check_context_field_value,
     )
-from entity_testtypedata    import (
+from .entity_testtypedata import (
     recordtype_dir,
     recordtype_coll_url, recordtype_url, recordtype_edit_url,
     recordtype_value_keys, recordtype_load_keys, 
     recordtype_create_values, recordtype_values, recordtype_read_values,
-    recordtype_entity_view_context_data, 
-    recordtype_entity_view_form_data, recordtype_delete_confirm_form_data
+    type_view_form_data, recordtype_delete_confirm_form_data,
+    type_view_context_data, 
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_list_type_url,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     get_site_types, get_site_types_sorted, get_site_types_linked,
     get_site_lists, get_site_lists_sorted, get_site_lists_linked,
     get_site_views, get_site_views_sorted, get_site_views_linked,
@@ -78,8 +90,8 @@ from entity_testsitedata    import (
     get_site_fields, get_site_fields_sorted, 
     get_site_field_types, get_site_field_types_sorted, 
     )
-from entity_testviewdata    import recordview_url
-from entity_testlistdata    import recordlist_url
+from .entity_testviewdata import recordview_url
+from .entity_testlistdata import recordlist_url
 
 #   -----------------------------------------------------------------------------
 #
@@ -123,8 +135,14 @@ class RecordTypeTest(AnnalistTestCase):
     def tearDown(self):
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(RecordTypeTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(RecordTypeTest, cls).tearDownClass()
         resetSitedata(scope="collections")
         return
 
@@ -235,7 +253,6 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self.list_options = self.no_list_id + get_site_lists_linked("testcoll")
         # For checking Location: header values...
         self.continuation_url = (
-            TestHostUri + 
             entitydata_list_type_url(coll_id="testcoll", type_id=layout.TYPE_TYPEID)
             )
         # Login and permissions
@@ -249,9 +266,15 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(RecordTypeEditViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        # resetSitedata()
+        super(RecordTypeEditViewTest, cls).tearDownClass()
+        resetSitedata()
         return
 
     #   -----------------------------------------------------------------------------
@@ -296,139 +319,38 @@ class RecordTypeEditViewTest(AnnalistTestCase):
     def _check_context_fields(self, response, 
             action="",
             type_id="", orig_type_id=None,
-            type_label="(?type_label)",
+            type_ids=None,
+            type_label=None,
+            type_descr=None,
             type_uri="(?type_uri)",
-            type_supertype_uris="",
-            type_view="Default_view",
-            type_list="Default_list"
+            type_supertype_uris=[],
+            type_view="_view/Default_view",
+            type_list="_list/Default_list",
+            type_aliases=[],
+            record_type="annal:Type",
+            update="RecordType",
+            continuation_url=None
             ):
-        # Common entity attributes
-        self.assertEqual(response.context['entity_id'],        type_id)
-        self.assertEqual(response.context['orig_id'],          orig_type_id)
-        self.assertEqual(response.context['type_id'],          layout.TYPE_TYPEID)
-        self.assertEqual(response.context['orig_type'],        layout.TYPE_TYPEID)
-        self.assertEqual(response.context['coll_id'],          'testcoll')
-        self.assertEqual(response.context['action'],           action)
-        self.assertEqual(response.context['view_id'],          'Type_view')
-        # View fields
+        expect_context = type_view_context_data(action=action,
+            coll_id="testcoll", type_entity_id=type_id, orig_id=orig_type_id,
+            type_ids=type_ids,
+            type_label=type_label,
+            type_descr=type_descr,
+            type_uri=type_uri,
+            type_supertype_uris=type_supertype_uris,
+            type_view=type_view,
+            type_list=type_list,
+            type_aliases=type_aliases,
+            record_type=record_type,
+            update=update,
+            continuation_url=continuation_url
+            )
+        actual_context = context_bind_fields(response.context)
         self.assertEqual(len(response.context['fields']), 7)
-        f0 = context_view_field(response.context, 0, 0)
-        f1 = context_view_field(response.context, 1, 0)
-        f2 = context_view_field(response.context, 2, 0)
-        f3 = context_view_field(response.context, 3, 0)
-        f4 = context_view_field(response.context, 4, 0)
-        f5 = context_view_field(response.context, 5, 0)
-        f6 = context_view_field(response.context, 5, 1)
-        # 1st field - Id
-        check_context_field(self, f0,
-            field_id=           "Type_id",
-            field_name=         "entity_id",
-            field_label=        "Type Id",
-            field_placeholder=  "(type id)",
-            field_property_uri= "annal:id",
-            field_render_type=  "EntityId",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:EntityRef",
-            field_placement=    "small-12 medium-6 columns",
-            field_value=        type_id,
-            options=            self.no_options
-            )
-        # 2nd field - Label
-        check_context_field(self, f1,
-            field_id=           "Type_label",
-            field_name=         "Type_label",
-            field_label=        "Label",
-            field_placeholder=  "(label)",
-            field_property_uri= "rdfs:label",
-            field_render_type=  "Text",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Text",
-            field_placement=    "small-12 columns",
-            field_value=        type_label,
-            options=            self.no_options
-            )
-        # 3rd field - comment
-        type_comment_placeholder = (
-            "(type description)"
-            )
-        check_context_field(self, f2,
-            field_id=           "Type_comment",
-            field_name=         "Type_comment",
-            field_label=        "Comment",
-            field_placeholder=  type_comment_placeholder,
-            field_property_uri= "rdfs:comment",
-            field_render_type=  "Markdown",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Richtext",
-            field_placement=    "small-12 columns",
-            options=            self.no_options
-            )
-        # 4th field - URI
-        type_uri_placeholder = (
-            "(Type URI or CURIE)"
-            )
-        check_context_field(self, f3,
-            field_id=           "Type_uri",
-            field_name=         "Type_uri",
-            field_label=        "Type URI",
-            field_placeholder=  type_uri_placeholder,
-            field_property_uri= "annal:uri",
-            field_render_type=  "Identifier",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Identifier",
-            field_value=        type_uri,
-            options=            self.no_options
-            )
-        # 5th field - Supertype URIs
-        type_supertype_uris_placeholder = (
-            "(Supertype URIs or CURIEs)"
-            )
-        check_context_field(self, f4,
-            field_id=           "Type_supertype_uris",
-            field_name=         "Type_supertype_uris",
-            field_label=        "Supertype URIs",
-            field_placeholder=  type_supertype_uris_placeholder,
-            field_property_uri= "annal:supertype_uri",
-            field_render_type=  "Group_Set_Row",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Type_supertype_uri",
-            field_value=        type_supertype_uris,
-            options=            self.no_options
-            )
-        # 6th field - view id
-        type_view_id_placeholder = (
-            "(view id)"
-            )
-        check_context_field(self, f5,
-            field_id=           "Type_view",
-            field_name=         "Type_view",
-            field_label=        "Default view",
-            field_placeholder=  type_view_id_placeholder,
-            field_property_uri= "annal:type_view",
-            field_render_type=  "Enum_optional",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:View",
-            field_placement=    "small-12 medium-6 columns",
-            field_value=        type_view,
-            options=            self.view_options
-            )
-        # 7th field - list id
-        type_list_id_placeholder = (
-            "(list id)"
-            )
-        check_context_field(self, f6,
-            field_id=           "Type_list",
-            field_name=         "Type_list",
-            field_label=        "Default list",
-            field_placeholder=  type_list_id_placeholder,
-            field_property_uri= "annal:type_list",
-            field_render_type=  "Enum_optional",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:List",
-            field_placement=    "small-12 medium-6 columns",
-            field_value=        type_list,
-            options=            self.list_options
-            )
+        # for i in range(7):
+        #     print("@@ act field[%d]: "%i, repr(actual_context['fields'][i]))
+        #     print("@@ exp field[%d]: "%i, repr(expect_context['fields'][i]))
+        self.assertDictionaryMatch(actual_context, expect_context)
         return
 
     #   -----------------------------------------------------------------------------
@@ -752,7 +674,9 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             action="new",
             type_id="00000001", orig_type_id=None,
             type_label="",
-            type_uri="", type_supertype_uris=""
+            type_uri="", type_supertype_uris="",
+            type_aliases="",
+            continuation_url="/xyzzy/"
             )
         return
 
@@ -779,27 +703,27 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             action="copy",
             type_id="Default_type_01", orig_type_id="Default_type",
             type_label="Default record",
-            type_uri="", type_supertype_uris=""
+            type_uri="", type_supertype_uris="",
+            type_aliases="",
+            continuation_url=""
             )
         return
 
     def test_get_copy_not_exists(self):
         u = entitydata_edit_url(
-            "copy", "testcoll", layout.TYPE_TYPEID, entity_id="notype", view_id="Type_view"
+            "copy", "testcoll", layout.TYPE_TYPEID, 
+            entity_id="notype", view_id="Type_view"
             )
         r = self.client.get(u)
         # log.info(r.content)
-        self.assertEqual(r.status_code,   404)
-        self.assertEqual(r.reason_phrase, "Not found")
-        self.assertContains(r, "<title>Annalist error</title>", status_code=404)
-        self.assertContains(r, "<h3>404: Not found</h3>", status_code=404)
-        err_label = error_label("testcoll", layout.TYPE_TYPEID, "notype")
-        msg_text  = make_message(message.ENTITY_DOES_NOT_EXIST, 
-            type_id=layout.TYPE_TYPEID, 
-            id="notype", 
-            label=err_label
+        self.check_entity_not_found_response(r, 
+            err_msg=make_message(
+                message.ENTITY_DOES_NOT_EXIST, 
+                type_id=layout.TYPE_TYPEID, 
+                id="notype", 
+                label=error_label("testcoll", layout.TYPE_TYPEID, "notype")
+                )
             )
-        self.assertContains(r, "<p>%s</p>"%msg_text, status_code=404)
         return
 
     def test_get_edit(self):
@@ -825,7 +749,9 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             action="edit",
             type_id="Default_type", orig_type_id="Default_type",
             type_label="Default record",
-            type_uri="annal:Default_type", type_supertype_uris=""
+            type_uri="annal:Default_type", type_supertype_uris="",
+            type_aliases="",
+            continuation_url=""
             )
         return
 
@@ -835,17 +761,14 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             )
         r = self.client.get(u)
         # log.info(r.content)
-        self.assertEqual(r.status_code,   404)
-        self.assertEqual(r.reason_phrase, "Not found")
-        self.assertContains(r, "<title>Annalist error</title>", status_code=404)
-        self.assertContains(r, "<h3>404: Not found</h3>", status_code=404)
-        err_label = error_label("testcoll", layout.TYPE_TYPEID, "notype")
-        msg_text  = make_message(message.ENTITY_DOES_NOT_EXIST, 
-            type_id=layout.TYPE_TYPEID, 
-            id="notype", 
-            label=err_label
+        self.check_entity_not_found_response(r, 
+            err_msg=make_message(
+                message.ENTITY_DOES_NOT_EXIST, 
+                type_id=layout.TYPE_TYPEID, 
+                id="notype", 
+                label=error_label("testcoll", layout.TYPE_TYPEID, "notype")
+                )
             )
-        self.assertContains(r, "<p>%s</p>"%msg_text, status_code=404)
         return
 
     #   -----------------------------------------------------------------------------
@@ -856,38 +779,40 @@ class RecordTypeEditViewTest(AnnalistTestCase):
 
     def test_post_new_type(self):
         self.assertFalse(RecordType.exists(self.testcoll, "newtype"))
-        f = recordtype_entity_view_form_data(
-            type_id="newtype", action="new", update="RecordType",
-            type_uri="test:type"
+        f = type_view_form_data(action="new", 
+            type_entity_id="newtype", type_entity_uri="test:type",
+            update="RecordType"
             )
         u = entitydata_edit_url("new", "testcoll", layout.TYPE_TYPEID, view_id="Type_view")
         r = self.client.post(u, f)
         # print r.content
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
         self._check_record_type_values("newtype", update="RecordType", type_uri="test:type")
         return
 
     def test_post_new_type_cancel(self):
         self.assertFalse(RecordType.exists(self.testcoll, "newtype"))
-        f = recordtype_entity_view_form_data(
-            type_id="newtype", action="new", cancel="Cancel", update="Updated RecordType"
+        f = type_view_form_data(action="new", 
+            type_entity_id="newtype", 
+            cancel="Cancel", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url("new", "testcoll", layout.TYPE_TYPEID, view_id="Type_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type still does not exist
         self.assertFalse(RecordType.exists(self.testcoll, "newtype"))
         return
 
     def test_post_new_type_missing_id(self):
-        f = recordtype_entity_view_form_data(action="new", update="RecordType")
+        f = type_view_form_data(action="new", update="RecordType")
         u = entitydata_edit_url("new", "testcoll", layout.TYPE_TYPEID, view_id="Type_view")
         r = self.client.post(u, f)
         # print r.content
@@ -897,16 +822,17 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         # Test context
         self._check_context_fields(r, 
             action="new",
-            type_id="", orig_type_id="orig_type_id",
-            type_label=None,
+            type_id="",
             type_uri=None,
             type_supertype_uris=[],
+            record_type=None
             )
         return
 
     def test_post_new_type_invalid_id(self):
-        f = recordtype_entity_view_form_data(
-            type_id="!badtype", orig_id="orig_type_id", action="new", update="RecordType"
+        f = type_view_form_data(action="new", 
+            type_entity_id="!badtype", orig_id="orig_type_id", 
+            update="RecordType"
             )
         u = entitydata_edit_url("new", "testcoll", layout.TYPE_TYPEID, view_id="Type_view")
         r = self.client.post(u, f)
@@ -917,7 +843,6 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._check_context_fields(r, 
             action="new",
             type_id="!badtype", orig_type_id="orig_type_id",
-            type_label=None,
             type_uri=None,
             type_supertype_uris=[],
             )
@@ -927,47 +852,54 @@ class RecordTypeEditViewTest(AnnalistTestCase):
 
     def test_post_copy_type(self):
         self.assertFalse(RecordType.exists(self.testcoll, "copytype"))
-        f = recordtype_entity_view_form_data(
-            type_id="copytype", 
-            orig_id="Default_type", orig_coll="_annalist_site", action="copy", 
-            update="RecordType",
-            type_uri=" test:type "  # Tests space stripping
+        f = type_view_form_data(action="copy", 
+            orig_coll="_annalist_site",
+            type_entity_id="copytype", orig_id="Default_type", 
+            type_entity_uri=" test:type ",  # Tests space stripping
+            update="RecordType"
             )
         u = entitydata_edit_url(
             "copy", "testcoll", layout.TYPE_TYPEID, entity_id="Default_type", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
-        self._check_record_type_values("copytype", update="RecordType", type_uri="test:type")
+        self._check_record_type_values(
+            "copytype", update="RecordType", type_uri="test:type"
+            )
         return
 
     def test_post_copy_type_cancel(self):
         self.assertFalse(RecordType.exists(self.testcoll, "copytype"))
-        f = recordtype_entity_view_form_data(
-            type_id="copytype", orig_id="Default_type", action="copy", cancel="Cancel", update="RecordType"
+        f = type_view_form_data(action="copy", 
+            type_entity_id="copytype", orig_id="Default_type", 
+            cancel="Cancel", 
+            update="RecordType"
             )
         u = entitydata_edit_url(
-            "copy", "testcoll", layout.TYPE_TYPEID, entity_id="Default_type", view_id="Type_view"
+            "copy", "testcoll", layout.TYPE_TYPEID, 
+            entity_id="Default_type", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that target record type still does not exist
         self.assertFalse(RecordType.exists(self.testcoll, "copytype"))
         return
 
     def test_post_copy_type_missing_id(self):
-        f = recordtype_entity_view_form_data(
-            action="copy", update="Updated RecordType"
+        f = type_view_form_data(action="copy", 
+            orig_id="Default_type",
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
-            "copy", "testcoll", layout.TYPE_TYPEID, entity_id="Default_type", view_id="Type_view"
+            "copy", "testcoll", layout.TYPE_TYPEID, 
+            entity_id="Default_type", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
@@ -976,16 +908,17 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         # Test context
         self._check_context_fields(r, 
             action="copy",
-            type_id="", orig_type_id="orig_type_id",
-            type_label=None,
+            type_id="", orig_type_id="Default_type",
             type_uri=None,
             type_supertype_uris=[],
+            update="Updated RecordType"
             )
         return
 
     def test_post_copy_type_invalid_id(self):
-        f = recordtype_entity_view_form_data(
-            type_id="!badtype", orig_id="Default_type", action="copy", update="Updated RecordType"
+        f = type_view_form_data(action="copy", 
+            type_entity_id="!badtype", orig_id="Default_type", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
             "copy", "testcoll", layout.TYPE_TYPEID, entity_id="Default_type", view_id="Type_view"
@@ -998,9 +931,9 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._check_context_fields(r, 
             action="copy",
             type_id="!badtype", orig_type_id="Default_type",
-            type_label=None,
             type_uri=None,
             type_supertype_uris=[],
+            update="Updated RecordType"
             )
         return
 
@@ -1009,16 +942,16 @@ class RecordTypeEditViewTest(AnnalistTestCase):
     def test_post_edit_type(self):
         self._create_record_type("edittype")
         self._check_record_type_values("edittype")
-        f = recordtype_entity_view_form_data(
-            type_id="edittype", orig_id="edittype", 
-            action="edit", update="Updated RecordType"
+        f = type_view_form_data(action="edit", 
+            type_entity_id="edittype", orig_id="edittype", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url("edit", "testcoll", layout.TYPE_TYPEID, entity_id="edittype", view_id="Type_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
         self._check_record_type_values("edittype", update="Updated RecordType")
         return
@@ -1032,18 +965,18 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self.assertFalse(RecordTypeData.exists(self.testcoll, "edittype2"))
         self.assertTrue(EntityData.exists(d1, "typeentity"))
         self._check_record_type_values("edittype1")
-        f = recordtype_entity_view_form_data(
-            type_id="edittype2", orig_id="edittype1", 
-            action="edit", update="Updated RecordType"
+        f = type_view_form_data(action="edit", 
+            type_entity_id="edittype2", orig_id="edittype1", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
             "edit", "testcoll", layout.TYPE_TYPEID, entity_id="edittype1", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists and old does not
         self.assertFalse(RecordType.exists(self.testcoll, "edittype1"))
         self.assertTrue(RecordType.exists(self.testcoll, "edittype2"))
@@ -1059,18 +992,19 @@ class RecordTypeEditViewTest(AnnalistTestCase):
     def test_post_edit_type_cancel(self):
         self._create_record_type("edittype")
         self._check_record_type_values("edittype")
-        f = recordtype_entity_view_form_data(
-            type_id="edittype", orig_id="edittype", 
-            action="edit", cancel="Cancel", update="Updated RecordType"
+        f = type_view_form_data(action="edit", 
+            type_entity_id="edittype", orig_id="edittype", 
+            cancel="Cancel", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
             "edit", "testcoll", layout.TYPE_TYPEID, entity_id="edittype", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that target record type still does not exist and unchanged
         self._check_record_type_values("edittype")
         return
@@ -1079,11 +1013,13 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._create_record_type("edittype")
         self._check_record_type_values("edittype")
         # Form post with ID missing
-        f = recordtype_entity_view_form_data(
-            action="edit", update="Updated RecordType"
+        f = type_view_form_data(action="edit", 
+            orig_id="edittype",
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
-            "edit", "testcoll", layout.TYPE_TYPEID, entity_id="edittype", view_id="Type_view"
+            "edit", "testcoll", layout.TYPE_TYPEID, 
+            entity_id="edittype", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
@@ -1092,10 +1028,10 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         # Test context for re-rendered form
         self._check_context_fields(r, 
             action="edit",
-            type_id="", orig_type_id="orig_type_id",
-            type_label=None,
+            type_id="", orig_type_id="edittype",
             type_uri=None,
             type_supertype_uris=[],
+            update="Updated RecordType"
             )
         # Check original data is unchanged
         self._check_record_type_values("edittype")
@@ -1105,11 +1041,13 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._create_record_type("edittype")
         self._check_record_type_values("edittype")
         # Form post with invalid ID
-        f = recordtype_entity_view_form_data(
-            type_id="!badtype", orig_id="edittype", action="edit", update="Updated RecordType"
+        f = type_view_form_data(action="edit", 
+            type_entity_id="!badtype", orig_id="edittype", 
+            update="Updated RecordType"
             )
         u = entitydata_edit_url(
-            "edit", "testcoll", layout.TYPE_TYPEID, entity_id="edittype", view_id="Type_view"
+            "edit", "testcoll", layout.TYPE_TYPEID, 
+            entity_id="edittype", view_id="Type_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   200)
@@ -1119,9 +1057,9 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._check_context_fields(r, 
             action="edit",
             type_id="!badtype", orig_type_id="edittype",
-            type_label=None,
             type_uri=None,
             type_supertype_uris=[],
+            update="Updated RecordType"
             )
         # Check original data is unchanged
         self._check_record_type_values("edittype")
@@ -1134,9 +1072,8 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._create_record_type("tasktype")
         self._check_record_type_values("tasktype")
         # Post define view+list
-        f = recordtype_entity_view_form_data(
-            type_id="tasktype",
-            type_uri="test:tasktype",
+        f = type_view_form_data(
+            type_entity_id="tasktype", type_entity_uri="test:tasktype",
             task="Define_view_list"
             )
         u = entitydata_edit_url(
@@ -1144,32 +1081,32 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
         # Check content of type, view and list
         common_vals = (
             { 'type_id':    "tasktype"
-            , 'type_label': "RecordType testcoll/tasktype"
+            , 'type_label': "RecordType testcoll/_type/tasktype"
             })
         expect_type_values = (
-            { 'annal:type':         "annal:Type"
-            , 'rdfs:label':         "RecordType testcoll/%(type_id)s"%common_vals
-            , 'annal:uri':          "test:%(type_id)s"%common_vals
-            , 'annal:type_view':    "_view/%(type_id)s"%common_vals
-            , 'annal:type_list':    "_list/%(type_id)s"%common_vals
+            { 'annal:type':                 "annal:Type"
+            , 'rdfs:label':                 "%(type_label)s"%common_vals
+            , 'annal:uri':                  "test:%(type_id)s"%common_vals
+            , 'annal:type_view':            "_view/%(type_id)s"%common_vals
+            , 'annal:type_list':            "_list/%(type_id)s"%common_vals
             })
         expect_view_values = (
-            { 'annal:type':         "annal:View"
-            , 'rdfs:label':         message.TYPE_VIEW_LABEL%common_vals
-            , 'annal:record_type':  "test:%(type_id)s"%common_vals
+            { 'annal:type':                 "annal:View"
+            , 'rdfs:label':                 message.TYPE_VIEW_LABEL%common_vals
+            , 'annal:view_entity_type':     "test:%(type_id)s"%common_vals
             })
         expect_list_values = (
-            { 'annal:type':         "annal:List"
-            , 'rdfs:label':         message.TYPE_LIST_LABEL%common_vals
-            , 'annal:default_view': "_view/%(type_id)s"%common_vals
-            , 'annal:default_type': "_type/%(type_id)s"%common_vals
-            , 'annal:record_type':  "test:%(type_id)s"%common_vals
-            , 'annal:display_type': "_enum_list_type/List"
+            { 'annal:type':                 "annal:List"
+            , 'rdfs:label':                 message.TYPE_LIST_LABEL%common_vals
+            , 'annal:default_view':         "_view/%(type_id)s"%common_vals
+            , 'annal:default_type':         "_type/%(type_id)s"%common_vals
+            , 'annal:list_entity_type':     "test:%(type_id)s"%common_vals
+            , 'annal:display_type':         "_enum_list_type/List"
             , 'annal:list_entity_selector': "'test:%(type_id)s' in [@type]"%common_vals
             })
         self.check_entity_values(layout.TYPE_TYPEID, "%(type_id)s"%common_vals, expect_type_values)
@@ -1182,9 +1119,8 @@ class RecordTypeEditViewTest(AnnalistTestCase):
         self._create_record_type("tasktype", type_uri="test:tasktype")
         self._check_record_type_values("tasktype")
         # Post define subtype
-        f = recordtype_entity_view_form_data(
-            type_id="tasktype",
-            type_uri="test:tasktype",
+        f = type_view_form_data(
+            type_entity_id="tasktype", type_entity_uri="test:tasktype",
             task="Define_subtype"
             )
         u = entitydata_edit_url(
@@ -1192,23 +1128,23 @@ class RecordTypeEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         subtype_id = "tasktype" + layout.SUFFIX_SUBTYPE
         self.assertIn(
             "/testsite/c/testcoll/v/Type_view/_type/%s/"%(subtype_id,), 
             r['location']
             )
-        self.assertEqual(r.content,       "")
+        self.assertEqual(r.content,       b"")
         # Check content of type record
         common_vals = (
             { 'coll_id':    "testcoll"
             , 'type_id':    "tasktype"
             , 'subtype_id': subtype_id
-            , 'type_label': "RecordType testcoll/tasktype"
+            , 'type_label': "RecordType testcoll/_type/tasktype"
             })
         expect_type_values = (
             { 'annal:type':             "annal:Type"
-            , 'rdfs:label':             "@@subtype of RecordType %(coll_id)s/%(type_id)s"%common_vals
+            , 'rdfs:label':             "@@subtype of %(type_label)s"%common_vals
             , 'annal:uri':              "test:%(subtype_id)s"%common_vals
             , 'annal:supertype_uri':    [{'@id': "test:%(type_id)s"%common_vals}]
             , 'annal:type_view':        "_view/Default_view"%common_vals
@@ -1255,19 +1191,18 @@ class ConfirmRecordTypeDeleteTests(AnnalistTestCase):
         u = TestHostUri + recordtype_edit_url("delete", "testcoll")
         f = recordtype_delete_confirm_form_data("deletetype")
         r = self.client.post(u, f)
-        self.assertEqual(r.status_code,     302)
-        self.assertEqual(r.reason_phrase,   "FOUND")
-        self.assertEqual(r.content,         "")
-        self.assertMatch(r['location'],    
-            "^"+TestHostUri+
-            collection_edit_url("testcoll")+
-            r"\?.*info_head=.*$"
-            )
-        self.assertMatch(r['location'],    
-            "^"+TestHostUri+
-            collection_edit_url("testcoll")+
-            r"\?.*info_message=.*deletetype.*testcoll.*$"
-            )
+        self.assertEqual(r.status_code,    302)
+        self.assertEqual(r.reason_phrase,  "Found")
+        self.assertEqual(r.content,        b"")
+        v  = collection_edit_url("testcoll")
+        e1 = "info_head="
+        e2 = "info_message="
+        e3 = "deletetype"
+        e4 = "testcoll"
+        self.assertIn(v,  r['location'])
+        self.assertIn(e1, r['location'])
+        self.assertIn(e2, r['location'])
+        self.assertIn(e3, r['location'])
         # Confirm deletion
         self.assertFalse(RecordType.exists(self.testcoll, "deletetype"))
         return
