@@ -6,17 +6,20 @@ type description sitedata files, and as such duplicates some tests covered by
 module test_entitygenericedit.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2017, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
+import logging
+log = logging.getLogger(__name__)
+
 import os
 import unittest
 import markdown
 
-import logging
-log = logging.getLogger(__name__)
-
 from django.conf                        import settings
 from django.db                          import models
 from django.http                        import QueryDict
@@ -24,6 +27,8 @@ from django.contrib.auth.models         import User
 from django.test                        import TestCase # cf. https://docs.djangoproject.com/en/dev/topics/testing/tools/#assertions
 from django.test.client                 import Client
 
+from utils.SuppressLoggingContext       import SuppressLogging
+
 from annalist.util                      import valid_id, extract_entity_id
 from annalist.identifiers               import RDF, RDFS, ANNAL
 from annalist                           import layout
@@ -38,10 +43,17 @@ from annalist.models.recordvocab        import RecordVocab
 from annalist.views.form_utils.fieldchoice  import FieldChoice
 from annalist.views.displayinfo             import apply_substitutions
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site,
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testfielddesc import get_field_description, get_bound_field
+from .entity_testutils import (
     make_message, make_quoted_message,
     site_dir, collection_dir,
     site_view_url, collection_edit_url, 
@@ -52,20 +64,20 @@ from entity_testutils       import (
     context_bind_fields,
     check_context_field, check_context_field_value,
     )
-from entity_testvocabdata    import (
+from .entity_testvocabdata import (
     recordvocab_dir,
     recordvocab_coll_url, recordvocab_url, recordvocab_edit_url,
     recordvocab_value_keys, recordvocab_load_keys, 
     recordvocab_create_values, recordvocab_values, recordvocab_read_values,
-    # recordvocab_entity_view_context_data, 
-    recordvocab_entity_view_form_data, # recordvocab_delete_confirm_form_data
+    vocab_view_context_data, 
+    vocab_view_form_data, # recordvocab_delete_confirm_form_data
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, entitydata_list_type_url,
     default_fields, default_label, default_comment, error_label,
     layout_classes
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     get_site_types, get_site_types_sorted, get_site_types_linked,
     get_site_lists, get_site_lists_sorted, get_site_lists_linked,
     get_site_views, get_site_views_sorted, get_site_views_linked,
@@ -74,8 +86,8 @@ from entity_testsitedata    import (
     get_site_fields, get_site_fields_sorted, 
     get_site_field_types, get_site_field_types_sorted, 
     )
-from entity_testviewdata    import recordview_url
-from entity_testlistdata    import recordlist_url
+from .entity_testviewdata import recordview_url
+from .entity_testlistdata import recordlist_url
 
 #   -----------------------------------------------------------------------------
 #
@@ -124,6 +136,16 @@ class RecordVocabTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    # @classmethod
+    # def setUpClass(cls):
+    #     super(zzzzzz, cls).setUpClass()
+    #     return
+
+    # @classmethod
+    # def tearDownClass(cls):
+    #     super(zzzzzz, cls).tearDownClass()
+    #     return
+
     def test_RecordVocabTest(self):
         self.assertEqual(RecordVocab.__name__, "RecordVocab", "Check RecordVocab class name")
         return
@@ -200,12 +222,13 @@ class RecordVocabEditViewTest(AnnalistTestCase):
     def setUp(self):
         init_annalist_test_site()
         self.testsite   = Site(TestBaseUri, TestBaseDir)
-        self.testcoll   = Collection.create(self.testsite, "testcoll", collection_create_values("testcoll"))
+        self.testcoll   = Collection.create(
+            self.testsite, "testcoll", collection_create_values("testcoll")
+            )
         self.annalcoll  = Collection.load(self.testsite, layout.SITEDATA_ID)
         self.no_options = [ FieldChoice('', label="(no options)") ]
         # For checking Location: header values...
         self.continuation_url = (
-            TestHostUri + 
             entitydata_list_type_url(coll_id="testcoll", type_id=layout.VOCAB_TYPEID)
             )
         # Login and permissions
@@ -220,9 +243,14 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(RecordVocabEditViewTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
-        # @@checkme@@ resetSitedata()
+        super(RecordVocabEditViewTest, cls).tearDownClass()
         return
 
     #   -----------------------------------------------------------------------------
@@ -261,101 +289,25 @@ class RecordVocabEditViewTest(AnnalistTestCase):
     def _check_context_fields(self, response, 
             action="",
             vocab_id="", orig_vocab_id=None,
-            vocab_label="(?vocab_label)",
-            vocab_uri="(?vocab_uri)",
-            vocab_seealso=[]
+            vocab_label=None,
+            vocab_descr=None,
+            vocab_uri=None,
+            vocab_seealso=[],
+            update="RecordVocab",
+            continuation_url=None
             ):
-        # Common entity attributes
-        self.assertEqual(response.context['entity_id'],    vocab_id)
-        self.assertEqual(response.context['orig_id'],      orig_vocab_id)
-        self.assertEqual(response.context['type_id'],      layout.VOCAB_TYPEID)
-        self.assertEqual(response.context['orig_type'],    layout.VOCAB_TYPEID)
-        self.assertEqual(response.context['coll_id'],      'testcoll')
-        self.assertEqual(response.context['action'],       action)
-        self.assertEqual(response.context['view_id'],      'Vocab_view')
-        # View fields
+        expect_context = vocab_view_context_data(
+            coll_id="testcoll", vocab_id=vocab_id, orig_id=orig_vocab_id, action=action, 
+            vocab_label=vocab_label,
+            vocab_descr=vocab_descr,
+            vocab_uri=vocab_uri,
+            vocab_seealso=[{"@id": v} for v in vocab_seealso],
+            update=update,
+            continuation_url=continuation_url
+            )
+        actual_context = context_bind_fields(response.context)
         self.assertEqual(len(response.context['fields']), 5)
-        f0 = context_view_field(response.context, 0, 0)
-        f1 = context_view_field(response.context, 1, 0)
-        f2 = context_view_field(response.context, 2, 0)
-        f3 = context_view_field(response.context, 3, 0)
-        f4 = context_view_field(response.context, 4, 0)
-        # 1st field - Id
-        check_context_field(self, f0,
-            field_id=           "Vocab_id",
-            field_name=         "entity_id",
-            field_label=        "Prefix",
-            field_placeholder=  "(vocabulary id)",
-            field_property_uri= "annal:id",
-            field_render_type=  "EntityId",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:EntityRef",
-            field_placement=    "small-12 medium-6 columns",
-            field_value=        vocab_id,
-            options=            self.no_options
-            )
-        # 2nd field - Label
-        check_context_field(self, f1,
-            field_id=           "Entity_label",
-            field_name=         "Entity_label",
-            field_label=        "Label",
-            field_placeholder=  "(label)",
-            field_property_uri= "rdfs:label",
-            field_render_type=  "Text",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Text",
-            field_placement=    "small-12 columns",
-            field_value=        vocab_label,
-            options=            self.no_options
-            )
-        # 3rd field - comment
-        vocab_comment_placeholder = (
-            "(description)"
-            )
-        check_context_field(self, f2,
-            field_id=           "Entity_comment",
-            field_name=         "Entity_comment",
-            field_label=        "Comment",
-            field_placeholder=  vocab_comment_placeholder,
-            field_property_uri= "rdfs:comment",
-            field_render_type=  "Markdown",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Richtext",
-            field_placement=    "small-12 columns",
-            options=            self.no_options
-            )
-        # 4th field - URI
-        vocab_uri_placeholder = (
-            "(Vocabulary namespace URI)"
-            )
-        check_context_field(self, f3,
-            field_id=           "Vocab_uri",
-            field_name=         "Vocab_uri",
-            field_label=        "Vocabulary URI",
-            field_placeholder=  vocab_uri_placeholder,
-            field_property_uri= "annal:uri",
-            field_render_type=  "URILink",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Identifier",
-            field_value=        vocab_uri,
-            options=            self.no_options
-            )
-        # 5th field - see also
-        see_also_placeholder = (
-            "(Links to further information)"
-            )
-        check_context_field(self, f4,
-            field_id=           "Entity_see_also_r",
-            field_name=         "Entity_see_also_r",
-            field_label=        "See also",
-            field_placeholder=  see_also_placeholder,
-            field_property_uri= "rdfs:seeAlso",
-            field_render_type=  "Group_Set_Row",
-            field_value_mode=   "Value_direct",
-            field_value_type=   "annal:Entity_see_also_list",
-            field_value=        [{"@id": v} for v in vocab_seealso],
-            options=            self.no_options
-            )
+        self.assertDictionaryMatch(actual_context, expect_context)
         return
 
     #   -----------------------------------------------------------------------------
@@ -450,9 +402,10 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         # Test view rendering
         # This checks for namespace prefix expansion in URL links.
         # Add test namespace
-        vocab_id     = "test_vocab"
-        vocab_curie  = "annal:test_vocab"
         annal_uri    = ANNAL.mk_uri("")
+        vocab_id     = "test_vocab"
+        vocab_curie  = "annal:"+vocab_id+"#"
+        vocab_uri    = annal_uri+vocab_id+"#"
         vocab_entity = RecordVocab.create(
             self.testcoll, vocab_id, 
             recordvocab_create_values(vocab_id=vocab_id, vocab_uri=vocab_curie)
@@ -472,8 +425,7 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             rendered_comment=markdown.markdown(apply_substitutions(r.context, default_comment)),
             vocab_id=vocab_id,
             vocab_curie=vocab_curie,
-            vocab_uri=annal_uri+vocab_id,
-            urie=annal_uri+vocab_id,
+            vocab_uri=vocab_uri,
             )
         formrow1 = """
             <div class="small-12 medium-6 columns">
@@ -487,20 +439,6 @@ class RecordVocabEditViewTest(AnnalistTestCase):
               </div>
             </div>
             """%field_vals(width=6)
-
-            #           <div class="small-12 medium-6 columns">
-            #   <div class="row view-value-row">
-            #     <div class="view-label small-12 medium-4 columns">
-            #       <span>Prefix</span>
-            #     </div>
-            #     <div class="view-value small-12 medium-8 columns">
-            # <a href="/testsite/c/testcoll/d/_vocab/test_vocab/
-            # ?continuation_url=/testsite/c/testcoll/v/Vocab_view/_vocab/test_vocab/!view">test_vocab</a>
-            #     </div>
-            #   </div>
- 
-
-
         formrow2 = """
             <div class="small-12 columns">
               <div class="row view-value-row">
@@ -567,7 +505,9 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             action="new",
             vocab_id="00000001", orig_vocab_id=None,
             vocab_label="",
-            vocab_uri=""
+            vocab_descr="",
+            vocab_uri="",
+            continuation_url="/xyzzy/"
             )
         return
 
@@ -595,27 +535,26 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             vocab_id="annal_01", orig_vocab_id="annal",
             vocab_label="Vocabulary namespace for Annalist-defined terms",
             vocab_uri="",
-            vocab_seealso=["https://github.com/gklyne/annalist/blob/master/src/annalist_root/annalist/identifiers.py"]
+            vocab_seealso=["https://github.com/gklyne/annalist/blob/master/src/annalist_root/annalist/identifiers.py"],
+            continuation_url=""
             )
         return
 
     def test_get_copy_not_exists(self):
         u = entitydata_edit_url(
-            "copy", "testcoll", layout.VOCAB_TYPEID, entity_id="novocab", view_id="Vocab_view"
+            "copy", "testcoll", layout.VOCAB_TYPEID, 
+            entity_id="novocab", view_id="Vocab_view"
             )
         r = self.client.get(u)
         # log.info(r.content)
-        self.assertEqual(r.status_code,   404)
-        self.assertEqual(r.reason_phrase, "Not found")
-        self.assertContains(r, "<title>Annalist error</title>", status_code=404)
-        self.assertContains(r, "<h3>404: Not found</h3>", status_code=404)
-        err_label = error_label("testcoll", layout.VOCAB_TYPEID, "novocab")
-        msg_text  = make_message(message.ENTITY_DOES_NOT_EXIST, 
-            id="novocab", 
-            type_id=layout.VOCAB_TYPEID,
-            label=err_label
+        self.check_entity_not_found_response(r, 
+            err_msg=make_message(
+                message.ENTITY_DOES_NOT_EXIST, 
+                type_id=layout.VOCAB_TYPEID, 
+                id="novocab", 
+                label=error_label("testcoll", layout.VOCAB_TYPEID, "novocab")
+                )
             )
-        self.assertContains(r, "<p>%s</p>"%msg_text, status_code=404)
         return
 
     def test_get_edit(self):
@@ -642,27 +581,26 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             vocab_id="annal", orig_vocab_id="annal",
             vocab_label="Vocabulary namespace for Annalist-defined terms",
             vocab_uri="http://purl.org/annalist/2014/#",
-            vocab_seealso=["https://github.com/gklyne/annalist/blob/master/src/annalist_root/annalist/identifiers.py"]
+            vocab_seealso=["https://github.com/gklyne/annalist/blob/master/src/annalist_root/annalist/identifiers.py"],
+            continuation_url=""
             )
         return
 
     def test_get_edit_not_exists(self):
         u = entitydata_edit_url(
-            "edit", "testcoll", layout.VOCAB_TYPEID, entity_id="novocab", view_id="Vocab_view"
+            "edit", "testcoll", layout.VOCAB_TYPEID, 
+            entity_id="novocab", view_id="Vocab_view"
             )
         r = self.client.get(u)
         # log.info(r.content)
-        self.assertEqual(r.status_code,   404)
-        self.assertEqual(r.reason_phrase, "Not found")
-        self.assertContains(r, "<title>Annalist error</title>", status_code=404)
-        self.assertContains(r, "<h3>404: Not found</h3>", status_code=404)
-        err_label = error_label("testcoll", layout.VOCAB_TYPEID, "novocab")
-        msg_text  = make_message(message.ENTITY_DOES_NOT_EXIST, 
-            id="novocab", 
-            type_id=layout.VOCAB_TYPEID,
-            label=err_label
+        self.check_entity_not_found_response(r, 
+            err_msg=make_message(
+                message.ENTITY_DOES_NOT_EXIST, 
+                type_id=layout.VOCAB_TYPEID, 
+                id="novocab", 
+                label=error_label("testcoll", layout.VOCAB_TYPEID, "novocab")
+                )
             )
-        self.assertContains(r, "<p>%s</p>"%msg_text, status_code=404)
         return
 
     #   -----------------------------------------------------------------------------
@@ -673,39 +611,39 @@ class RecordVocabEditViewTest(AnnalistTestCase):
 
     def test_post_new_vocab(self):
         self.assertFalse(RecordVocab.exists(self.testcoll, "newvocab"))
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="newvocab", action="new",
-            vocab_uri="test:newvocab",
+            vocab_uri="test:newvocab#",
             update="RecordVocab"
             )
         u = entitydata_edit_url("new", "testcoll", layout.VOCAB_TYPEID, view_id="Vocab_view")
         r = self.client.post(u, f)
         # print r.content
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
-        self._check_record_vocab_values("newvocab", update="RecordVocab", vocab_uri="test:newvocab")
+        self._check_record_vocab_values("newvocab", update="RecordVocab", vocab_uri="test:newvocab#")
         return
 
     def test_post_new_vocab_cancel(self):
         self.assertFalse(RecordVocab.exists(self.testcoll, "newvocab"))
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="newvocab", action="new", cancel="Cancel", update="Updated RecordVocab"
             )
         u = entitydata_edit_url("new", "testcoll", layout.VOCAB_TYPEID, view_id="Vocab_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type still does not exist
         self.assertFalse(RecordVocab.exists(self.testcoll, "newvocab"))
         return
 
     def test_post_new_vocab_missing_id(self):
-        f = recordvocab_entity_view_form_data(action="new", update="RecordVocab")
+        f = vocab_view_form_data(action="new", update="RecordVocab")
         u = entitydata_edit_url("new", "testcoll", layout.VOCAB_TYPEID, view_id="Vocab_view")
         r = self.client.post(u, f)
         # print r.content
@@ -715,14 +653,15 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         # Test context
         self._check_context_fields(r, 
             action="new",
-            vocab_id="", orig_vocab_id="orig_vocab_id",
+            vocab_id=None, orig_vocab_id="orig_vocab_id",
             vocab_label=None,
+            vocab_descr=None,
             vocab_uri=None,
             )
         return
 
     def test_post_new_vocab_invalid_id(self):
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="!badvocab", orig_id="orig_vocab_id", action="new", update="RecordVocab"
             )
         u = entitydata_edit_url("new", "testcoll", layout.VOCAB_TYPEID, view_id="Vocab_view")
@@ -735,6 +674,7 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             action="new",
             vocab_id="!badvocab", orig_vocab_id="orig_vocab_id",
             vocab_label=None,
+            vocab_descr=None,
             vocab_uri=None,
             )
         return
@@ -743,27 +683,27 @@ class RecordVocabEditViewTest(AnnalistTestCase):
 
     def test_post_copy_vocab(self):
         self.assertFalse(RecordVocab.exists(self.testcoll, "copyvocab"))
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="copyvocab", 
             orig_id="annal", orig_coll="_annalist_site", action="copy", 
             update="RecordVocab",
-            vocab_uri=" test:copyvocab "  # Tests space stripping
+            vocab_uri=" test:copyvocab# "  # Tests space stripping
             )
         u = entitydata_edit_url(
             "copy", "testcoll", layout.VOCAB_TYPEID, entity_id="annal", view_id="Vocab_view"
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
-        self._check_record_vocab_values("copyvocab", update="RecordVocab", vocab_uri="test:copyvocab")
+        self._check_record_vocab_values("copyvocab", update="RecordVocab", vocab_uri="test:copyvocab#")
         return
 
     def test_post_copy_vocab_cancel(self):
         self.assertFalse(RecordVocab.exists(self.testcoll, "copyvocab"))
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="copyvocab", orig_id="annal", action="copy", cancel="Cancel", update="RecordVocab"
             )
         u = entitydata_edit_url(
@@ -771,16 +711,19 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that target record vocab still does not exist
         self.assertFalse(RecordVocab.exists(self.testcoll, "copytype"))
         return
 
     def test_post_copy_vocab_missing_id(self):
-        f = recordvocab_entity_view_form_data(
-            action="copy", update="Updated RecordVocab"
+        self._create_record_vocab("Default_vocab")
+        f = vocab_view_form_data(
+            action="copy", 
+            orig_id="Default_vocab", 
+            update="Updated RecordVocab"
             )
         u = entitydata_edit_url(
             "copy", "testcoll", layout.VOCAB_TYPEID, entity_id="Default_vocab", view_id="Vocab_view"
@@ -792,15 +735,17 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         # Test context
         self._check_context_fields(r, 
             action="copy",
-            vocab_id="", orig_vocab_id="orig_vocab_id",
-            vocab_label=None,
-            vocab_uri=None,
+            vocab_id="", orig_vocab_id="Default_vocab",
+            update="Updated RecordVocab"
             )
         return
 
     def test_post_copy_vocab_invalid_id(self):
-        f = recordvocab_entity_view_form_data(
-            vocab_id="!badvocab", orig_id="Default_vocab", action="copy", update="Updated RecordVocab"
+        self._create_record_vocab("Default_vocab")
+        f = vocab_view_form_data(
+            action="copy", 
+            vocab_id="!badvocab", orig_id="Default_vocab", 
+            update="Updated RecordVocab"
             )
         u = entitydata_edit_url(
             "copy", "testcoll", layout.VOCAB_TYPEID, entity_id="Default_vocab", view_id="Vocab_view"
@@ -813,8 +758,7 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         self._check_context_fields(r, 
             action="copy",
             vocab_id="!badvocab", orig_vocab_id="Default_vocab",
-            vocab_label=None,
-            vocab_uri=None,
+            update="Updated RecordVocab"
             )
         return
 
@@ -823,16 +767,16 @@ class RecordVocabEditViewTest(AnnalistTestCase):
     def test_post_edit_vocab(self):
         self._create_record_vocab("editvocab")
         self._check_record_vocab_values("editvocab")
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="editvocab", orig_id="editvocab", 
             action="edit", update="Updated RecordVocab"
             )
         u = entitydata_edit_url("edit", "testcoll", layout.VOCAB_TYPEID, entity_id="editvocab", view_id="Vocab_view")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that new record type exists
         self._check_record_vocab_values("editvocab", update="Updated RecordVocab")
         return
@@ -840,7 +784,7 @@ class RecordVocabEditViewTest(AnnalistTestCase):
     def test_post_edit_vocab_cancel(self):
         self._create_record_vocab("editvocab")
         self._check_record_vocab_values("editvocab")
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="editvocab", orig_id="editvocab", 
             action="edit", cancel="Cancel", update="Updated RecordVocab"
             )
@@ -849,9 +793,9 @@ class RecordVocabEditViewTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
-        self.assertEqual(r.content,       "")
-        self.assertEqual(r['location'], self.continuation_url)
+        self.assertEqual(r.reason_phrase, "Found")
+        self.assertEqual(r.content,       b"")
+        self.assertEqual(r['location'],   self.continuation_url)
         # Check that target record type still does not exist and unchanged
         self._check_record_vocab_values("editvocab")
         return
@@ -860,8 +804,10 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         self._create_record_vocab("editvocab")
         self._check_record_vocab_values("editvocab")
         # Form post with ID missing
-        f = recordvocab_entity_view_form_data(
-            action="edit", update="Updated RecordVocab"
+        f = vocab_view_form_data(
+            action="edit",
+            orig_id="editvocab", 
+            update="Updated RecordVocab"
             )
         u = entitydata_edit_url(
             "edit", "testcoll", layout.VOCAB_TYPEID, entity_id="editvocab", view_id="Vocab_view"
@@ -873,9 +819,8 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         # Test context for re-rendered form
         self._check_context_fields(r, 
             action="edit",
-            vocab_id="", orig_vocab_id="orig_vocab_id",
-            vocab_label=None,
-            vocab_uri=None,
+            vocab_id="", orig_vocab_id="editvocab",
+            update="Updated RecordVocab"
             )
         # Check original data is unchanged
         self._check_record_vocab_values("editvocab")
@@ -885,7 +830,7 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         self._create_record_vocab("editvocab")
         self._check_record_vocab_values("editvocab")
         # Form post with invalid ID
-        f = recordvocab_entity_view_form_data(
+        f = vocab_view_form_data(
             vocab_id="!badvocab", orig_id="editvocab", action="edit", update="Updated RecordVocab"
             )
         u = entitydata_edit_url(
@@ -899,8 +844,40 @@ class RecordVocabEditViewTest(AnnalistTestCase):
         self._check_context_fields(r, 
             action="edit",
             vocab_id="!badvocab", orig_vocab_id="editvocab",
-            vocab_label=None,
-            vocab_uri=None,
+            update="Updated RecordVocab"
+            )
+        # Check original data is unchanged
+        self._check_record_vocab_values("editvocab")
+        return
+
+    def test_post_edit_vocab_invalid_uri(self):
+        self._create_record_vocab("editvocab")
+        self._check_record_vocab_values("editvocab")
+        # Form post with invalid ID
+        f = vocab_view_form_data(
+            vocab_id="editvocab", orig_id="editvocab", action="edit", 
+            update="Updated RecordVocab",
+            vocab_uri="test:uri_no_final_delimiter"
+            )
+        u = entitydata_edit_url(
+            "edit", "testcoll", layout.VOCAB_TYPEID, entity_id="editvocab", view_id="Vocab_view"
+            )
+        with SuppressLogging(logging.WARNING):
+            r = self.client.post(u, f)
+        self.assertEqual(r.status_code,   200)
+        self.assertEqual(r.reason_phrase, "OK")
+        self.assertContains(r, "<h3>%s</h3>"%(message.INPUT_VALIDATION_ERROR))
+        msg = (
+            message.RECORD_VOCAB_URI_TERM%
+                ({"id": "editvocab", "uri": "test:uri_no_final_delimiter"})
+            )
+        self.assertContains(r, '<p class="messages">%s</p>'%msg)
+        # Test context
+        self._check_context_fields(r, 
+            action="edit",
+            vocab_id="editvocab", orig_vocab_id="editvocab",
+            update="Updated RecordVocab",
+            vocab_uri="test:uri_no_final_delimiter",
             )
         # Check original data is unchanged
         self._check_record_vocab_values("editvocab")
