@@ -2,32 +2,32 @@
 Tests for text value used as URI for import object; view as hyperlink.
 
 The text value is taken to be a URI or URI reference.
-
-@@TODO: later developments should also support CURIES (cf. issue #19,
-https://github.com/gklyne/annalist/issues/19).
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
+import logging
+log = logging.getLogger(__name__)
+
 import sys
 import os
 import unittest
 import re
-from collections import OrderedDict
-
-import logging
-log = logging.getLogger(__name__)
-
-from annalist.resourcetypes                 import file_extension, file_extension_for_content_type
 
+from annalist.resourcetypes import (
+    file_extension, file_extension_for_content_type
+    )
 from annalist.views.fields.render_uri_import import (
     get_uri_import_renderer, 
     URIImportValueMapper
     )
 
-from annalist.tests.field_rendering_support import FieldRendererTestSupport
+from .field_rendering_support import FieldRendererTestSupport
 
 class UriImportRenderingTest(FieldRendererTestSupport):
 
