@@ -18,6 +18,9 @@ It is not intended to check details of web page presentation.
 (The first couple of tests also check aspects of the test site data setup.)
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
@@ -50,10 +53,16 @@ from annalist.views.fields.find_renderers   import is_repeat_field_render_type
 from annalist.views.fields.render_placement import get_placement_options
 from annalist.views.form_utils.fieldchoice  import FieldChoice, get_choice_labels
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import init_annalist_test_site, init_annalist_test_coll, resetSitedata
-from entity_testutils       import (
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
+    )
+from .init_tests import (
+    init_annalist_test_site, 
+    init_annalist_test_coll,
+    resetSitedata
+    )
+from .entity_testutils import (
     site_view_url,
     collection_view_url,
     collection_edit_url,
@@ -62,14 +71,13 @@ from entity_testutils       import (
     collection_entity_edit_url,
     create_user_permissions, create_test_user
     )
-from entity_testcolldata    import (
+from .entity_testcolldata import (
     collectiondata_url, collectiondata_resource_url,
     collectiondata_view_url, collectiondata_view_resource_url,
     collectiondata_value_keys, collectiondata_load_keys,
     collectiondata_create_values, collectiondata_values, collectiondata_read_values,
-    collectiondata_view_form_data
     )
-from entity_testsitedata    import (
+from .entity_testsitedata import (
     make_field_choices, no_selection,
     get_site_types,        get_site_types_sorted,
     get_site_lists,        get_site_lists_sorted,
@@ -104,8 +112,8 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.testsite  = Site(TestBaseUri, TestBaseDir)
         self.coll1     = Collection.load(self.testsite, "coll1")
         self.local_types = make_field_choices(
-            [ ("_type/type1", "RecordType coll1/type1")
-            , ("_type/type2", "RecordType coll1/type2")
+            [ ("_type/type1", "RecordType coll1/_type/type1")
+            , ("_type/type2", "RecordType coll1/_type/type2")
             ])
         self.local_lists = make_field_choices(
             [ ("_list/list1", "RecordList coll1/list1")
@@ -135,12 +143,17 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         return
 
     def tearDown(self):
-        # resetSitedata()
+        resetSitedata()
+        return
+
+    @classmethod
+    def setUpClass(cls):
+        super(AnnalistSiteDataTest, cls).setUpClass()
         return
 
     @classmethod
     def tearDownClass(cls):
-        # @@checkme@@  resetSitedata()
+        super(AnnalistSiteDataTest, cls).tearDownClass()
         return
 
     # --------------------------------------------------------------------------
@@ -184,7 +197,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             { u'\u2588': u"&block;"
             , u'\u2591': u"&blk14;"
             })
-        for u, e in entity_map.iteritems():
+        for u, e in entity_map.items():
             s = s.replace(u, e)
         return s
 
@@ -226,12 +239,13 @@ class AnnalistSiteDataTest(AnnalistTestCase):
                 )
             f = next(i, "(@@no value@@)")
             if f != e:
-                print "@@ Expected: %r, found %r"%(e, f)
+                # Print additional test-failure diagnostic
+                print("Expected: %r, found %r"%(e, f))
                 cols = (row_data
                         .find("div", class_="row")
                         .find_all("div", class_="columns")
                     )
-                print "@@ cols %s"%(cols,)
+                print("Cols %s"%(cols,))
             self.assertEqual(e, f, "%s != %s (%r)"%(e, f, row_expected))
         return
 
@@ -251,12 +265,14 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         trows = s.find_all("div", class_="select-row")
         self.assertEqual(len(trows), len(expect_fields))
         for i in range(len(trows)):
-            tcols = trows[i].select("div.columns div.row div.columns")
+            tcols = trows[i].select("div.small-11.columns > div.row > div.columns")
+            # print("@@@@ trows[%d]\n"%(i), trows[i].prettify())
+            # print("@@@@ tcols\n", "\n---\n".join(map(str,tcols)))
             self.assertEqual(trows[i].div.input['type'],  "checkbox")
             self.assertEqual(trows[i].div.input['name'],  "View_fields__select_fields")
             self.assertEqual(trows[i].div.input['value'], str(i))
             self.check_select_field(
-                tcols[0], "View_fields__%d__Field_id"%i, 
+                tcols[0], "View_fields__%d__View_field_sel"%i, 
                 expect_field_choices, expect_fields[i]
                 )
         return
@@ -279,28 +295,24 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.assertEqual(type_list[ANNAL.CURIE.display_type],   "_enum_list_type/List")
         self.assertEqual(type_list[ANNAL.CURIE.default_type],   "_type/"+type_id)
         self.assertEqual(type_list[ANNAL.CURIE.default_view],   "_view/"+view_id)
-        self.assertEqual(type_list[ANNAL.CURIE.record_type],    type_uri)
+        self.assertEqual(type_list[ANNAL.CURIE.list_entity_type], type_uri)
         self.assertIn(ANNAL.CURIE.list_entity_selector,         type_list)
         # Read type view description
         type_view = RecordView.load(self.coll1, view_id, altscope="all")
         self.assertEqual(type_view["@type"],                    [ANNAL.CURIE.View])
         self.assertEqual(type_view[ANNAL.CURIE.id],             view_id)
         self.assertEqual(type_view[ANNAL.CURIE.type_id],        "_view")
-        self.assertEqual(type_view[ANNAL.CURIE.record_type],    type_uri)
+        self.assertEqual(type_view[ANNAL.CURIE.view_entity_type], type_uri)
         self.assertIn(ANNAL.CURIE.open_view,                    type_view)
         # Read and check fields used in list and view displays
-        # print "@@ l: " + type_list[ANNAL.CURIE.id]
         self.check_type_fields(type_id, type_uri, type_list[ANNAL.CURIE.list_fields])
-        # print "@@ v: " + type_view[ANNAL.CURIE.id]
         self.check_type_fields(type_id, type_uri, type_view[ANNAL.CURIE.view_fields])
         return
 
     # Test consistency of field descriptions for a given type
     def check_type_fields(self, type_id, type_uri, view_fields):
-        # print "@@ t: " + type_id
         for f in view_fields:
             field_id    = extract_entity_id(f[ANNAL.CURIE.field_id])
-            # print "@@ f: " + field_id
             view_field  = RecordField.load(self.coll1, field_id, altscope="all")
             render_type = extract_entity_id(view_field[ANNAL.CURIE.field_render_type])
             value_type  = extract_entity_id(view_field[ANNAL.CURIE.field_value_type])
@@ -331,9 +343,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
                     # Check field list
                     field_list      = view_field[ANNAL.CURIE.field_fields]
                     repeat_type_uri = view_field[ANNAL.CURIE.field_value_type]
-                    # print "@@ subfields: " + repeat_type_uri
                     self.check_type_fields("_field", repeat_type_uri, field_list)
-                    # print "@@ subfields: end"
                 enum_types = (
                     [ "Type", "View", "List", "Field"
                     , "Enum", "Enum_optional"
@@ -396,7 +406,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         u = collectiondata_url(coll_id=layout.SITEDATA_ID)
         r = self.client.get(u, HTTP_ACCEPT="application/ld+json")
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         v = r['Location']
         self.assertEqual(v, TestHostUri+collection_url+layout.COLL_META_REF)
         r = self.client.get(v)
@@ -425,10 +435,10 @@ class AnnalistSiteDataTest(AnnalistTestCase):
     def test_collection_edit(self):
         u = collection_edit_url(coll_id="coll1")
         s = self.get_page(u)
-        self.assertEqual(s.h2.string, "Customize collection: Collection coll1")
+        self.assertEqual(s.h2.string, "Customize collection \u2014 Collection coll1")
         local_types_expected = make_field_choices(
-            [ ("type1", "RecordType coll1/type1")
-            , ("type2", "RecordType coll1/type2")
+            [ ("type1", "RecordType coll1/_type/type1")
+            , ("type2", "RecordType coll1/_type/type2")
             ])
         local_lists_expected = make_field_choices(
             [ ("list1", "RecordList coll1/list1")
@@ -460,17 +470,17 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         trows_expected = (
             [ [ "_list/list1",    ["list1",    "List",              "RecordList coll1/list1"] ]
             , [ "_list/list2",    ["list2",    "List",              "RecordList coll1/list2"] ]
-            , [ "_type/type1",    ["type1",    "Type",              "RecordType coll1/type1"] ]
-            , [ "_type/type2",    ["type2",    "Type",              "RecordType coll1/type2"] ]
+            , [ "_type/type1",    ["type1",    "Type",              "RecordType coll1/_type/type1"] ]
+            , [ "_type/type2",    ["type2",    "Type",              "RecordType coll1/_type/type2"] ]
             , [ "_user/testuser", ["testuser", "User permissions",  "Test User"] ]
             , [ "_view/view1",    ["view1",    "View",              "RecordView coll1/view1"] ]
             , [ "_view/view2",    ["view2",    "View",              "RecordView coll1/view2"] ]
-            , [ "type1/entity1",  ["entity1",  "RecordType coll1/type1", "Entity coll1/type1/entity1"] ]
-            , [ "type1/entity2",  ["entity2",  "RecordType coll1/type1", "Entity coll1/type1/entity2"] ]
-            , [ "type1/entity3",  ["entity3",  "RecordType coll1/type1", "Entity coll1/type1/entity3"] ]
-            , [ "type2/entity1",  ["entity1",  "RecordType coll1/type2", "Entity coll1/type2/entity1"] ]
-            , [ "type2/entity2",  ["entity2",  "RecordType coll1/type2", "Entity coll1/type2/entity2"] ]
-            , [ "type2/entity3",  ["entity3",  "RecordType coll1/type2", "Entity coll1/type2/entity3"] ]
+            , [ "type1/entity1",  ["entity1",  "RecordType coll1/_type/type1", "Entity coll1/type1/entity1"] ]
+            , [ "type1/entity2",  ["entity2",  "RecordType coll1/_type/type1", "Entity coll1/type1/entity2"] ]
+            , [ "type1/entity3",  ["entity3",  "RecordType coll1/_type/type1", "Entity coll1/type1/entity3"] ]
+            , [ "type2/entity1",  ["entity1",  "RecordType coll1/_type/type2", "Entity coll1/type2/entity1"] ]
+            , [ "type2/entity2",  ["entity2",  "RecordType coll1/_type/type2", "Entity coll1/type2/entity2"] ]
+            , [ "type2/entity3",  ["entity3",  "RecordType coll1/_type/type2", "Entity coll1/type2/entity3"] ]
             ])
         self.check_list_row_data(s, trows_expected)
         # @@TODO: check entity and type links
@@ -493,8 +503,8 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         trows_expected = (
             [ [ "_list/list1",    ["list1",    "RecordList coll1/list1"] ]
             , [ "_list/list2",    ["list2",    "RecordList coll1/list2"] ]
-            , [ "_type/type1",    ["type1",    "RecordType coll1/type1"] ]
-            , [ "_type/type2",    ["type2",    "RecordType coll1/type2"] ]
+            , [ "_type/type1",    ["type1",    "RecordType coll1/_type/type1"] ]
+            , [ "_type/type2",    ["type2",    "RecordType coll1/_type/type2"] ]
             , [ "_user/testuser", ["testuser", "Test User"] ]
             , [ "_view/view1",    ["view1",    "RecordView coll1/view1"] ]
             , [ "_view/view2",    ["view2",    "RecordView coll1/view2"] ]
@@ -552,6 +562,8 @@ class AnnalistSiteDataTest(AnnalistTestCase):
                 [ "_field",            "annal:Field",            "Field"                 ] ]
             , [ "_type/_group",            
                 [ "_group",            "annal:Field_group",      "Field group"           ] ]
+            , [ "_type/_info",             
+                [ "_info",             "annal:Information",      "General information"  ] ]
             , [ "_type/_list",             
                 [ "_list",             "annal:List",             "List"                  ] ]
             , [ "_type/_type",             
@@ -565,9 +577,9 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_type/Default_type",      
                 [ "Default_type",      "annal:Default_type",     "Default record"        ] ]
             , [ "_type/type1",             
-                [ "type1",             "(@@no value@@)",         "RecordType coll1/type1"] ]
+                [ "type1",             "(@@no value@@)",         "RecordType coll1/_type/type1"] ]
             , [ "_type/type2",             
-                [ "type2",             "(@@no value@@)",         "RecordType coll1/type2"] ]
+                [ "type2",             "(@@no value@@)",         "RecordType coll1/_type/type2"] ]
             ])
         self.check_list_row_data(s, trows_expected)
         return
@@ -601,9 +613,10 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_type_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_type_fields_sorted()
         expect_fields = (
             [ "_field/Type_id"
+            , "_field/Type_prefix"
             , "_field/Type_label"
             , "_field/Type_comment"
             , "_field/Type_uri"
@@ -627,7 +640,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "List_label", "text", None)
         self.check_input_type_value(s, "List_comment", "textarea", None)
         self.check_input_type_value(s, "List_entity_selector", "text", "'annal:Type' in [@type]")
-        self.check_input_type_value(s, "List_target_type", "text", "annal:Type")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:Type")
         self.check_select_field(
             s, "List_type", 
             self.list_types_expected, 
@@ -675,6 +688,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_list/Enum_list_all",      ["Enum_list_all",       "List enumeration values and types"  ] ]
             , [ "_list/Field_group_list",   ["Field_group_list",    "Field groups"                       ] ]
             , [ "_list/Field_list",         ["Field_list",          "Field definitions"                  ] ]
+            , [ "_list/Info_list",          ["Info_list",           "General information"                ] ]
             , [ "_list/List_list",          ["List_list",           "List definitions"                   ] ]
             , [ "_list/Type_list",          ["Type_list",           "Entity types"                       ] ]
             , [ "_list/User_list",          ["User_list",           "User permissions"                   ] ]
@@ -707,7 +721,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             "_view/Default_view"
             )
         self.check_input_type_value(s, "List_entity_selector", "text", "ALL")
-        self.check_input_type_value(s, "List_target_type", "text", "")
+        self.check_input_type_value(s, "List_entity_type", "text", "")
         self.check_select_field(s, "view_choice", self.views_expected, "_view/List_view")
         return
 
@@ -718,7 +732,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_list_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_list_fields_sorted()
         expect_fields = (
             [ "_field/List_id"
             , "_field/List_type"
@@ -727,7 +741,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , "_field/List_default_type"
             , "_field/List_default_view"
             , "_field/List_entity_selector"
-            , "_field/List_target_type"
+            , "_field/List_entity_type"
             , "_field/List_fields"
             ])
         self.check_view_fields(s, expect_fields, expect_field_choices)
@@ -745,7 +759,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "List_label", "text", None)
         self.check_input_type_value(s, "List_comment", "textarea", None)
         self.check_input_type_value(s, "List_entity_selector", "text", "'annal:List' in [@type]")
-        self.check_input_type_value(s, "List_target_type", "text", "annal:List")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:List")
         self.check_select_field(s, "List_type", self.list_types_expected, "_enum_list_type/List")
         self.check_select_field(
             s, "List_default_type", 
@@ -789,6 +803,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_view/Enum_view",          ["Enum_view",           "Enumerated value view" ] ]
             , [ "_view/Field_group_view",   ["Field_group_view",    "Field group definition"] ]
             , [ "_view/Field_view",         ["Field_view",          "Field definition"      ] ]
+            , [ "_view/Info_view",          ["Info_view",           "General information"   ] ]
             , [ "_view/List_view",          ["List_view",           "List definition"       ] ]
             , [ "_view/Type_view",          ["Type_view",           "Type definition"       ] ]
             , [ "_view/User_view",          ["User_view",           "User permissions"      ] ]
@@ -810,7 +825,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "entity_id", "text", None)
         self.check_input_type_value(s, "View_label", "text", None)
         self.check_input_type_value(s, "View_comment", "textarea", None)
-        self.check_input_type_value(s, "View_target_type", "text", None)
+        self.check_input_type_value(s, "View_entity_type", "text", None)
         self.check_input_type_value(s, "View_edit_view", "checkbox", "Yes")
         self.check_select_field(s, "view_choice", self.views_expected, "_view/View_view")
         return
@@ -822,12 +837,12 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_view_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_view_fields_sorted()
         expect_fields        = (
             [ "_field/View_id"
             , "_field/View_label"
             , "_field/View_comment"
-            , "_field/View_target_type"
+            , "_field/View_entity_type"
             , "_field/View_edit_view"
             , "_field/View_fields"
             ])
@@ -860,7 +875,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             s, "List_entity_selector", "text", "'annal:View' in [@type]"
             )
         self.check_input_type_value(
-            s, "List_target_type", "text", "annal:View"
+            s, "List_entity_type", "text", "annal:View"
             )
         return
 
@@ -907,8 +922,8 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "entity_id", "text", None)
         self.check_input_type_value(s, "Group_label", "text", None)
         self.check_input_type_value(s, "Group_comment", "textarea", None)
-        self.check_input_type_value(s, "Group_target_type", "text", None)
-        expect_field_choices = no_selection("(field sel)") + get_site_group_fields_sorted()
+        self.check_input_type_value(s, "Group_entity_type", "text", None)
+        expect_field_choices = no_selection("(field reference)") + get_site_group_fields_sorted()
         expect_fields = []
         self.check_view_fields(s, expect_fields, expect_field_choices)
         self.check_select_field(
@@ -924,12 +939,12 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_group_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_group_fields_sorted()
         expect_fields = (
             [ "_field/Group_id"
             , "_field/Group_label"
             , "_field/Group_comment"
-            , "_field/Group_target_type"
+            , "_field/Group_entity_type"
             , "_field/Group_fields"
             ])
         self.check_view_fields(s, expect_fields, expect_field_choices)
@@ -949,7 +964,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(
             s, "List_entity_selector", "text", "'annal:Field_group' in [@type]"
             )
-        self.check_input_type_value(s, "List_target_type", "text", "annal:Field_group")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:Field_group")
         self.check_select_field(s, "List_type", self.list_types_expected, "_enum_list_type/List")
         self.check_select_field(
             s, "List_default_type", 
@@ -1012,6 +1027,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_field/Entity_comment",            ["Entity_comment",    "Markdown rich text", "annal:Richtext"     ] ]
             , [ "_field/Entity_id",                 ["Entity_id",         "Entity Id",      "annal:EntityRef"        ] ]
             , [ "_field/Entity_label",              ["Entity_label",      "Short text",     "annal:Text"             ] ]
+            , [ "_field/Entity_ref",                ["Entity_ref",        "Entity Id",      "annal:EntityRef"        ] ]
             , [ "_field/Entity_see_also",           ["Entity_see_also",   "Web link",       "rdfs:Resource"          ] ]
             , [ "_field/Entity_see_also_r",         ["Entity_see_also_r", "Field group set as table", 
                                                                                         "annal:Entity_see_also_list" ] ]
@@ -1020,7 +1036,6 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_field/Enum_uri",                  ["Enum_uri",          "Identifier",     "annal:Identifier"       ] ]
             , [ "_field/Field_default",             ["Field_default",     "Short text",     "annal:Text"             ] ]
             , [ "_field/Field_entity_type",         ["Field_entity_type", "Identifier",     "annal:Identifier"       ] ]
-            , [ "_field/Field_fieldref",            ["Field_fieldref",    "Identifier",     "annal:Identifier"       ] ]
             , [ "_field/Field_fields",              ["Field_fields",      "Field group sequence as table",
                                                                                             "annal:Field_list"       ] ]
             , [ "_field/Field_groupref",            ["Field_groupref",    "Optional/new entity reference", 
@@ -1056,25 +1071,25 @@ class AnnalistSiteDataTest(AnnalistTestCase):
                                                                                             "annal:EntityRef"        ] ]
             , [ "_field/Field_value_type",          ["Field_value_type",  "Identifier",     "annal:Identifier"       ] ]
             , [ "_field/Group_comment",             ["Group_comment"             ] ]
+            , [ "_field/Group_entity_type",         ["Group_entity_type"         ] ]
             , [ "_field/Group_field_placement",     ["Group_field_placement"     ] ]
             , [ "_field/Group_field_property",      ["Group_field_property"      ] ]
             , [ "_field/Group_field_sel",           ["Group_field_sel"           ] ]
             , [ "_field/Group_fields",              ["Group_fields"              ] ]
             , [ "_field/Group_id",                  ["Group_id"                  ] ]
             , [ "_field/Group_label",               ["Group_label"               ] ]
-            , [ "_field/Group_target_type",         ["Group_target_type"         ] ]
             , [ "_field/List_choice",               ["List_choice"               ] ]
             , [ "_field/List_comment",              ["List_comment"              ] ]
             , [ "_field/List_default_type",         ["List_default_type"         ] ]
             , [ "_field/List_default_view",         ["List_default_view"         ] ]
             , [ "_field/List_entity_selector",      ["List_entity_selector"      ] ]
+            , [ "_field/List_entity_type",          ["List_entity_type"          ] ]
             , [ "_field/List_field_placement",      ["List_field_placement"      ] ]
             , [ "_field/List_field_property",       ["List_field_property"       ] ]
             , [ "_field/List_field_sel",            ["List_field_sel"            ] ]
             , [ "_field/List_fields",               ["List_fields"               ] ]
             , [ "_field/List_id",                   ["List_id"                   ] ]
             , [ "_field/List_label",                ["List_label"                ] ]
-            , [ "_field/List_target_type",          ["List_target_type"          ] ]
             , [ "_field/List_type",                 ["List_type"                 ] ]
             , [ "_field/Type_alias_source",         ["Type_alias_source"         ] ]
             , [ "_field/Type_alias_target",         ["Type_alias_target"         ] ]
@@ -1083,6 +1098,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_field/Type_id",                   ["Type_id"                   ] ]
             , [ "_field/Type_label",                ["Type_label"                ] ]
             , [ "_field/Type_list",                 ["Type_list"                 ] ]
+            , [ "_field/Type_prefix",               ["Type_prefix"               ] ]
             , [ "_field/Type_supertype_uri",        ["Type_supertype_uri"        ] ]
             , [ "_field/Type_supertype_uris",       ["Type_supertype_uris"       ] ]
             , [ "_field/Type_uri",                  ["Type_uri"                  ] ]
@@ -1095,13 +1111,13 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , [ "_field/View_choice",               ["View_choice"               ] ]
             , [ "_field/View_comment",              ["View_comment"              ] ]
             , [ "_field/View_edit_view",            ["View_edit_view"            ] ]
+            , [ "_field/View_entity_type",          ["View_entity_type"          ] ]
             , [ "_field/View_field_placement",      ["View_field_placement"      ] ]
             , [ "_field/View_field_property",       ["View_field_property"       ] ]
             , [ "_field/View_field_sel",            ["View_field_sel"            ] ]
             , [ "_field/View_fields",               ["View_fields"               ] ]
             , [ "_field/View_id",                   ["View_id"                   ] ]
             , [ "_field/View_label",                ["View_label"                ] ]
-            , [ "_field/View_target_type",          ["View_target_type"          ] ]
             , [ "_field/Vocab_id",                  ["Vocab_id"                  ] ]
             , [ "_field/Vocab_uri",                 ["Vocab_uri"                 ] ]
             ])
@@ -1151,7 +1167,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_field_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_field_fields_sorted()
         expect_fields = (
             [ "_field/Field_id"
             , "_field/Field_render_type"
@@ -1160,11 +1176,10 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             , "_field/Field_property"
             , "_field/Field_placement"
             , "_field/Field_superproperty_uris"
+            , "_field/Field_entity_type"
             , "_field/Field_value_type"
             , "_field/Field_value_mode"
-            , "_field/Field_entity_type"
             , "_field/Field_typeref"
-            , "_field/Field_fieldref"
             , "_field/Field_default"
             , "_field/Field_placeholder"
             , "_field/Field_tooltip"
@@ -1187,7 +1202,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "entity_id", "text", "Field_list")
         self.check_input_type_value(s, "List_label", "text", None)
         self.check_input_type_value(s, "List_comment", "textarea", None)
-        self.check_input_type_value(s, "List_target_type", "text", "annal:Field")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:Field")
         self.check_input_type_value(
             s, "List_entity_selector", "text", "'annal:Field' in [@type]"
             )
@@ -1259,7 +1274,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_vocab_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_vocab_fields_sorted()
         expect_fields = (
             [ "_field/Vocab_id"
             , "_field/Entity_label"
@@ -1284,7 +1299,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(
             s, "List_entity_selector", "text", "'annal:Vocabulary' in [@type]"
             )
-        self.check_input_type_value(s, "List_target_type", "text", "annal:Vocabulary")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:Vocabulary")
         self.check_select_field(s, "List_type", self.list_types_expected, "_enum_list_type/List")
         self.check_select_field(
             s, "List_default_type", 
@@ -1370,7 +1385,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
             view_id="View_view", action="edit"
             )
         s = self.get_page(u)
-        expect_field_choices = no_selection("(field sel)") + get_site_user_fields_sorted()
+        expect_field_choices = no_selection("(field reference)") + get_site_user_fields_sorted()
         expect_fields = (
             [ "_field/User_id"
             , "_field/User_name"
@@ -1392,7 +1407,7 @@ class AnnalistSiteDataTest(AnnalistTestCase):
         self.check_input_type_value(s, "entity_id", "text", "User_list")
         self.check_input_type_value(s, "List_label", "text", None)
         self.check_input_type_value(s, "List_comment", "textarea", None)
-        self.check_input_type_value(s, "List_target_type", "text", "annal:User")
+        self.check_input_type_value(s, "List_entity_type", "text", "annal:User")
         self.check_input_type_value(
             s, "List_entity_selector", "text", "'annal:User' in [@type]"
             )
