@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Tests for file upload functions.
 """
@@ -15,7 +18,7 @@ log = logging.getLogger(__name__)
 from django.conf                    import settings
 from django.contrib.auth.models     import User
 from django.test                    import TestCase
-from django.core.urlresolvers       import resolve, reverse
+from django.urls                    import resolve, reverse
 from django.test.client             import Client
 
 from annalist                       import util
@@ -29,12 +32,17 @@ from annalist.models.recordview     import RecordView
 from annalist.models.recordfield    import RecordField
 from annalist.models.entitytypeinfo import EntityTypeInfo
 
-from AnnalistTestCase       import AnnalistTestCase
-from tests                  import TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
-from init_tests             import (
-    init_annalist_test_site, init_annalist_test_coll, create_test_coll_inheriting, resetSitedata
+from .AnnalistTestCase import AnnalistTestCase
+from .tests import (
+    TestHost, TestHostUri, TestBasePath, TestBaseUri, TestBaseDir
     )
-from entity_testutils       import (
+from .init_tests import (
+    init_annalist_test_site, 
+    init_annalist_test_coll,
+    create_test_coll_inheriting,
+    resetSitedata
+    )
+from .entity_testutils import (
     create_test_user,
     create_user_permissions,
     context_field_map,
@@ -43,9 +51,9 @@ from entity_testutils       import (
     context_list_head_fields,
     context_list_item_fields
     )
-from entity_testentitydata  import (
+from .entity_testentitydata import (
     entity_url, entitydata_edit_url, 
-    entitydata_default_view_form_data,
+    default_view_form_data,
     )
 
 #   -----------------------------------------------------------------------------
@@ -85,8 +93,7 @@ test_upload_file_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_upload_view label"
     , 'rdfs:comment':               "test_upload_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -107,8 +114,7 @@ test_upload_image_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_upload_image_view label"
     , 'rdfs:comment':               "test_upload_image_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -129,8 +135,7 @@ test_reference_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_reference_view label"
     , 'rdfs:comment':               "test_reference_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -151,8 +156,7 @@ test_image_ref_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_image_view label"
     , 'rdfs:comment':               "test_image_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -173,8 +177,7 @@ test_image_view_create_values = (
     { 'annal:type':                 "annal:View"
     , 'rdfs:label':                 "test_image_view label"
     , 'rdfs:comment':               "test_image_view comment"
-    , 'annal:record_type':          ""
-    # , 'annal:add_field':            "yes"
+    , 'annal:view_entity_type':     ""
     , 'annal:view_fields':
       [ { 'annal:field_id':             "Entity_id"
         , 'annal:field_placement':      "small:0,12;medium:0,6"
@@ -224,7 +227,7 @@ test_reference_field_create_values = (
     , 'rdfs:comment':                   "test_reference_field comment"
     , 'annal:property_uri':             "test:reference"
     , 'annal:field_render_type':        "URILink"
-    , 'annal:field_value_mode':         "Value_field"
+    , 'annal:field_value_mode':         "Value_direct"
     , 'annal:field_value_type':        "annal:Identifier"
     , 'annal:field_ref_type':           "testupltype"
     , 'annal:field_ref_restriction':    "ALL"
@@ -240,7 +243,7 @@ test_image_ref_field_create_values = (
     , 'rdfs:comment':                   "test_image_ref_field comment"
     , 'annal:property_uri':             "test:reference"
     , 'annal:field_render_type':        "RefImage"
-    , 'annal:field_value_mode':         "Value_field"
+    , 'annal:field_value_mode':         "Value_direct"
     , 'annal:field_value_type':        "annal:Identifier"
     , 'annal:field_ref_type':           "testupltype"
     , 'annal:field_ref_restriction':    "ALL"
@@ -412,8 +415,14 @@ class UploadResourceTest(AnnalistTestCase):
         # resetSitedata(scope="collections")
         return
 
+    @classmethod
+    def setUpClass(cls):
+        super(UploadResourceTest, cls).setUpClass()
+        return
+
     @classmethod
     def tearDownClass(cls):
+        super(UploadResourceTest, cls).tearDownClass()
         resetSitedata(scope="collections")      # @@checkme@@
         return
 
@@ -427,13 +436,13 @@ class UploadResourceTest(AnnalistTestCase):
         testobj1 = self.test_upl_type_info.get_fileobj(
             "test1", "test1res", "annal:Text", "text/plain", "wb"
             )
-        testobj1.write("Test data test1res.txt")
+        testobj1.write(b"Test data test1res.txt")
         self.assertEqual(testobj1.name, test1dir+"/test1res.txt")
         testobj1.close()
         testobj2 = self.test_upl_type_info.get_fileobj(
             "test1", "test1res", "annal:Text", "text/plain", "rb"
             )
-        self.assertEqual(testobj2.read(), "Test data test1res.txt")
+        self.assertEqual(testobj2.read(), b"Test data test1res.txt")
         testobj2.close()
         return
 
@@ -448,22 +457,25 @@ class UploadResourceTest(AnnalistTestCase):
         resource_fileobj.close()
         testobj1.close()
         # Read back both and compare
-        siteobj = open(TestBaseDir+"/testdatafile.md", "rb")
-        testobj = self.test_upl_type_info.get_fileobj(
-            "test1", "test1res", "annal:Richtext", resource_type, "rb"
-            )
-        self.assertEqual(siteobj.read(), testobj.read())
+        with open(TestBaseDir+"/testdatafile.md", "rb") as siteobj:
+            testobj = self.test_upl_type_info.get_fileobj(
+                "test1", "test1res", "annal:Richtext", resource_type, "rb"
+                )
+            self.assertEqual(siteobj.read(), testobj.read())
+            testobj.close()
         return
 
     def test_upload_file_resource(self):
         # See https://docs.djangoproject.com/en/1.7/topics/testing/tools/#django.test.Client.post
         with open(self.filepath) as fp:
-            f = entitydata_default_view_form_data(type_id="testupltype", entity_id="test1", action="edit")
+            f = default_view_form_data(
+                type_id="testupltype", entity_id="test1", action="edit"
+                )
             f['upl_field'] = fp     # Upload file with submission
             u = entitydata_edit_url("edit", "testcoll", "testupltype", entity_id="test1", view_id="testuplfileview")
             r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Retrieve updated form
         r = self.client.get(u)
         # Test context
@@ -479,24 +491,27 @@ class UploadResourceTest(AnnalistTestCase):
         self.assertEqual(f3.field_id,     "Test_upload_file")
         self.assertDictionaryMatch(f3.field_value, test_upload_file_field_value())
         # Read back and compare entity resource just created
-        siteobj = open(self.filepath, "rb")
-        testobj = self.test_upl_type_info.get_fileobj(
-            "test1", "upl_field", "annal:Richtext", "text/markdown", "rb"
-            )
-        self.assertEqual(siteobj.read(), testobj.read())
+        with open(self.filepath, "rb") as siteobj:
+            testobj = self.test_upl_type_info.get_fileobj(
+                "test1", "upl_field", "annal:Richtext", "text/markdown", "rb"
+                )
+            self.assertEqual(siteobj.read(), testobj.read())
+            testobj.close()
         return
 
     def test_reference_uploaded_resource(self):
         # Create uploaded resource (see previous test)
         with open(self.filepath) as fp:
-            f = entitydata_default_view_form_data(type_id="testupltype", entity_id="test1", action="edit")
+            f = default_view_form_data(
+                type_id="testupltype", entity_id="test1", action="edit"
+                )
             f['upl_field'] = fp     # Upload file with submission
             u = entitydata_edit_url(
                 "view", "testcoll", "testupltype", entity_id="test1", view_id="testuplfileview"
                 )
             r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Display resource with reference
         u = entitydata_edit_url(
             "view", "testcoll", "testreftype", entity_id="test1", view_id="testrefview"
@@ -531,13 +546,15 @@ class UploadResourceTest(AnnalistTestCase):
 
     def test_upload_image_resource(self):
         # See https://docs.djangoproject.com/en/1.7/topics/testing/tools/#django.test.Client.post
-        with open(self.imagepath) as fp:
-            f = entitydata_default_view_form_data(type_id="testupltype", entity_id="test1", action="edit")
+        with open(self.imagepath, "rb") as fp:
+            f = default_view_form_data(
+                type_id="testupltype", entity_id="test1", action="edit"
+                )
             f['upl_field'] = fp     # Upload file with submission
             u = entitydata_edit_url("edit", "testcoll", "testupltype", entity_id="test1", view_id="testuplimageview")
             r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
         # Retrieve updated form
         r = self.client.get(u)
         # Test context
@@ -553,12 +570,12 @@ class UploadResourceTest(AnnalistTestCase):
         self.assertEqual(f3.field_id,     "Test_upload_image")
         self.assertDictionaryMatch(f3.field_value, test_upload_image_field_value())
         # Read back and compare entity resource just created
-        siteobj = open(self.imagepath, "rb")
-        testobj = self.test_upl_type_info.get_fileobj(
-            "test1", "upl_field", "annal:Image", "image/jpeg", "rb"
-            )
-        self.assertTrue(siteobj.read() == testobj.read(), "Uploaded image != original")
-        # self.assertEqual(siteobj.read(), testobj.read())
+        with open(self.imagepath, "rb") as siteobj:
+            testobj = self.test_upl_type_info.get_fileobj(
+                "test1", "upl_field", "annal:Image", "image/jpeg", "rb"
+                )
+            self.assertTrue(siteobj.read() == testobj.read(), "Uploaded image != original")
+            testobj.close()
         return
 
     def test_reference_uploaded_image(self):
@@ -622,25 +639,27 @@ class UploadResourceTest(AnnalistTestCase):
 
     def test_image_edit_field(self):
         # Upload to an image view field
-        with open(self.imagepath) as fp:
-            f = entitydata_default_view_form_data(type_id="testimgtype", entity_id="test1", action="edit")
+        with open(self.imagepath, "rb") as fp:
+            f = default_view_form_data(
+                type_id="testimgtype", entity_id="test1", action="edit"
+                )
             f['img_field'] = fp     # Upload file with submission
             u = entitydata_edit_url("edit", "testcoll", "testimgtype", entity_id="test1", view_id="testimgview")
             r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
 
         # Read back and compare entity resource just created
-        siteobj = open(self.imagepath, "rb")
-        testobj = self.test_img_type_info.get_fileobj(
-            "test1", "img_field", "annal:Image", "image/jpeg", "rb"
-            )
-        self.assertTrue(siteobj.read() == testobj.read(), "Referenced image != original")
+        with open(self.imagepath, "rb") as siteobj:
+            testobj = self.test_img_type_info.get_fileobj(
+                "test1", "img_field", "annal:Image", "image/jpeg", "rb"
+                )
+            self.assertTrue(siteobj.read() == testobj.read(), "Referenced image != original")
+            testobj.close()
 
         # Retrieve updated form
         r = self.client.get(u)
         # Test context
-        # print "@@ "+context_field_map(r.context)
         self.assertEqual(len(r.context['fields']), 4)
         f0 = context_view_field(r.context, 0, 0)
         self.assertEqual(f0.field_id,     "Entity_id")
@@ -715,11 +734,13 @@ class UploadResourceTest(AnnalistTestCase):
         self.test_image_edit_field()
 
         # Edit entity
-        f = entitydata_default_view_form_data(type_id="testimgtype", entity_id="test1", action="edit", update="Updated")
+        f = default_view_form_data(
+            type_id="testimgtype", entity_id="test1", action="edit", update="Updated"
+            )
         u = entitydata_edit_url("edit", "testcoll", "testimgtype", entity_id="test1", view_id="testimgview")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
 
         # Retrieve updated form
         r = self.client.get(u)
@@ -738,11 +759,12 @@ class UploadResourceTest(AnnalistTestCase):
         self.assertDictionaryMatch(f3.field_value, test_image_field_value())
 
         # Read back and compare entity resource
-        siteobj = open(self.imagepath, "rb")
-        testobj = self.test_img_type_info.get_fileobj(
-            "test1", "img_field", "annal:Image", "image/jpeg", "rb"
-            )
-        self.assertTrue(siteobj.read() == testobj.read(), "Edited entity image != original")
+        with open(self.imagepath, "rb") as siteobj:
+            testobj = self.test_img_type_info.get_fileobj(
+                "test1", "img_field", "annal:Image", "image/jpeg", "rb"
+                )
+            self.assertTrue(siteobj.read() == testobj.read(), "Edited entity image != original")
+            testobj.close()
         return
 
     def test_image_rename(self):
@@ -752,18 +774,21 @@ class UploadResourceTest(AnnalistTestCase):
         self.test_image_edit_field()
 
         # Rename entity
-        f = entitydata_default_view_form_data(type_id="testimgtype", orig_id="test1", entity_id="test_new", action="edit")
+        f = default_view_form_data(
+            type_id="testimgtype", orig_id="test1", entity_id="test_new", action="edit"
+            )
         u = entitydata_edit_url("edit", "testcoll", "testimgtype", entity_id="test1", view_id="testimgview")
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
 
         # Read back and compare renamed entity resource
-        siteobj = open(self.imagepath, "rb")
-        testobj = self.test_img_type_info.get_fileobj(
-            "test_new", "img_field", "annal:Image", "image/jpeg", "rb"
-            )
-        self.assertTrue(siteobj.read() == testobj.read(), "Renamed entity image != original")
+        with open(self.imagepath, "rb") as siteobj:
+            testobj = self.test_img_type_info.get_fileobj(
+                "test_new", "img_field", "annal:Image", "image/jpeg", "rb"
+                )
+            self.assertTrue(siteobj.read() == testobj.read(), "Renamed entity image != original")
+            testobj.close()
         return
 
     def test_inherited_image_edit(self):
@@ -806,7 +831,7 @@ class UploadResourceTest(AnnalistTestCase):
         self.assertContains(r, hi5, html=True)
 
         # Edit entity
-        f = entitydata_default_view_form_data(
+        f = default_view_form_data(
             coll_id="testsubcoll", type_id="testimgtype", entity_id="test1", 
             orig_coll="testcoll", action="edit", 
             update="Updated"
@@ -816,7 +841,7 @@ class UploadResourceTest(AnnalistTestCase):
             )
         r = self.client.post(u, f)
         self.assertEqual(r.status_code,   302)
-        self.assertEqual(r.reason_phrase, "FOUND")
+        self.assertEqual(r.reason_phrase, "Found")
 
         # Retrieve updated form
         r = self.client.get(u)
@@ -838,10 +863,12 @@ class UploadResourceTest(AnnalistTestCase):
         inherited_test_img_type_info = EntityTypeInfo(
             testsubcoll, "testimgtype", create_typedata=True
             )
-        siteobj = open(self.imagepath, "rb")
-        testobj = inherited_test_img_type_info.get_fileobj(
-            "test1", "img_field", "annal:Image", "image/jpeg", "rb"
-            )
-        self.assertTrue(siteobj.read() == testobj.read(), "Edited entity image != original")
+        with open(self.imagepath, "rb") as siteobj:
+            testobj = inherited_test_img_type_info.get_fileobj(
+                "test1", "img_field", "annal:Image", "image/jpeg", "rb"
+                )
+            self.assertTrue(siteobj.read() == testobj.read(), "Edited entity image != original")
+            testobj.close()
+        return
 
 # End.
