@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Collection resource access (JSON-LD context and maybe more)
 """
@@ -19,11 +22,8 @@ from annalist                           import layout
 import annalist.models.entitytypeinfo as entitytypeinfo
 from annalist.models.entityresourceaccess import (
     collection_fixed_json_resources,
-    find_fixed_resource,
-    entity_resource_file,
-    json_resource_file,
-    turtle_resource_file, 
-    make_turtle_resource_info
+    find_entity_resource,
+    get_resource_file
     )
 
 from annalist.views.displayinfo         import DisplayInfo
@@ -36,11 +36,6 @@ class CollectionResourceAccess(AnnalistGenericView):
     This view class returns a collection data resource.
     """
 
-    # NOTE: the logic of this view is modelled on `entityresource`, but currently
-    #       the only resource recognized is the JSON-LD context.
-
-    # @TODO: define common superclass with `entityresource` to share common logic.
-
     def __init__(self):
         super(CollectionResourceAccess, self).__init__()
         return
@@ -69,9 +64,10 @@ class CollectionResourceAccess(AnnalistGenericView):
                     message=message.COLLECTION_NOT_EXISTS%{'id': coll_id}
                     )
                 )
-
         # Locate resource
-        resource_info = find_fixed_resource(collection_fixed_json_resources, resource_ref)
+        resource_info = find_entity_resource(
+            viewinfo.site, resource_ref, fixed_resources=collection_fixed_json_resources
+            )
         log.debug("CollectionResourceAccess.get: resource_info %r"%(resource_info,))
         if resource_info is None:
             return self.error(
@@ -83,18 +79,9 @@ class CollectionResourceAccess(AnnalistGenericView):
                     )
                 )
         coll_baseurl = viewinfo.reqhost + self.get_collection_base_url(coll_id)
-        # log.info("@@@@ coll_baseurl %s, coll_id %s, resource_ref %s"%(coll_baseurl, coll_id, resource_ref))
-        if "resource_access" in resource_info:
-            # Use indicated resource access renderer
-            jsondata      = coll.get_values()
-            resource_file = resource_info["resource_access"](coll_baseurl, jsondata, resource_info)
-        else:
-            # Return resource data direct from storage
-            resource_file = entity_resource_file(coll, resource_info)
-        # resource_file = (
-        #     coll.resource_file(resource_info["resource_path"]) or
-        #     viewinfo.site.resource_file(resource_info["resource_path"])
-        #     )
+        resource_file, resource_type = get_resource_file(
+            coll, resource_info, coll_baseurl
+            )
         if resource_file is None:
             return self.error(
                 dict(self.error404values(),
@@ -104,7 +91,6 @@ class CollectionResourceAccess(AnnalistGenericView):
                         }
                     )
                 )
-
         # Return resource
         try:
             response = self.resource_response(resource_file, resource_info["resource_type"])
@@ -132,15 +118,4 @@ class CollectionResourceAccess(AnnalistGenericView):
         viewinfo.check_authorization(action)
         return viewinfo
 
-    def resource_response(self, resource_file, resource_type):
-        """
-        Construct response containing body of referenced resource,
-        with supplied resoure_type as its content_type
-        """
-        # @@TODO: assumes response can reasonably be held in memory;
-        #         consider 'StreamingHttpResponse'?
-        response = HttpResponse(content_type=resource_type)
-        response.write(resource_file.read())
-        return response
-
 # End.
