@@ -7,23 +7,30 @@ into a common module to avoid repetition of logic and reduce code clutter in
 the various Annalist view processing handlers.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-from collections                    import OrderedDict
-from distutils.version              import LooseVersion
-import json
-import re
-import urlparse
-import traceback
 import logging
 log = logging.getLogger(__name__)
 
+import json
+import re
+import traceback
+
+from packaging.version              import Version
+
+# from distutils.version              import LooseVersion
+
 from django.conf                    import settings
 from django.http                    import HttpResponse
 from django.http                    import HttpResponseRedirect
-from django.core.urlresolvers       import resolve, reverse
+from django.urls                    import resolve, reverse
+
+from utils.py3porting               import urljoin, urlsplit
 
 import annalist
 from annalist                       import message
@@ -118,24 +125,24 @@ def apply_substitutions(context, text_in):
     Any other occurrence of '$' (i.e. not part of any pattern above) is untouched.
 
     >>> context = { 'aa': '-aa-', 'bb': '-bb-', 'c:c': '-cc-'}
-    >>> apply_substitutions(context, "foo bar")
-    'foo bar'
-    >>> apply_substitutions(context, "foo $aa bar")
-    'foo -aa- bar'
-    >>> apply_substitutions(context, "foo $bb:bar")
-    'foo -bb-bar'
-    >>> apply_substitutions(context, "foo $[c:c] bar")
-    'foo -cc- bar'
-    >>> apply_substitutions(context, "foo $$ bar")
-    'foo $ bar'
-    >>> apply_substitutions(context, "foo $dd bar")
-    'foo $dd bar'
-    >>> apply_substitutions(context, "foo $ee bar")
-    'foo $ee bar'
-    >>> apply_substitutions(context, "foo $[f:f] bar")
-    'foo $[f:f] bar'
-    >>> apply_substitutions(context, "foo $aa $bb: $[c:c] $[f:f] bar")
-    'foo -aa- -bb- -cc- $[f:f] bar'
+    >>> apply_substitutions(context, "foo bar") == 'foo bar'
+    True
+    >>> apply_substitutions(context, "foo $aa bar") == 'foo -aa- bar'
+    True
+    >>> apply_substitutions(context, "foo $bb:bar") == 'foo -bb-bar'
+    True
+    >>> apply_substitutions(context, "foo $[c:c] bar") == 'foo -cc- bar'
+    True
+    >>> apply_substitutions(context, "foo $$ bar") == 'foo $ bar'
+    True
+    >>> apply_substitutions(context, "foo $dd bar") == 'foo $dd bar'
+    True
+    >>> apply_substitutions(context, "foo $ee bar") == 'foo $ee bar'
+    True
+    >>> apply_substitutions(context, "foo $[f:f] bar") == 'foo $[f:f] bar'
+    True
+    >>> apply_substitutions(context, "foo $aa $bb: $[c:c] $[f:f] bar") == 'foo -aa- -bb- -cc- $[f:f] bar'
+    True
     """
     def sub_fn(matchobj):
         matched = matchobj.group(1) or matchobj.group(2)
@@ -311,7 +318,7 @@ class DisplayInfo(object):
                 self.orig_coll  = self.collection
                 self.perm_coll  = self.collection
                 ver = self.collection.get(ANNAL.CURIE.software_version, None) or "0.0.0"
-                if LooseVersion(ver) > LooseVersion(annalist.__version__):
+                if Version(ver) > Version(annalist.__version__):
                     self.http_response = self.view.error(
                         dict(self.view.error500values(),
                             message=message.COLLECTION_NEWER_VERSION%{'id': coll_id, 'ver': ver}
@@ -322,12 +329,13 @@ class DisplayInfo(object):
 
     def flush_collection_caches(self):
         """
-        Called to flush collection caches so that changes made independentlyu of the caches
-        can be used.
+        Called to flush collection caches so that changes made independently of 
+        the caches can be used.
 
-        NOTE: this is currently called by the top-level collection view.  This is a bit of 
-        a hack to ensure that it is always possible for the user to force caches to be flushed,
-        e.g. when type informatiuon is updated in a different tab or by another user.
+        NOTE: this is currently called by the top-level collection customize view.
+        This is a bit of  a hack to ensure that it is always possible for the user 
+        to force caches to be flushed, e.g. when type informatiuon is updated in a 
+        different tab or by another user.
         """
         assert (self.collection is not None)
         self.collection.flush_collection_caches()
@@ -363,7 +371,7 @@ class DisplayInfo(object):
 
         See also method 'get_request_type_info'.
         """
-        # print "@@@@ get_type_info: type_id %s"%(type_id,)
+        # print "@@ get_type_info: type_id %s"%(type_id,)
         if not self.http_response:
             assert ((self.site and self.collection) is not None)
             if type_id:
@@ -405,14 +413,6 @@ class DisplayInfo(object):
                 list_id = self.get_list_id(self.type_id, None)
                 msg2 = message.DISPLAY_ALTERNATIVE_LIST%{'id': list_id, 'coll_id': self.coll_id}
                 self.add_error_message(msg2)
-                #@@
-                # self.http_response = self.view.error(
-                #     dict(self.view.error404values(),
-                #         message=message.RECORD_LIST_NOT_EXISTS%(
-                #             {'id': list_id, 'coll_id': self.coll_id})
-                #         )
-                #     )
-                #@@
             self.list_id    = list_id
             self.recordlist = RecordList.load(self.collection, list_id, altscope="all")
             if "@error" in self.recordlist:
@@ -448,14 +448,6 @@ class DisplayInfo(object):
                 view_id = self.get_view_id(self.type_id, None)
                 msg2 = message.DISPLAY_ALTERNATIVE_VIEW%{'id': view_id, 'coll_id': self.coll_id}
                 self.add_error_message(msg2)
-                #@@
-                # self.http_response = self.view.error(
-                #     dict(self.view.error404values(),
-                #         message=message.RECORD_VIEW_NOT_EXISTS%(
-                #             {'id': view_id, 'coll_id': self.coll_id})
-                #         )
-                #     )
-                #@@
             self.view_id    = view_id
             self.recordview = RecordView.load(self.collection, view_id, altscope="all")
             if "@error" in self.recordview:
@@ -582,9 +574,7 @@ class DisplayInfo(object):
         """
         Save list of error message to be displayed on completion of the current operation
         """
-        # print "@@ add_error_messages: > %r"%(messages,)
         self.error_messages.extend(messages)
-        # print "@@ add_error_messages: < %r"%(self.error_messages,)
         return self.http_response
 
     def redisplay_path_params(self):
@@ -628,7 +618,6 @@ class DisplayInfo(object):
                 redirect_msg_params.update(self.view.info_params("\n\n".join(self.info_messages)))
             if self.error_messages:
                 redirect_msg_params.update(self.view.error_params("\n\n".join(self.error_messages)))
-            # print "@@ redirect_response: redirect_msg_params %r"%(redirect_msg_params,)
             redirect_uri = (
                 uri_with_params(
                     redirect_path,
@@ -803,6 +792,22 @@ class DisplayInfo(object):
             self.recordlist.get(ANNAL.CURIE.default_type, None) or "Default_type"
             )
 
+    # Additional support functions for field definition view
+
+    def get_uri_type_id(self, type_uri):
+        """
+        Return type id fpr given type URI, or "Default_type".
+
+        This accesses the per-collection cache of type URI:Id mappings
+        """
+        assert (self.collection is not None)
+        type_id = "Default_type"
+        if type_uri:
+            type_ref = self.collection.get_uri_type(type_uri)
+            if type_ref:
+                type_id = type_ref.get_id()
+        return type_id
+
     # Additional support functions for collection view
 
     def get_default_view_type_entity(self):
@@ -877,14 +882,23 @@ class DisplayInfo(object):
         """
         Get URI for entity edit or copy view from list display
         """
+        # Use default view for entity type
+        # (Use list view id only for new entities)
         return self.view.view_uri(
-                "AnnalistEntityEditView", 
+                "AnnalistEntityDefaultDataView", 
                 coll_id=coll_id, 
-                view_id=self.get_list_view_id(), 
                 type_id=type_id,
                 entity_id=entity_id,
                 action=action
                 )
+        # return self.view.view_uri(
+        #         "AnnalistEntityEditView", 
+        #         coll_id=coll_id, 
+        #         view_id=self.get_list_view_id(), 
+        #         type_id=type_id,
+        #         entity_id=entity_id,
+        #         action=action
+        #         )
 
     def get_src_entity_resource_url(self, resource_ref):
         """
@@ -905,7 +919,7 @@ class DisplayInfo(object):
                 self.coll_id, type_id,
                 entity_id
                 )
-        return urlparse.urljoin(base_url, resource_ref)
+        return urljoin(base_url, resource_ref)
 
     # Additonal support functions
 
@@ -982,13 +996,13 @@ class DisplayInfo(object):
         """
         assert self.curr_typeinfo is not None
         data_ref = self.curr_typeinfo.entityclass.meta_resource_name(name_ext=name_ext)
-        # log.info("@@@@ get_entity_data_ref: data_ref "+data_ref)
+        # log.info("@@ get_entity_data_ref: data_ref "+data_ref)
         data_ref = make_data_ref(
             self.view.get_request_path(),   # For parameter values
             data_ref, 
             return_type
             )
-        # log.info("@@@@ get_entity_data_ref: data_ref "+data_ref)
+        # log.info("@@ get_entity_data_ref: data_ref "+data_ref)
         return data_ref
 
     def get_entity_jsonld_ref(self, return_type=None):
@@ -1063,7 +1077,7 @@ class DisplayInfo(object):
         Context values set here do not need to be named in the valuye map used to
         create the view context.
         """
-        site_url_parts = urlparse.urlsplit(self.site._entityurl)
+        site_url_parts = urlsplit(self.site._entityurl)
         context = (
             { 'site_label':         self.sitedata["title"]
             , 'title':              self.sitedata["title"]
@@ -1074,17 +1088,19 @@ class DisplayInfo(object):
             , 'view_id':            self.view_id
             , 'list_id':            self.list_id
             , 'collection':         self.collection
+            , 'info_coll_id':       self.coll_id or layout.SITEDATA_ID
             , "SITE":               site_url_parts.path
             , "HOST":               self.reqhost            
             })
         context.update(self.authorizations)
         if self.collection:
-            coll_url_parts = urlparse.urlsplit(self.collection._entityurl)
+            coll_url_parts = urlsplit(self.collection._entityurl)
             context.update(
                 { 'heading':    self.collection[RDFS.CURIE.label]
                 , 'coll_label': self.collection[RDFS.CURIE.label]
                 , "COLL":       coll_url_parts.path
                 , "BASE":       coll_url_parts.path + layout.COLL_BASE_REF
+                , "PAGE":       coll_url_parts.path + layout.COLL_PAGE_REF
                 })
             context['title'] = "%(coll_label)s"%context
         if self.recordview:
@@ -1094,8 +1110,9 @@ class DisplayInfo(object):
                 , 'edit_view_button':   self.recordview.get(ANNAL.CURIE.open_view, "yes")
                 })
             context['title'] = "%(view_label)s - %(coll_label)s"%context
-            edit_task_buttons = self.recordview.get(ANNAL.CURIE.edit_task_buttons, None)
-            view_task_buttons = self.recordview.get(ANNAL.CURIE.view_task_buttons, None)
+            task_buttons      = self.recordview.get(ANNAL.CURIE.task_buttons, None)
+            edit_task_buttons = self.recordview.get(ANNAL.CURIE.edit_task_buttons, task_buttons)
+            view_task_buttons = self.recordview.get(ANNAL.CURIE.view_task_buttons, task_buttons)
             self.add_task_button_context('edit_task_buttons', edit_task_buttons, context)
             self.add_task_button_context('view_task_buttons', view_task_buttons, context)
         if self.recordlist:
