@@ -2,19 +2,20 @@
 Entity list view
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import urlparse
-
 import logging
 log = logging.getLogger(__name__)
 
 from django.conf                        import settings
 from django.http                        import HttpResponse
 from django.http                        import HttpResponseRedirect
-from django.core.urlresolvers           import resolve, reverse
+from django.urls                        import resolve, reverse
 
 from annalist                           import layout
 from annalist                           import message
@@ -157,7 +158,7 @@ class EntityGenericListView(AnnalistGenericView):
         entityref = make_type_entity_id(
             entityvals[ANNAL.CURIE.type_id], entityvals[ANNAL.CURIE.id]
             )
-        entityvals['@id'] = base_url+entityref+"/"
+        entityvals['@id'] = base_url+entityref
         return entityvals
 
     def assemble_list_data(self, listinfo, scope, search_for):
@@ -175,10 +176,6 @@ class EntityGenericListView(AnnalistGenericView):
                     context={'list': listinfo.recordlist}, search=search_for
                     )
             )
-        #@@
-        # log.info("assemble_list_data: %r"%([e.get_id() for e in entity_list],))
-        #@@
-        # typeinfo = listinfo.curr_typeinfo
         base_url = self.get_collection_base_url(listinfo.coll_id)
         list_url = self.get_list_url(
             listinfo.coll_id, listinfo.list_id,
@@ -187,14 +184,11 @@ class EntityGenericListView(AnnalistGenericView):
             search=search_for
             )
         entityvallist = [ self.strip_context_values(listinfo, e, base_url) for e in entity_list ]
-        # print "@@@@ type_id %s"%(listinfo.type_id,)
-        # print "@@@@ entity_list %r"%(entity_list,)
-        # print "@@@@ entityvallist %r"%(entityvallist,)
         # log.debug("@@ listinfo.list_id %s, coll base_url %s"%(listinfo.list_id, base_url))
-        log.info(
-            "EntityListDataView.assemble_list_data: list_url %s, base_url %s, context_url %s"%
-            (list_url, base_url, base_url+layout.COLL_CONTEXT_FILE)
-            )
+        # log.info(
+        #     "EntityListDataView.assemble_list_data: list_url %s, base_url %s, context_url %s"%
+        #     (list_url, base_url, base_url+layout.COLL_CONTEXT_FILE)
+        #     )
         jsondata = (
             { '@id':            list_url
             , '@context': [
@@ -303,6 +297,7 @@ class EntityGenericListView(AnnalistGenericView):
             entity_id   = None
             if len(entity_ids) == 1:
                 (entity_type, entity_id) = split_type_entity_id(entity_ids[0], entity_type)
+                log.info("EntityList.post entity_ids: entity_type %s, entity_id %s"%(entity_type, entity_id))
             if "new" in request.POST:
                 action        = "new"
                 redirect_path = listinfo.get_new_view_uri(coll_id, entity_type)
@@ -333,9 +328,6 @@ class EntityGenericListView(AnnalistGenericView):
                     confirmed_deletion_uri
                     )
             if "default_view" in request.POST:
-                #@@
-                # auth_check = self.form_action_auth("config", listinfo.collection, CONFIG_PERMISSIONS)
-                #@@
                 auth_check = listinfo.check_authorization("config")
                 if auth_check:
                     return auth_check
@@ -371,10 +363,6 @@ class EntityGenericListView(AnnalistGenericView):
             listinfo.redirect_response(
                 redirect_path, redirect_params=redirect_params, action=action
                 )
-            # return (
-            #     listinfo.check_authorization(action) or
-            #     HttpResponseRedirect(redirect_uri)
-            #     )
         if listinfo.http_response:
             return listinfo.http_response
 
