@@ -2,17 +2,20 @@
 Define class to represent a field description when processing an entity view.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2015, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
 
-import sys
-import traceback
-import collections
-
 import logging
 log = logging.getLogger(__name__)
 
+import sys
+import traceback
+from collections            import OrderedDict
+
 from annalist               import layout
 from annalist               import message
 from annalist.identifiers   import RDFS, ANNAL
@@ -129,7 +132,7 @@ class FieldDescription(object):
             # Note: the options list may be used more than once, so the id generator
             # returned must be materialized as a list
             # Uses collections.OrderedfDict to preserve entity ordering
-            self._field_desc['field_choices'] = collections.OrderedDict()
+            self._field_desc['field_choices'] = OrderedDict()
             if field_render_type in ["Enum_optional", "Enum_choice_opt"]:
                 # Add blank choice for optional selections
                 self._field_desc['field_choices'][''] = FieldChoice('', label=field_placeholder)
@@ -251,8 +254,10 @@ class FieldDescription(object):
         """
         Returns list of possible subproperty URIs for the described field
         """
-        property_uri     = self.get_field_property_uri()
-        subproperty_uris = self._collection.cache_get_subproperty_uris(property_uri)
+        subproperty_uris = []
+        if self._collection is not None:
+            property_uri     = self.get_field_property_uri()
+            subproperty_uris = self._collection.cache_get_subproperty_uris(property_uri)
         return subproperty_uris
 
     def get_field_value_key(self, entityvals):
@@ -360,10 +365,9 @@ class FieldDescription(object):
             "  , 'field_name': %r\n"%(self.get_field_name())+
             "  , 'field_render_type': %r\n"%(self._field_desc["field_render_type"])+
             "  , 'field_property_uri': %r\n"%(self.get_field_property_uri())+
-            "  , 'type_ref': %r\n"%(self._field_desc["field_ref_type"])+
-            # "  , 'group_ref': %r\n"%(self._field_desc["field_group_ref"])+
-            # "  , 'group_list': %r\n"%(self._field_desc["group_field_list"])+
-            "  , 'group_descs': %r\n"%(self._field_desc["group_field_descs"])+
+            "  , 'field_ref_type': %r\n"%(self._field_desc["field_ref_type"])+
+            "  , 'group_field_list': %r\n"%(self._field_desc["group_field_list"])+
+            "  , 'group_field_descs': %r\n"%(self._field_desc["group_field_descs"])+
             "  })"
             )
 
@@ -378,22 +382,26 @@ class FieldDescription(object):
             )
 
     def __repr__(self):
-        return self.__repr1__()
+        return self.__repr2__()
 
     # Define methods to facilitate access to values using dictionary operations
     # on the FieldDescription object
+    #
+    # @@TODO: do we really need to return lists for .keys() and .items()?
+    # It would be more consistent with Python3 to just return an interator.
+    # Try returning iter(...) instead and see what happens?
 
     def keys(self):
         """
         Return collection metadata value keys
         """
-        return self._field_desc.keys()
+        return list(self._field_desc.keys())
 
     def items(self):
         """
         Return collection metadata value fields
         """
-        return self._field_desc.items()
+        return list(self._field_desc.items())
 
     def get(self, key, default):
         """
@@ -422,7 +430,9 @@ class FieldDescription(object):
             yield k
         return
 
-def field_description_from_view_field(collection, field, view_context=None, field_ids_seen=[]):
+def field_description_from_view_field(
+    collection, field, view_context=None, field_ids_seen=[]
+    ):
     """
     Returns a field description value created using information from
     a field reference in a view description record (i.e. a dictionary
