@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 RenderFieldValue class for returning field renderers.  This class works for 
 fields that can be rendered using supplied renderer objects (which may be 
@@ -24,9 +27,20 @@ from django.http        import HttpResponse
 from django.template    import Template, Context
 
 import django
-django.setup()  # Needed for template loader
-from django.template.loaders.app_directories import Loader
- 
+# django.setup()  # Needed for template loader (??)
+
+# Used to bypass configurable template loader so we can render using Context values
+#
+# Mostly, Analist calls template renderers with dict values for context data, which are 
+# fine with the template rendering framework introduced with Django 1.8.  But where 
+# renderers are references using {% include .. %} directives from Django templates, 
+# Context values are provided, and assumed by the compiled templates used with field 
+# value renderers.  So we need to explicitly access the DjangoTemplates engine to render 
+# field values.
+#
+from django.template import engine
+template_backend = engine.Engine.get_default()
+
 from annalist.exceptions import Annalist_Error
 
 #   ------------------------------------------------------------
@@ -39,7 +53,7 @@ from annalist.exceptions import Annalist_Error
 # Render-type-independent templates
 
 label_template = (
-    """<span>{{field.field_label|default:"&nbsp;"}}</span>"""
+    """<span>{{field.description.field_label|default:"&nbsp;"}}</span>"""
     )
 
 no_tooltip   = ""
@@ -49,8 +63,8 @@ with_tooltip = "{{field.field_tooltip_attr|safe}}"
 
 # Wrap field label
 label_wrapper_template = ( 
-    # """<!-- label_wrapper_template ({{field.field_render_type}}, {{render_mode}}) -->"""+
-    """<div class="view-label {{field.field_placement.field}}">\n"""+
+    # """<!-- label_wrapper_template ({{field.description.field_render_type}}, {{render_mode}}) -->"""+
+    """<div class="view-label {{field.description.field_placement.field}}">\n"""+
     """  {% include value_renderer %}\n"""+
     "</div>"""
     )
@@ -58,8 +72,8 @@ label_wrapper_template = (
 # Wrap bare value (e.g. column value)
 def value_wrapper_template(tooltip):
     return ( 
-        # """<!-- value_wrapper_template ({{field.field_render_type}}, {{render_mode}}) -->"""+
-        """<div class="view-value {{field.field_placement.field}}"%s>\n"""+
+        # """<!-- value_wrapper_template ({{field.description.field_render_type}}, {{render_mode}}) -->"""+
+        """<div class="view-value {{field.description.field_placement.field}}"%s>\n"""+
         """  {%% include value_renderer %%}\n"""+
         """</div>"""
         )%(tooltip,)
@@ -70,13 +84,13 @@ edit_value_wrapper_template = value_wrapper_template(with_tooltip)
 # Wrap value and include label
 def label_value_wrapper_template(tooltip):
     return (
-        # """<!-- label_value_wrapper_template ({{field.field_render_type}}, {{render_mode}}) -->"""+
-        """<div class="{{field.field_placement.field}}"%s>\n"""+
+        # """<!-- label_value_wrapper_template ({{field.description.field_render_type}}, {{render_mode}}) -->"""+
+        """<div class="{{field.description.field_placement.field}}"%s>\n"""+
         """  <div class="row view-value-row">\n"""+
-        """    <div class="view-label {{field.field_placement.label}}">\n"""+
-        """      <span>{{field.field_label}}</span>\n"""+
+        """    <div class="view-label {{field.description.field_placement.label}}">\n"""+
+        """      <span>{{field.description.field_label}}</span>\n"""+
         """    </div>\n"""+
-        """    <div class="view-value {{field.field_placement.value}}">\n"""+
+        """    <div class="view-value {{field.description.field_placement.value}}">\n"""+
         """      {%% include value_renderer %%}\n"""+
         """    </div>\n"""+
         """  </div>\n"""+
@@ -88,8 +102,8 @@ label_edit_value_wrapper_template = label_value_wrapper_template(with_tooltip)
 
 # Wrap field label with column heading styling
 col_head_wrapper_template = ( 
-    # """<!-- col_head_wrapper_template ({{field.field_render_type}}, {{render_mode}}) -->"""+
-    """<div class="view-label col-head {{field.field_placement.field}}">\n"""+
+    # """<!-- col_head_wrapper_template ({{field.description.field_render_type}}, {{render_mode}}) -->"""+
+    """<div class="view-label col-head {{field.description.field_placement.field}}">\n"""+
     """  {% include value_renderer %}\n"""+
     """</div>"""
     )
@@ -97,11 +111,11 @@ col_head_wrapper_template = (
 # Wrap value with column value styling; include label on small displays only
 def col_label_value_wrapper_template(tooltip):
     return ( 
-        # """<!-- col_label_value_wrapper_template ({{field.field_render_type}}, {{render_mode}}) -->"""+
-        """<div class="{{field.field_placement.field}}"%s>\n"""+
+        # """<!-- col_label_value_wrapper_template ({{field.description.field_render_type}}, {{render_mode}}) -->"""+
+        """<div class="{{field.description.field_placement.field}}"%s>\n"""+
         """  <div class="row show-for-small-only">\n"""+
         """    <div class="view-label small-12 columns">\n"""+
-        """      <span>{{field.field_label}}</span>\n"""+
+        """      <span>{{field.description.field_label}}</span>\n"""+
         """    </div>\n"""+
         """  </div>\n"""+
         """  <div class="row view-value-col">\n"""+
@@ -130,7 +144,8 @@ class WrapValueRenderer(object):
         try:
             return self.value_renderer.render(context)
         except Exception as e:
-            log.exception("Exception in WrapValueRenderer.value_renderer")
+            msg = "Exception in WrapValueRenderer.value_renderer"
+            log.exception(msg)
             ex_type, ex, tb = sys.exc_info()
             traceback.print_tb(tb)
             response_parts = (
@@ -140,7 +155,7 @@ class WrapValueRenderer(object):
                 ["***WrapValueRenderer.value_renderer***"]
                 )
             del tb
-            raise ValueError(msg) #@@@ (used in testing to help pinpoint errors)
+            raise ValueError(msg) # (used in testing to help pinpoint errors)
             return "\n".join(response_parts)
 
 class TemplateWrapValueRenderer(object):
@@ -155,6 +170,8 @@ class TemplateWrapValueRenderer(object):
         self.value_renderer   = WrapValueRenderer(value_renderer)
         return
     def render(self, context):
+        if isinstance(context, dict):
+            raise ValueError("@@ TemplateWrapValueRenderer.render called with dict")
         with context.push(value_renderer=self.value_renderer):
             try:
                 return self.compiled_wrapper.render(context)
@@ -180,6 +197,8 @@ class ModeWrapValueRenderer(object):
         self.value_renderer = value_renderer
         return
     def render(self, context):
+        if isinstance(context, dict):
+            raise ValueError("@@ ModeWrapValueRenderer.render called with dict")
         with context.push(render_mode=self.render_mode):
             try:
                 return self.value_renderer.render(context)
@@ -260,7 +279,7 @@ class RenderFieldValue(object):
         elif view_template is not None:
             self._view_renderer = Template(view_template)
         elif view_file is not None:
-            self._view_renderer = Template(get_template(view_file))
+            self._view_renderer = get_field_template(view_file)
         else:
             raise Annalist_Error("RenderFieldValue: no view renderer or template provided")
         # Save edit renderer
@@ -269,7 +288,7 @@ class RenderFieldValue(object):
         elif edit_template is not None:
             self._edit_renderer = Template(edit_template)
         elif edit_file is not None:
-            self._edit_renderer = Template(get_template(edit_file))
+            self._edit_renderer = get_field_template(edit_file)
         else:
             raise Annalist_Error("RenderFieldValue: no edit renderer or template provided")
         # Initialize various renderer caches
@@ -445,30 +464,22 @@ class RenderFieldValue(object):
 # Helper function for caller to get template content.
 # This uses the configured Django template loader.
 
-def get_template(templatefile, failmsg="no template filename supplied"):
+def get_field_template(templatefile, failmsg="no template filename supplied"):
     """
-    Retrieve template source from the supplied filename
+    Retrieve field template from the supplied filename
     """
     assert templatefile, "get_template: %s"%failmsg
-    # Instantiate a template loader
-    loader = Loader()
-    # Source: actual source code read from template file
-    # File path: absolute file path of template file
-    source, file_path = loader.load_template_source(templatefile)
-    return source
+    # Use DjangoTemplates backend to get template that works with Context values
+    template = template_backend.get_template(templatefile)
+    return template
 
 # Helper functions for accessing values from context
 
-# @@TODO: this seems redundant, and only used once.  Use context.get()?
 def get_context_value(context, key, default):
     if key in context:
         return context[key]
     return default
 
-# def get_context_repeat_value(context, key, default):
-#     repeat = get_context_value(context, 'repeat', {})
-#     return get_context_value(repeat, key, default)
-
 def get_context_field_value(context, key, default):
     field = get_context_value(context, 'field', {})
     return get_context_value(field, key, default)
@@ -479,5 +490,9 @@ def get_field_edit_value(context, default):
 def get_field_view_value(context, default):
     return get_context_field_value(context, 'field_view_value', default)
 
+def get_context_field_description_value(context, key, default):
+    field = get_context_value(context, 'field', None)
+    return get_context_value(field.description, key, default)
+
 # End.
 #........1.........2.........3.........4.........5.........6.........7.........8
