@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Value mapper for Identifier (URI/CURIE) field
 """
@@ -9,6 +12,8 @@ __license__     = "MIT (http://opensource.org/licenses/MIT)"
 import logging
 log = logging.getLogger(__name__)
 
+from utils.py3porting                   import is_string, to_unicode
+
 from annalist.views.fields.render_base  import RenderBase
 
 #   ----------------------------------------------------------------------------
@@ -27,7 +32,7 @@ class IdentifierValueMapper(RenderBase):
         """
         Returns an Identifier (URI/CURIE) form field value with leading/trailing spaces trimmed
         """
-        if isinstance(field_value, (str, unicode)):
+        if is_string(field_value):
             field_value = field_value.strip()
         return field_value
 
