@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Renderer and value mapper for URI value displayed as an audio player widget.
 """
@@ -67,8 +70,8 @@ class ref_audio_edit_renderer(object):
 
     def __init__(self):
         self._template = Template(
-            '''<input type="text" size="64" name="{{repeat_prefix}}{{field.field_name}}" '''+
-                   '''placeholder="{{field.field_placeholder}}" '''+
+            '''<input type="text" size="64" name="{{repeat_prefix}}{{field.description.field_name}}" '''+
+                   '''placeholder="{{field.description.field_placeholder}}" '''+
                    '''value="{{field.field_edit_value}}" />'''
         )
         return
