@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Renderer and value mapper for multiple fields displayed from a referenced entity.
 
@@ -107,21 +110,18 @@ class RenderMultiFields_label(object):
 
     returns a string that is incorporated into the resulting web page.
     """
-    # log.info("RenderMultiFields_label.render (mode: %s)"%context['render_mode'])
-    group_field_descs = context['field']['group_field_descs']
+    group_field_descs = context['field'].description['group_field_descs']
     if group_field_descs is None:
         return (
             """<span class="value-missing">Missing field group for %(group_id)s</span>"""%
             context['field']
             )
     try:
-        # log.info("@@@ RenderMultiFields_label.render field: %r"%(context['field'],))
-        # log.info("RenderMultiFields_label.render descs: %r"%(context['field']['group_field_descs'],))
         group_fields = [ bound_field(f, {}) for f in group_field_descs ]
         group_dict = (
             { 'group_bound_fields':  group_fields
             })
-        log.info("RenderMultiFields_label.render group_dict: %r"%(group_dict))
+        #@@ log.info("RenderMultiFields_label.render group_dict: %r"%(group_dict))
         with context.push(group_dict):
             response_parts = [self._template_head.render(context)]
             response_parts.append(self._template_body.render(context))
@@ -180,24 +180,18 @@ class RenderMultiFields_value(object):
                                     description bound to an entity that contains a 
                                     reference to some target entity.
 
-                @@@`context['field']` contains the group field descriptions.@@@
-
     returns a string that is incorporated into the resulting web page.
     """
     # log.info("RenderMultiFields_value.render (mode: %s)"%context['render_mode'])
-    group_field_descs = context['field']['group_field_descs']
+    group_field_descs = context['field'].description['group_field_descs']
     if group_field_descs is None:
         return (
             """<span class="value-missing">Missing field group for %(field_id)s</span>"""%
             context['field']
             )
     try:
-        # log.info("@@ RenderMultiFields_value.render field: %r"%(context['field'],))
-        # log.info("@@ RenderMultiFields_value.render descs: %r"%(context['field']['group_field_descs'],))
-        # target_vals = context['field']['target_value']
         target_vals = context['field'].get_targetvals()
         extras      = context['field']['context_extra_values']
-        # log.info("@@ RenderMultiFields_value.render target_vals: %r"%(target_vals))
         group_fields = [ 
             bound_field(f, target_vals, context_extra_values=extras) 
             for f in group_field_descs 
