@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Renderer and value mapper for a group of fields repeated over a list of values.
 """
@@ -11,14 +14,13 @@ import traceback
 import logging
 log = logging.getLogger(__name__)
 
-from django.http        import HttpResponse
-from django.template    import Template, Context
+from django.http            import HttpResponse
+from django.template        import Template, Context
 
-from annalist.exceptions                import Annalist_Error
+from annalist.exceptions    import Annalist_Error
 
-from annalist.views.fields.bound_field  import bound_field
-
-from render_fieldvalue  import (
+from .bound_field           import bound_field
+from .render_fieldvalue     import (
     RenderFieldValue,
     TemplateWrapValueRenderer, 
     ModeWrapValueRenderer
@@ -29,20 +31,20 @@ from render_fieldvalue  import (
 #   ------------------------------------------------------------
 
 view_group = (
-    { 'head':
+    { "head":
         """
         <!-- views.fields.render_repeatgroup.view_group (head) -->
         <div class="small-12 columns">
           <div class="row">
             <div class="group-label small-2 columns">
-              <span>{{field.field_label}}</span>
+              <span>{{field.description.field_label}}</span>
             </div>
             <div class="group-placeholder small-10 columns">
-              {{field.field_placeholder}}
+              {{field.description.field_placeholder}}
             </div>
           </div>
         </div>"""
-    , 'body':
+    , "body":
         """
         <div class="group-row small-12 columns">
           <div class="row">
@@ -58,31 +60,31 @@ view_group = (
             </div>
           </div>
         </div>"""
-    # , 'tail':
+    # , "tail":
     #     """
     #     """
     })
 
 edit_group = (
-    { 'head':
+    { "head":
         """<!-- views.fields.render_repeatgroup.edit_group (head) -->
         <div class="small-12 columns"{{field.field_tooltip_attr|safe}}>
           <div class="row">
             <div class="group-label small-2 columns">
-              <span>{{field.field_label}}</span>
+              <span>{{field.description.field_label}}</span>
             </div>
             <div class="group-placeholder small-10 columns">
-              {{field.field_placeholder}}
+              {{field.description.field_placeholder}}
             </div>
           </div>
         </div>"""
-    , 'body':
+    , "body":
         """
         <div class="group-row small-12 columns"{{field.field_tooltip_attr|safe}}>
           <div class="row selectable">
             <div class="small-2 columns checkbox-in-edit-padding">
               {% if auth_config %}
-              <input type="checkbox" name="{{field.group_id}}__select_fields"
+              <input type="checkbox" name="{{field.description.group_id}}__select_fields"
                      value="{{repeat_index}}" class="right" />
               {% endif %}
             </div>
@@ -95,7 +97,7 @@ edit_group = (
             </div>
           </div>
         </div>"""
-    , 'tail':
+    , "tail":
         """
         <div class="small-12 columns">
           <div class="row">
@@ -103,13 +105,13 @@ edit_group = (
               &nbsp;
             </div>
             <div class="small-10 columns">
-              <input type="submit" name="{{field.group_id}}__remove"
-                     value="{{field.group_delete_label}}" />
-              <input type="submit" name="{{field.group_id}}__add"
-                     value="{{field.group_add_label}}" />
-              <input type="submit" name="{{field.group_id}}__up"
+              <input type="submit" name="{{field.description.group_id}}__remove"
+                     value="{{field.description.group_delete_label}}" />
+              <input type="submit" name="{{field.description.group_id}}__add"
+                     value="{{field.description.group_add_label}}" />
+              <input type="submit" name="{{field.description.group_id}}__up"
                      value="Move &#x2b06;" />
-              <input type="submit" name="{{field.group_id}}__down"
+              <input type="submit" name="{{field.description.group_id}}__down"
                      value="Move &#x2b07;" />
             </div>
           </div>
@@ -117,13 +119,13 @@ edit_group = (
     })
 
 view_grouprow = (
-    { 'head':
+    { "head":
         """
         <!-- views.fields.render_repeatgroup.view_grouprow (head) -->
         <div class="small-12 columns">
           <div class="grouprow row">
             <div class="group-label small-12 medium-2 columns">
-              <span>{{field.field_label}}</span>
+              <span>{{field.description.field_label}}</span>
             </div>
             <div class="small-12 medium-10 columns hide-for-small-only">
               <div class="row">
@@ -131,7 +133,7 @@ view_grouprow = (
                   <div class="view-grouprow col-head row">
                     {% for f in group_head_fields %}
                     <!-- ===== renderer {{f.render}} -->
-                    <!-- ===== {{f.field_render_type}}.{{f.field_value_mode}}/{{f.field_id}}:{{f.field_label}} ({{render_mode}}) -->
+                    <!-- ===== {{f.description.field_render_type}}.{{f.description.field_value_mode}}/{{f.description.field_id}}:{{f.description.field_label}} ({{render_mode}}) -->
                     <!-- ===== f.render.col_head_view... -->
                     <!-- {_ include f.field_render_colhead_view with field=f %} -->
                     {% include f.render.col_head_view with field=f %}
@@ -144,13 +146,13 @@ view_grouprow = (
           </div>
         </div>
         """
-    , 'head_empty':
+    , "head_empty":
         """
         <!-- views.fields.render_repeatgroup.view_grouprow (empty list) -->
         <div class="small-12 columns">
           <div class="grouprow row">
             <div class="group-label small-12 medium-2 columns">
-              <span>{{field.field_label}}</span>
+              <span>{{field.description.field_label}}</span>
             </div>
             <div class="group-placeholder small-12 medium-10 columns">
               <span>(None specified)</span>
@@ -158,7 +160,7 @@ view_grouprow = (
           </div>
         </div>
         """
-    , 'body':
+    , "body":
         """
         <div class="small-12 columns">
           <div class="grouprow row">
@@ -179,19 +181,19 @@ view_grouprow = (
           </div>
         </div>
         """
-    # , 'tail':
+    # , "tail":
     #     """
     #     """
     })
 
 edit_grouprow = (
-    { 'head':
+    { "head":
         """
         <!-- views.fields.render_repeatgroup.edit_grouprow (head) -->
         <div class="small-12 columns"{{field.field_tooltip_attr|safe}}>
           <div class="grouprow row">
             <div class="group-label small-12 medium-2 columns">
-              <span>{{field.field_label}}</span>
+              <span>{{field.description.field_label}}</span>
             </div>
             <div class="small-12 medium-10 columns hide-for-small-only">
               <div class="row">
@@ -210,7 +212,7 @@ edit_grouprow = (
           </div>
         </div>
         """
-    , 'body':
+    , "body":
         """
         <div class="small-12 columns">
           <div class="grouprow row">
@@ -221,7 +223,7 @@ edit_grouprow = (
               <div class="tbody row select-row">
                 <div class="small-1 columns checkbox-in-edit-padding">
                   <input type="checkbox" class="select-box right"
-                         name="{{field.group_id}}__select_fields"
+                         name="{{field.description.group_id}}__select_fields"
                          value="{{repeat_index}}" />
                 </div>
                 <div class="small-11 columns">
@@ -236,7 +238,7 @@ edit_grouprow = (
           </div>
         </div>
         """
-    , 'tail':
+    , "tail":
         """
         <div class="small-12 columns">
           <div class="grouprow row">
@@ -249,13 +251,13 @@ edit_grouprow = (
                   &nbsp;
                 </div>
                 <div class="small-11 columns">
-                  <input type="submit" name="{{field.group_id}}__remove" 
-                         value="{{field.group_delete_label}}" />
-                  <input type="submit" name="{{field.group_id}}__add"    
-                         value="{{field.group_add_label}}" />
-                  <input type="submit" name="{{field.group_id}}__up"
+                  <input type="submit" name="{{field.description.group_id}}__remove" 
+                         value="{{field.description.group_delete_label}}" />
+                  <input type="submit" name="{{field.description.group_id}}__add"    
+                         value="{{field.description.group_add_label}}" />
+                  <input type="submit" name="{{field.description.group_id}}__up"
                          value="Move &#x2b06;" />
-                  <input type="submit" name="{{field.group_id}}__down"
+                  <input type="submit" name="{{field.description.group_id}}__down"
                          value="Move &#x2b07;" />
                 </div>
               </div>
@@ -266,7 +268,7 @@ edit_grouprow = (
 
 # Used for rendering lists of entities via the EntityList view class
 view_listrow = (
-    { 'head':
+    { "head":
         """
         <!-- views.fields.render_repeatgroup.view_listrow (head) -->
         <div class="thead row">
@@ -282,7 +284,7 @@ view_listrow = (
           </div>
         </div>
         """
-    , 'body':
+    , "body":
         """
         <div class="tbody row select-row">
           <div class="small-1 columns">
@@ -317,12 +319,12 @@ class RenderRepeatGroup(object):
         # log.info("RenderRepeatGroup: __init__ %r"%(templates))
         super(RenderRepeatGroup, self).__init__()
         assert templates is not None, "RenderRepeatGroup template must be supplied (.edit, .view or .item)"
-        self._template_head  = Template(templates.get('head', ""))
-        self._template_body  = Template(templates.get('body', "@@missing body@@"))
-        self._template_tail  = Template(templates.get('tail', ""))
+        self._template_head  = Template(templates.get("head", ""))
+        self._template_body  = Template(templates.get("body", "@@missing body@@"))
+        self._template_tail  = Template(templates.get("tail", ""))
         self._template_empty = self._template_head
-        if 'head_empty' in templates:
-            self._template_empty = Template(templates['head_empty'])
+        if "head_empty" in templates:
+            self._template_empty = Template(templates["head_empty"])
         return
 
     def __str__(self):
@@ -338,7 +340,7 @@ class RenderRepeatGroup(object):
 
         returns a string that is incorporated into the resulting web page.
 
-        `context['field']` is a `bound_field` value that combines the field 
+        `context["field"]` is a `bound_field` value that combines the field 
         definition, entity values and additional context information.  
 
         The entity value is either the entire entity that is currently 
@@ -347,26 +349,35 @@ class RenderRepeatGroup(object):
         """
         # log.info("RenderRepeatGroup.render")
         try:
-            # log.info("RenderRepeatGroup.render field: %r"%(context['field'],))
-            # log.info("RenderRepeatGroup.render descs: %r"%(context['field']['group_field_descs'],))
-            h = [ bound_field(f, {}) for f in context['field']['group_field_descs'] ]
-            with context.push({ 'group_head_fields': h }):
-                value_list     = context['field']['field_value']
+            # log.info("RenderRepeatGroup.render field: %r"%(context["field"],))
+            group_id          = context["field"]["description"]["group_id"]
+            group_field_descs = context["field"]["description"]["group_field_descs"]
+            # log.info("RenderRepeatGroup.render descs: %r"%(group_field_descs,))
+            h = [ bound_field(f, {}) for f in group_field_descs ]
+            with context.push({ "group_head_fields": h }):
+                value_list     = context["field"]["field_value"]
+                if value_list and not isinstance(value_list, list):
+                  # This is to allow field changes from single to repeated values
+                  # to be handled less confusingly.  String values were previously
+                  # treated as lists if characters, which gave some pretty weird
+                  # results.
+                  value_list = [value_list]
                 if len(value_list) > 0:
                     response_parts = [self._template_head.render(context)]
                     repeat_index = 0
-                    extras       = context['field']['context_extra_values']
+                    extras       = context["field"]["context_extra_values"]
                     for g in value_list:
                         # log.debug("RenderRepeatGroup.render field_val: %r"%(g))
                         r = [ bound_field(f, g, context_extra_values=extras) 
-                              for f in context['field']['group_field_descs'] ]
-                        repeat_id = context.get('repeat_prefix', "") + context['field']['group_id']
+                              for f in group_field_descs 
+                              ]
+                        repeat_id = context.get("repeat_prefix", "") + group_id
                         repeat_dict = (
-                            { 'repeat_id':            repeat_id
-                            , 'repeat_index':         str(repeat_index)
-                            , 'repeat_prefix':        repeat_id+("__%d__"%repeat_index)
-                            , 'repeat_bound_fields':  r
-                            , 'repeat_entity':        g
+                            { "repeat_id":            repeat_id
+                            , "repeat_index":         str(repeat_index)
+                            , "repeat_prefix":        repeat_id+("__%d__"%repeat_index)
+                            , "repeat_bound_fields":  r
+                            , "repeat_entity":        g
                             })
                         # log.info("RenderRepeatGroup.render repeat_dict: %r"%(repeat_dict))
                         with context.push(repeat_dict):
