@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Renderer and value mapper for URI value used to import a resource into 
 the local data store.
@@ -13,6 +16,10 @@ __license__     = "MIT (http://opensource.org/licenses/MIT)"
 import logging
 log = logging.getLogger(__name__)
 
+from utils.py3porting import is_string
+
+from django.template    import Template, Context
+
 from annalist.views.fields.render_base          import RenderBase
 from annalist.views.fields.render_fieldvalue    import (
     RenderFieldValue,
@@ -20,14 +27,29 @@ from annalist.views.fields.render_fieldvalue    import (
     get_field_view_value
     )
 
-from django.template    import Template, Context
-
 #   ----------------------------------------------------------------------------
 #
 #   Link URI value mapping
 #
 #   ----------------------------------------------------------------------------
 
+def import_field_value(data_value):
+    """
+    Construct field value in expected format for remaining processing
+    """
+    if data_value:
+        if is_string(data_value):
+            data_value = (
+                { 'resource_name': "imported.data"
+                , 'import_url':    data_value
+                })
+    else:
+        # Also for empty string case
+        data_value = (
+            { 'resource_name': "imported.data"
+            , 'import_url':    ""
+            })
+    return data_value
 
 class URIImportValueMapper(RenderBase):
     """
@@ -39,7 +61,7 @@ class URIImportValueMapper(RenderBase):
         """
         Extracts import URL from value structure, for field display.
         """
-        return (data_value or {}).get('import_url', "")
+        return import_field_value(data_value).get('import_url', "")
 
     @classmethod
     def decode(cls, field_value):
@@ -75,12 +97,12 @@ edit_import = (
     """<!-- fields.uri_import_edit_renderer -->
     <div class="row">
       <div class="small-10 columns view-value view-subfield less-import-button">
-        <input type="text" size="64" name="{{repeat_prefix}}{{field.field_name}}"
-               placeholder="{{field.field_placeholder}}"
+        <input type="text" size="64" name="{{repeat_prefix}}{{field.description.field_name}}"
+               placeholder="{{field.description.field_placeholder}}"
                value="{{encoded_field_value}}" />
       </div>
       <div class="small-2 columns view-value view-subfield import-button left small-text-right">
-        <input type="submit" name="{{repeat_prefix}}{{field.field_name}}__import" value="Import" />
+        <input type="submit" name="{{repeat_prefix}}{{field.description.field_name}}__import" value="Import" />
       </div>
     </div>
     """)
