@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Annalist class for processing a SimpleValueMap in an annalist view value mapping table.
 
