@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Annalist action confirmation view definition
 """
@@ -21,7 +24,7 @@ log = logging.getLogger(__name__)
 
 from django.http                    import HttpResponse
 from django.http                    import HttpResponseRedirect
-from django.template                import RequestContext, loader
+from django.template                import loader
 
 from django.conf                    import settings
 
