@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 """
 Annalist record view delete confirmation response handler
 """
@@ -12,7 +15,7 @@ log = logging.getLogger(__name__)
 from django.conf                        import settings
 from django.http                        import HttpResponse
 from django.http                        import HttpResponseRedirect
-from django.core.urlresolvers           import resolve, reverse
+from django.urls                        import resolve, reverse
 
 from annalist.views.uri_builder         import continuation_params
 from annalist.views.entitydeletebase    import EntityDeleteConfirmedBaseView
