@@ -2,7 +2,8 @@
 am_errors.py - status codes returns by annalist_manager
 """
 
-from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
 
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2013-2014, Graham Klyne"
@@ -47,5 +48,8 @@ AM_INSTALLCOLLFAIL  = 15        # Failed to install collection
 AM_COPYCOLLFAIL     = 16        # Failed to copy collection
 AM_MIGRATECOLLFAIL  = 17        # Failed to migrate collection
 AM_COPYENTITYFAIL   = 18        # Failed to copy entity
+AM_NOSERVERPIDFILE  = 19        # Could not find server PID file
+AM_PIDNOTFOUND      = 20        # Could not find process with PID
+AM_SERVERALREADYRUN = 21        # Server already run (saved PID found)
 
 # End.
\ No newline at end of file
