@@ -2,7 +2,8 @@
 am_getargvalue.py - read command value if not already defined
 """
 
-from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
 
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2013-2014, Graham Klyne"
@@ -14,6 +15,8 @@ import getpass
 # raw_input and getpass:
 #   http://packetforger.wordpress.com/2014/03/26/using-pythons-getpass-module/
 #   https://docs.python.org/2/library/getpass.html
+# Also, for Python 2/3:
+#   http://python-future.org/compatible_idioms.html#raw-input
 
 def getarg(args, index):
     """
@@ -27,7 +30,7 @@ def getargvalue(val, prompt):
     """
     if not val:
         if sys.stdin.isatty():
-            val = raw_input(prompt)
+            val = input(prompt)
         else:
             val = sys.stdin.readline()
             if val[-1] == '\n': val = val[:-1]
@@ -35,8 +38,13 @@ def getargvalue(val, prompt):
 
 def getsecret(prompt):
     """
-    Prompt and read secret value without echo
+    Prompt and read secret value without echo, or read from stdin.
     """
-    return getpass.getpass(prompt)
+    if sys.stdin.isatty():
+        val = getpass.getpass(prompt)
+    else:
+        val = sys.stdin.readline()
+        if val[-1] == '\n': val = val[:-1]
+    return val
 
 # End.
\ No newline at end of file
