@@ -2,7 +2,8 @@
 Display Annalist server help messages.
 """
 
-from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
 
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, G. Klyne"
@@ -15,7 +16,7 @@ import subprocess
 
 log = logging.getLogger(__name__)
 
-import am_errors
+from . import am_errors
 
 command_summary_help = ("\n"+
     "Commands:\n"+
@@ -23,6 +24,7 @@ command_summary_help = ("\n"+
     "  %(prog)s help [command]\n"+
     "  %(prog)s runtests [testlabel]\n"+
     "  %(prog)s initialize [ CONFIG ]\n"+
+    "  %(prog)s collectstatic [ CONFIG ]\n"+
     #@@ "  %(prog)s idprovider ...\n"+  #@@ TODO
     "  %(prog)s createlocaluser [ username [ email [ firstname [ lastname ] ] ] ] [ CONFIG ]\n"+
     "  %(prog)s createadminuser [ username [ email [ firstname [ lastname ] ] ] ] [ CONFIG ]\n"+
@@ -40,11 +42,16 @@ command_summary_help = ("\n"+
     "  %(prog)s migratecollection coll_id [ CONFIG ]\n"+
     "  %(prog)s migrateallcollections [ CONFIG ]\n"+
     "  %(prog)s runserver [ CONFIG ]\n"+
+    "  %(prog)s stopserver [ CONFIG ]\n"+
+    "  %(prog)s pidserver [ CONFIG ]\n"+
+    "  %(prog)s rundevserver [ CONFIG ]\n"+
     "  %(prog)s sitedirectory [ CONFIG ]\n"+
     "  %(prog)s settingsmodule [ CONFIG ]\n"+
     "  %(prog)s settingsdir [ CONFIG ]\n"+
     "  %(prog)s settingsfile [ CONFIG ]\n"+
     "  %(prog)s serverlog [ CONFIG ]\n"+
+    "  %(prog)s accesslog [ CONFIG ]\n"+
+    "  %(prog)s errorlog [ CONFIG ]\n"+
     "  %(prog)s version\n"+
     "")
 
@@ -74,7 +81,7 @@ permissions_help = (
     "The 'permissions' parameter is a list of space-separated permission keywords,\n"+
     "or may be empty.  If multiple permissions are specified, some form of command-line\n"+
     "quoting should be used so they are presented as a single argument (e.g. enclose\n"+
-    "the list of keywords in double quoted).\n"+
+    "the list of keywords in double quotes).\n"+
     "\n"+
     "If not specified on the command line, the user will be prompted for default permissions.\n"+
     "\n"+
@@ -132,6 +139,17 @@ def am_help(options, progname):
             config_options_help+
             "\n"+
             "")
+    elif options.args[0].startswith("collect"):
+        help_text = ("\n"+
+            "  %(prog)s collectstatic [ CONFIG ]\n"+
+            "\n"+
+            "Copies Annalist static data to a location where is can be served directly\n"+
+            "by a front-end server.  The location is generally subdirectory 'static'\n"+
+            "in the Annalist site base directory (see 'annalist-manager sitedirectory').\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
     elif options.args[0].startswith("createl"):
         help_text = ("\n"+
             "  %(prog)s createlocaluser [ username [ email [ firstname [ lastname ] ] ] ] [ CONFIG ]\n"+
@@ -359,7 +377,44 @@ def am_help(options, progname):
         help_text = ("\n"+
             "  %(prog)s runserver [ CONFIG ]\n"+
             "\n"+
-            "Starts an Annalist server running.\n"+
+            "Starts an Annalist server running asynchronously, and\n"+
+            "writes its process id to stdout.\n"+
+            "\n"+
+            "Normally run behind an Apache or Nginx HTTPS proxy.  Use:\n"+
+            "  OAUTHLIB_INSECURE_TRANSPORT=1 %(prog)s runserver [ CONFIG ]\n"+
+            "for local testing under HTTP\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
+    elif options.args[0].startswith("stop"):
+        help_text = ("\n"+
+            "  %(prog)s stopserver [ CONFIG ]\n"+
+            "\n"+
+            "Stops a running Annalist server.\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
+    elif options.args[0].startswith("pid"):
+        help_text = ("\n"+
+            "  %(prog)s pidserver [ CONFIG ]\n"+
+            "\n"+
+            "Displays PID of a running Annalist server.\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
+    elif options.args[0].startswith("rund"):
+        help_text = ("\n"+
+            "  %(prog)s rundevserver [ CONFIG ]\n"+
+            "\n"+
+            "Starts an Annalist development server running.  "+
+            "(Not recommended for production use.)\n"+
+            "\n"+
+            "Use:\n"+
+            "  OAUTHLIB_INSECURE_TRANSPORT=1 %(prog)s rundevserver [ CONFIG ]\n"+
+            "to allow OpenId Connect login under HTTP\n"+
             "\n"+
             config_options_help+
             "\n"+
@@ -409,6 +464,33 @@ def am_help(options, progname):
             config_options_help+
             "\n"+
             "")
+    elif options.args[0].startswith("ser"):
+        help_text = ("\n"+
+            "  %(prog)s serverlog [ CONFIG ]\n"+
+            "\n"+
+            "Sends the Annalist log filename to standard output.\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
+    elif options.args[0].startswith("acc"):
+        help_text = ("\n"+
+            "  %(prog)s accesslog [ CONFIG ]\n"+
+            "\n"+
+            "Sends the WSGI (HTTP server) access log filename to standard output.\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
+    elif options.args[0].startswith("err"):
+        help_text = ("\n"+
+            "  %(prog)s errorlog [ CONFIG ]\n"+
+            "\n"+
+            "Sends the WSGI (HTTP server) error log filename to standard output.\n"+
+            "\n"+
+            config_options_help+
+            "\n"+
+            "")
     elif options.args[0].startswith("ver"):
         help_text = ("\n"+
             "  %(prog)s version\n"+
