@@ -1,31 +1,41 @@
-# Shared deployment (separate server host) settings
-#
-# Data is kept under /var directory
-# Configuration is kept under /etc directory
-#
+"""
+Shared deployment (separate server host) settings
 
-from common import *
+Data is kept under /var directory.
+Configuration is kept under /etc directory.
+"""
+
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
+from .common import *
 
 ANNALIST_VERSION_MSG = "Annalist version %s (shared service configuration)"%(ANNALIST_VERSION)
 
-SETTINGS_MODULE = __name__
-BASE_DATA_DIR   = "/var"
-BASE_SITE_DIR   = os.path.join(BASE_DATA_DIR, layout.SITE_DIR)
-CONFIG_BASE     = "/etc/annalist/"
+SETTINGS_MODULE   = __name__
+SITE_DIR_NAME     = "annalist_site"
+BASE_DATA_DIR     = "/var"
+BASE_SITE_DIR     = os.path.join(BASE_DATA_DIR, SITE_DIR_NAME)
+CONFIG_BASE       = "/etc/annalist/"
+STATIC_ROOT       = os.path.join(BASE_SITE_DIR, 'static')
 
-# SECURITY WARNING: don't run with debug turned on in production!
-DEBUG           = False
-TEMPLATE_DEBUG  = False
-ALLOWED_HOSTS   = ['.annalist.net']     # @@FIXME
+BASE_LOG_DIR      = "/var/log/annalist/"
+ANNALIST_LOG_PATH = BASE_LOG_DIR+ANNALIST_LOG_FILE
+ACCESS_LOG_PATH   = BASE_LOG_DIR+ACCESS_LOG_FILE
+ERROR_LOG_PATH    = BASE_LOG_DIR+ERROR_LOG_FILE
 
-DATABASES = {
+DATABASE_PATH     = os.path.join(BASE_SITE_DIR, 'db.sqlite3')
+DATABASES         = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': os.path.join(BASE_DATA_DIR, 'annalist_site/db.sqlite3'),
+        'NAME':   DATABASE_PATH,
     }
 }
 
-LOGGING_FILE    = '/var/log/annalist/annalist.log'
+# SECURITY WARNING: don't run with debug turned on in production!
+DEBUG           = False
+ALLOWED_HOSTS   = ['.annalist.net']     # @@FIXME
+
 LOGGING = {
     'version': 1,
     'disable_existing_loggers': False,
@@ -41,7 +51,7 @@ LOGGING = {
         # Log to a text file that can be rotated by logrotate
         'logfile': {
             'class': 'logging.handlers.WatchedFileHandler',
-            'filename': LOGGING_FILE
+            'filename': ANNALIST_LOG_PATH
         },
     },
     'loggers': {
@@ -70,17 +80,19 @@ LOGGING = {
     },
 }
 
-
 import logging
 log = logging.getLogger(__name__)
 log.info(ANNALIST_VERSION_MSG)
-# log.info("Annalist version %s (shared service configuration)"%(ANNALIST_VERSION))
-log.info("SETTINGS_MODULE: "+SETTINGS_MODULE)
-log.info("BASE_DATA_DIR:   "+BASE_DATA_DIR)
-log.info("CONFIG_BASE:     "+CONFIG_BASE)
-log.info("DJANGO_ROOT:     "+DJANGO_ROOT)
-log.info("SITE_CONFIG_DIR: "+SITE_CONFIG_DIR)
-log.info("SITE_SRC_ROOT:   "+SITE_SRC_ROOT)
-log.info("DB PATH:         "+DATABASES['default']['NAME'])
+log.debug("SETTINGS_MODULE:   "+SETTINGS_MODULE)
+log.debug("BASE_DATA_DIR:     "+BASE_DATA_DIR)
+log.debug("CONFIG_BASE:       "+CONFIG_BASE)
+log.debug("DJANGO_ROOT:       "+DJANGO_ROOT)
+log.debug("SITE_CONFIG_DIR:   "+SITE_CONFIG_DIR)
+log.debug("SITE_SRC_ROOT:     "+SITE_SRC_ROOT)
+log.debug("STATICFILES_DIRS:  "+repr(STATICFILES_DIRS))
+log.debug("DB PATH:           "+DATABASES['default']['NAME'])
+log.debug("ALLOWED_HOSTS:     "+",".join(ALLOWED_HOSTS))
+log.debug("ANNALIST_LOG_PATH: "+ANNALIST_LOG_PATH)
+log.debug("TRACE_FIELD_VALUE: "+str(TRACE_FIELD_VALUE))
 
 # End.
