@@ -2,6 +2,9 @@
 User login views and supporting functions
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2014, 2016 G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
