@@ -2,6 +2,9 @@
 Message strings used by the login pages and associated authentication logic.
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2016, G. Klyne"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
@@ -16,6 +19,6 @@ USER_NO_EMAIL           = "No email address associated with authenticated user %
 USER_WRONG_EMAIL        = "Authenticated user %s email address mismatch (%s, %s)"
 USER_WRONG_PASSWORD     = "Login as %s: no such user or incorrect password"
 USER_ACCOUNT_DISABLED   = "Account %s has been disabled"
-
+SESSION_INTERRUPTED     = "Session data missing (try login again)"
 
 # End.
