@@ -1,7 +1,10 @@
 """
-Miscellaneous uti;lity functions
+Miscellaneous utility functions
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2009-2013, Graham Klyne, University of Oxford"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
