@@ -1,9 +1,11 @@
 #!/usr/bin/python
-
 """
 Context manager for temporarily suppressing logging
 """
 
+from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function
+
 __author__      = "Graham Klyne (GK@ACM.ORG)"
 __copyright__   = "Copyright 2011-2014, University of Oxford"
 __license__     = "MIT (http://opensource.org/licenses/MIT)"
